// FB Alpha Neo Geo driver module

#include "neogeo.h"

#include "bitswap.h"

static struct BurnRomInfo emptyRomDesc[] = {
	{"", 0, 0, 0},
};

// -----------------------------------------------------------------------------
// Common data

static struct BurnInputInfo neogeoInputList[] = {
	{"P1 Coin",		BIT_DIGITAL,	NeoButton2 + 0,	"p1 coin"},			//  0
	{"P1 Start",	BIT_DIGITAL,	NeoButton1 + 0,	"p1 start"},		//	1
	{"P1 Select",	BIT_DIGITAL,	NeoButton1 + 1,	"p1 select"},		//  2

	{"P1 Up",		BIT_DIGITAL,	NeoJoy1 + 0,	"p1 up"},			//  3
	{"P1 Down",		BIT_DIGITAL,	NeoJoy1 + 1,	"p1 down"},			//  4
	{"P1 Left",		BIT_DIGITAL,	NeoJoy1 + 2,	"p1 left"},			//	5
	{"P1 Right",	BIT_DIGITAL,	NeoJoy1 + 3,	"p1 right"},		//	6
	{"P1 Button A",	BIT_DIGITAL,	NeoJoy1 + 4,	"p1 fire 1"},		//	7
	{"P1 Button B",	BIT_DIGITAL,	NeoJoy1 + 5,	"p1 fire 2"},		//	8
	{"P1 Button C",	BIT_DIGITAL,	NeoJoy1 + 6,	"p1 fire 3"},		//	9
	{"P1 Button D",	BIT_DIGITAL,	NeoJoy1 + 7,	"p1 fire 4"},		//	A

	{"P2 Coin",		BIT_DIGITAL,	NeoButton2 + 1,	"p2 coin"},			//	B
	{"P2 Start",	BIT_DIGITAL,	NeoButton1 + 2,	"p2 start"},		//	C
	{"P2 Select",	BIT_DIGITAL,	NeoButton1 + 3,	"p2 select"},		//	D

	{"P2 Up",		BIT_DIGITAL,	NeoJoy2 + 0,	"p2 up"},			//	E
	{"P2 Down",		BIT_DIGITAL,	NeoJoy2 + 1,	"p2 down"},			//  F
	{"P2 Left",		BIT_DIGITAL,	NeoJoy2 + 2,	"p2 left"},			// 10
	{"P2 Right",	BIT_DIGITAL,	NeoJoy2 + 3,	"p2 right"},		// 11
	{"P2 Button A",	BIT_DIGITAL,	NeoJoy2 + 4,	"p2 fire 1"},		// 12
	{"P2 Button B",	BIT_DIGITAL,	NeoJoy2 + 5,	"p2 fire 2"},		// 13
	{"P2 Button C",	BIT_DIGITAL,	NeoJoy2 + 6,	"p2 fire 3"},		// 14
	{"P2 Button D",	BIT_DIGITAL,	NeoJoy2 + 7,	"p2 fire 4"},		// 15

	{"Reset",		BIT_DIGITAL,	&NeoReset,		"reset"},			// 16
	{"Test",		BIT_DIGITAL,	NeoDiag + 0,	"diag"},			// 17
	{"Service",		BIT_DIGITAL,	NeoButton2 + 2,	"service"},			// 18
	{"Dip 1",		BIT_DIPSWITCH,	NeoInput + 4,	"dip"},				// 19
	{"Dip 2",		BIT_DIPSWITCH,	NeoInput + 5,	"dip"},				// 1A

	{"System",		BIT_DIPSWITCH,	&NeoSystem,		"dip"},				// 1B
};

STDINPUTINFO(neogeo);

#define A(a, b, c, d) { a, b, (unsigned char*)(c), d }

static struct BurnInputInfo neopaddleInputList[] = {
	{"P1 Coin",		BIT_DIGITAL,	NeoButton2 + 0,	"p1 coin"},			//  0
	{"P1 Start",	BIT_DIGITAL,	NeoButton1 + 0,	"p1 start"},		//	1
	{"P1 Select",	BIT_DIGITAL,	NeoButton1 + 1,	"p1 select"},		//  2

	{"P1 Up",		BIT_DIGITAL,	NeoJoy1 + 0,	"p1 up"},			//  3
	{"P1 Down",		BIT_DIGITAL,	NeoJoy1 + 1,	"p1 down"},			//  4
	{"P1 Left",		BIT_DIGITAL,	NeoJoy1 + 2,	"p1 left"},			//	5
	{"P1 Right",	BIT_DIGITAL,	NeoJoy1 + 3,	"p1 right"},		//	6
	{"P1 Button A",	BIT_DIGITAL,	NeoJoy1 + 4,	"p1 fire 1"},		//	7
	{"P1 Button B",	BIT_DIGITAL,	NeoJoy1 + 5,	"p1 fire 2"},		//	8
	{"P1 Button C",	BIT_DIGITAL,	NeoJoy1 + 6,	"p1 fire 3"},		//	9
	{"P1 Button D",	BIT_DIGITAL,	NeoJoy1 + 7,	"mouse button 1"},	//	A
   A("P1 Paddle",	BIT_ANALOG_REL, NeoAxis + 0,	"mouse x-axis"),	//	B

	{"P2 Coin",		BIT_DIGITAL,	NeoButton2 + 1,	"p2 coin"},			//	C
	{"P2 Start",	BIT_DIGITAL,	NeoButton1 + 2,	"p2 start"},		//	D
	{"P2 Select",	BIT_DIGITAL,	NeoButton1 + 3,	"p2 select"},		//	E

	{"P2 Up",		BIT_DIGITAL,	NeoJoy2 + 0,	"p2 up"},			//	F
	{"P2 Down",		BIT_DIGITAL,	NeoJoy2 + 1,	"p2 down"},			// 10
	{"P2 Left",		BIT_DIGITAL,	NeoJoy2 + 2,	"p2 left"},			// 11
	{"P2 Right",	BIT_DIGITAL,	NeoJoy2 + 3,	"p2 right"},		// 12
	{"P2 Button A",	BIT_DIGITAL,	NeoJoy2 + 4,	"p2 fire 1"},		// 13
	{"P2 Button B",	BIT_DIGITAL,	NeoJoy2 + 5,	"p2 fire 2"},		// 14
	{"P2 Button C",	BIT_DIGITAL,	NeoJoy2 + 6,	"p2 fire 3"},		// 15
	{"P2 Button D",	BIT_DIGITAL,	NeoJoy2 + 7,	"p2 fire 4"},		// 16
   A("P2 Paddle",	BIT_ANALOG_REL, NeoAxis + 1,	"p2 x-axis"),		// 17

	{"Reset",		BIT_DIGITAL,	&NeoReset,		"reset"},			// 18
	{"Test",		BIT_DIGITAL,	NeoDiag + 0,	"diag"},			// 19
	{"Service",		BIT_DIGITAL,	NeoButton2 + 2,	"service"},			// 1A
	{"Dip 1",		BIT_DIPSWITCH,	NeoInput + 4,	"dip"},				// 1B
	{"Dip 2",		BIT_DIPSWITCH,	NeoInput + 5,	"dip"},				// 1C

	{"System",		BIT_DIPSWITCH,	&NeoSystem,		"dip"},				// 1D
};

STDINPUTINFO(neopaddle);

static struct BurnInputInfo neotrackballInputList[] = {
	{"P1 Coin",		BIT_DIGITAL,	NeoButton2 + 0,	"p1 coin"},			//  0
	{"P1 Start",	BIT_DIGITAL,	NeoButton1 + 0,	"p1 start"},		//	1

   A("P1 X Axis",	BIT_ANALOG_REL,	NeoAxis + 0,	"mouse x-axis"),	//	2
   A("P1 Y Axis",	BIT_ANALOG_REL,	NeoAxis + 1,	"mouse y-axis"),	//	3

	{"P1 Button A",	BIT_DIGITAL,	NeoJoy2 + 4,	"mouse button 1"},	//	4
	{"P1 Button B",	BIT_DIGITAL,	NeoJoy2 + 5,	"mouse button 2"},	//	5

	{"P2 Coin",		BIT_DIGITAL,	NeoButton2 + 1,	"p2 coin"},			//	6
	{"P2 Start",	BIT_DIGITAL,	NeoButton1 + 2,	"p2 start"},		//	7

	{"P2 Button A",	BIT_DIGITAL,	NeoJoy2 + 6,	"p2 fire 1"},		//  8
	{"P2 Button B",	BIT_DIGITAL,	NeoJoy2 + 7,	"p2 fire 2"},		//  9

	{"Reset",		BIT_DIGITAL,	&NeoReset,		"reset"},			//  A
	{"Test",		BIT_DIGITAL,	NeoDiag + 0,	"diag"},			//  B
	{"Service",		BIT_DIGITAL,	NeoButton2 + 2,	"service"},			//  C
	{"Dip 1",		BIT_DIPSWITCH,	NeoInput + 4,	"dip"},				//  D
	{"Dip 2",		BIT_DIPSWITCH,	NeoInput + 5,	"dip"},				//  E

	{"System",		BIT_DIPSWITCH,	&NeoSystem,		"dip"},				//  F
};

STDINPUTINFO(neotrackball);

#undef A

static struct BurnInputInfo neodualInputList[] = {
	{"P1 Coin",		BIT_DIGITAL,	NeoButton2 + 0,	"p1 coin"},			//  0
	{"P1 Start",	BIT_DIGITAL,	NeoButton1 + 0,	"p1 start"},		//	1
	{"P1 Select",	BIT_DIGITAL,	NeoButton1 + 1,	"p1 select"},		//  2

	{"P1 Up",		BIT_DIGITAL,	NeoJoy1 + 0,	"p1 up"},			//  3
	{"P1 Down",		BIT_DIGITAL,	NeoJoy1 + 1,	"p1 down"},			//  4
	{"P1 Left",		BIT_DIGITAL,	NeoJoy1 + 2,	"p1 left"},			//	5
	{"P1 Right",	BIT_DIGITAL,	NeoJoy1 + 3,	"p1 right"},		//	6
	{"P1 Button A",	BIT_DIGITAL,	NeoJoy1 + 4,	"p1 fire 1"},		//	7
	{"P1 Button B",	BIT_DIGITAL,	NeoJoy1 + 5,	"p1 fire 2"},		//	8
	{"P1 Button C",	BIT_DIGITAL,	NeoJoy1 + 6,	"p1 fire 3"},		//	9
	{"P1 Button D",	BIT_DIGITAL,	NeoJoy1 + 7,	"p1 fire 4"},		//	A

	{"P2 Coin",		BIT_DIGITAL,	NeoButton2 + 1,	"p2 coin"},			//	B
	{"P2 Start",	BIT_DIGITAL,	NeoButton1 + 2,	"p2 start"},		//	C
	{"P2 Select",	BIT_DIGITAL,	NeoButton1 + 3,	"p2 select"},		//	D

	{"P2 Up",		BIT_DIGITAL,	NeoJoy2 + 0,	"p2 up"},			//	E
	{"P2 Down",		BIT_DIGITAL,	NeoJoy2 + 1,	"p2 down"},			//  F
	{"P2 Left",		BIT_DIGITAL,	NeoJoy2 + 2,	"p2 left"},			// 10
	{"P2 Right",	BIT_DIGITAL,	NeoJoy2 + 3,	"p2 right"},		// 11
	{"P2 Button A",	BIT_DIGITAL,	NeoJoy2 + 4,	"p2 fire 1"},		// 12
	{"P2 Button B",	BIT_DIGITAL,	NeoJoy2 + 5,	"p2 fire 2"},		// 13
	{"P2 Button C",	BIT_DIGITAL,	NeoJoy2 + 6,	"p2 fire 3"},		// 14
	{"P2 Button D",	BIT_DIGITAL,	NeoJoy2 + 7,	"p2 fire 4"},		// 15

	{"P3 Coin",		BIT_DIGITAL,	NeoButton4 + 0,	"p3 coin"},			// 16
	{"P3 Start",	BIT_DIGITAL,	NeoButton3 + 0,	"p3 start"},		// 17
	{"P3 Select",	BIT_DIGITAL,	NeoButton3 + 1,	"p3 select"},		// 18

	{"P3 Up",		BIT_DIGITAL,	NeoJoy3 + 0,	"p3 up"},			// 19
	{"P3 Down",		BIT_DIGITAL,	NeoJoy3 + 1,	"p3 down"},			// 1A
	{"P3 Left",		BIT_DIGITAL,	NeoJoy3 + 2,	"p3 left"},			// 1B
	{"P3 Right",	BIT_DIGITAL,	NeoJoy3 + 3,	"p3 right"},		// 1C
	{"P3 Button A",	BIT_DIGITAL,	NeoJoy3 + 4,	"p3 fire 1"},		// 1D
	{"P3 Button B",	BIT_DIGITAL,	NeoJoy3 + 5,	"p3 fire 2"},		// 1E
	{"P3 Button C",	BIT_DIGITAL,	NeoJoy3 + 6,	"p3 fire 3"},		// 1F
	{"P3 Button D",	BIT_DIGITAL,	NeoJoy3 + 7,	"p3 fire 4"},		// 20

	{"P4 Coin",		BIT_DIGITAL,	NeoButton4 + 1,	"p4 coin"},			// 21
	{"P4 Start",	BIT_DIGITAL,	NeoButton3 + 2,	"p4 start"},		// 22
	{"P4 Select",	BIT_DIGITAL,	NeoButton3 + 3,	"p4 select"},		// 23

	{"P4 Up",		BIT_DIGITAL,	NeoJoy4 + 0,	"p4 up"},			// 24
	{"P4 Down",		BIT_DIGITAL,	NeoJoy4 + 1,	"p4 down"},			// 25
	{"P4 Left",		BIT_DIGITAL,	NeoJoy4 + 2,	"p4 left"},			// 26
	{"P4 Right",	BIT_DIGITAL,	NeoJoy4 + 3,	"p4 right"},		// 27
	{"P4 Button A",	BIT_DIGITAL,	NeoJoy4 + 4,	"p4 fire 1"},		// 28
	{"P4 Button B",	BIT_DIGITAL,	NeoJoy4 + 5,	"p4 fire 2"},		// 29
	{"P4 Button C",	BIT_DIGITAL,	NeoJoy4 + 6,	"p4 fire 3"},		// 2A
	{"P4 Button D",	BIT_DIGITAL,	NeoJoy4 + 7,	"p4 fire 4"},		// 2B

	{"Reset",		BIT_DIGITAL,	&NeoReset,		"reset"},			// 2C

	{"Test 1",		BIT_DIGITAL,	NeoDiag + 0,	"diag"},			// 2D
	{"Service 1",	BIT_DIGITAL,	NeoButton2 + 2,	"service"},			// 2E
	{"Test 2",		BIT_DIGITAL,	NeoDiag + 1,	""},				// 2F
	{"Service 2",	BIT_DIGITAL,	NeoButton4 + 2,	""},				// 30

	{"Dip 1",		BIT_DIPSWITCH,	NeoInput + 4,	"dip"},				// 31
	{"Dip 2",		BIT_DIPSWITCH,	NeoInput + 5,	"dip"},				// 32

	{"System",		BIT_DIPSWITCH,	&NeoSystem,		"dip"},				// 33
};

STDINPUTINFO(neodual);

static struct BurnInputInfo neomahjongInputList[] = {
	{"P1 Coin",		BIT_DIGITAL,	NeoButton2 + 0,	"p1 coin"},			//  0
	{"P1 Start",	BIT_DIGITAL,	NeoButton1 + 0,	"p1 start"},		//	1
	{"P1 Select",	BIT_DIGITAL,	NeoButton1 + 1,	"p1 select"},		//  2

	{"P1 Up",		BIT_DIGITAL,	NeoJoy1 + 0,	"p1 up"},			//  3
	{"P1 Down",		BIT_DIGITAL,	NeoJoy1 + 1,	"p1 down"},			//  4
	{"P1 Left",		BIT_DIGITAL,	NeoJoy1 + 2,	"p1 left"},			//	5
	{"P1 Right",	BIT_DIGITAL,	NeoJoy1 + 3,	"p1 right"},		//	6
	{"P1 Button A",	BIT_DIGITAL,	NeoJoy1 + 4,	"p1 fire 1"},		//	7
	{"P1 Button B",	BIT_DIGITAL,	NeoJoy1 + 5,	"p1 fire 2"},		//	8
	{"P1 Button C",	BIT_DIGITAL,	NeoJoy1 + 6,	"p1 fire 3"},		//	9
	{"P1 Button D",	BIT_DIGITAL,	NeoJoy1 + 7,	"p1 fire 4"},		//	A

	{"A",			BIT_DIGITAL,	NeoButton1 +  8,	"key tab"},		//  B
	{"B",			BIT_DIGITAL,	NeoButton1 +  9,	"key q"},		//  C
	{"C",			BIT_DIGITAL,	NeoButton1 + 10,	"key w"},		//  D
	{"D",			BIT_DIGITAL,	NeoButton1 + 11,	"key e"},		//  E
	{"E",			BIT_DIGITAL,	NeoButton1 + 12,	"key r"},		//  F
	{"F",			BIT_DIGITAL,	NeoButton1 + 13,	"key t"},		// 10
	{"G",			BIT_DIGITAL,	NeoButton1 + 14,	"key y"},		// 11
	{"H",			BIT_DIGITAL,	NeoButton1 + 16,	"key u"},		// 12
	{"I",			BIT_DIGITAL,	NeoButton1 + 17,	"key i"},		// 13
	{"J",			BIT_DIGITAL,	NeoButton1 + 18,	"key o"},		// 14
	{"K",			BIT_DIGITAL,	NeoButton1 + 19,	"key p"},		// 15
	{"L",			BIT_DIGITAL,	NeoButton1 + 20,	"key ["},		// 16
	{"M",			BIT_DIGITAL,	NeoButton1 + 21,	"key ]"},		// 17
	{"N",			BIT_DIGITAL,	NeoButton1 + 22,	"key backslash"},		// 18
	{"Pon",			BIT_DIGITAL,	NeoButton1 + 24,	"key a"},		// 19
	{"Chi",			BIT_DIGITAL,	NeoButton1 + 25,	"key s"},		// 1A
	{"Kan",			BIT_DIGITAL,	NeoButton1 + 26,	"key d"},		// 1B
	{"Ron",			BIT_DIGITAL,	NeoButton1 + 27,	"key f"},		// 1C
	{"Reach",		BIT_DIGITAL,	NeoButton1 + 28,	"key g"},		// 1D

	{"P2 Coin",		BIT_DIGITAL,	NeoButton2 + 1,	"p2 coin"},			// 1E
	{"P2 Start",	BIT_DIGITAL,	NeoButton1 + 2,	"p2 start"},		// 1F
	{"P2 Select",	BIT_DIGITAL,	NeoButton1 + 3,	"p2 select"},		// 20

	{"P2 Up",		BIT_DIGITAL,	NeoJoy2 + 0,	"p2 up"},			// 21
	{"P2 Down",		BIT_DIGITAL,	NeoJoy2 + 1,	"p2 down"},			// 22
	{"P2 Left",		BIT_DIGITAL,	NeoJoy2 + 2,	"p2 left"},			// 23
	{"P2 Right",	BIT_DIGITAL,	NeoJoy2 + 3,	"p2 right"},		// 24
	{"P2 Button A",	BIT_DIGITAL,	NeoJoy2 + 4,	"p2 fire 1"},		// 25
	{"P2 Button B",	BIT_DIGITAL,	NeoJoy2 + 5,	"p2 fire 2"},		// 26
	{"P2 Button C",	BIT_DIGITAL,	NeoJoy2 + 6,	"p2 fire 3"},		// 27
	{"P2 Button D",	BIT_DIGITAL,	NeoJoy2 + 7,	"p2 fire 4"},		// 28

	{"Reset",		BIT_DIGITAL,	&NeoReset,		"reset"},			// 29
	{"Test",		BIT_DIGITAL,	NeoDiag + 0,	"diag"},			// 2A
	{"Service",		BIT_DIGITAL,	NeoButton2 + 2,	"service"},			// 2B
	{"Dip 1",		BIT_DIPSWITCH,	NeoInput + 4,	"dip"},				// 2C
	{"Dip 2",		BIT_DIPSWITCH,	NeoInput + 5,	"dip"},				// 2D

	{"System",		BIT_DIPSWITCH,	&NeoSystem,		"dip"},				// 2E
};

STDINPUTINFO(neomahjong);

static struct BurnDIPInfo neodefaultDIPList[] = {
	// Offset
	{0x19,	0xF0, 0x00,	0x00, NULL},

	// Defaults
	{0x00,	0xFF, 0xFF,	0x00, NULL},
	{0x01,	0xFF, 0x7F,	0x00, NULL},
	// Fake DIPs
	{0x02,	0xFF, 0xFF,	0x86, NULL},

	{0,		0xFE, 0,	2,	  "Autofire"},
	{0x00,	0x01, 0x04,	0x00, "Off"},
	{0x00,	0x01, 0x04,	0x04, "On"},
};

static struct BurnDIPInfo neopaddleDIPList[] = {
	// Offset
	{0x1B,	0xF0, 0x00,	0x00, NULL},

	// Defaults
	{0x00,	0xFF, 0xFF,	0x00, NULL},
	{0x01,	0xFF, 0x7F,	0x00, NULL},
	// Fake DIPs
	{0x02,	0xFF, 0xFF,	0x86, NULL},
};

static struct BurnDIPInfo neodualDIPList[] = {
	// Offset
	{0x31,	0xF0, 0x00,	0x00, NULL},

	// Defaults
	{0x00,	0xFF, 0xFF,	0x00, NULL},
	{0x01,	0xFF, 0x7F,	0x00, NULL},
	// Fake DIPs
	{0x02,	0xFF, 0xFF,	0x86, NULL},

	{0,		0xFE, 0,	2,	  "Autofire"},
	{0x00,	0x01, 0x04,	0x00, "Off"},
	{0x00,	0x01, 0x04,	0x04, "On"},
};

static struct BurnDIPInfo neomahjongDIPList[] = {
	// Offset
	{0x2C,	0xF0, 0x00,	0x00, NULL},

	// Defaults
	{0x00,	0xFF, 0xFF,	0x00, NULL},
	{0x01,	0xFF, 0x7F,	0x00, NULL},
	// Fake DIPs
	{0x02,	0xFF, 0xFF,	0x84, NULL},

	{0,		0xFE, 0,	2,	  "Mahjong control panel"},
	{0x00,	0x01, 0x04,	0x00, "Off"},
	{0x00,	0x01, 0x04,	0x04, "On"},
};

static struct BurnDIPInfo neogeoDIPList[] = {
	// DIP 1
	{0,		0xFE, 0,	2,	  "Setting mode"},
	{0x00,	0x01, 0x01,	0x00, "Off"},
	{0x00,	0x01, 0x01,	0x01, "On"},

	// 1 or 2 coin slots
	{0,		0xFE, 0,	2,	  "Coin chutes"},
	{0x00,	0x02, 0x02,	0x00, "1"},
	{0x02,	0x00, 0x3F,	0x06, NULL},
	{0x00,	0x02, 0x02,	0x02, "2"},
	{0x02,	0x00, 0x3F,	0x06, NULL},
	// 2 or 4 coin slots
	{0,		0xFE, 0,	2,	  "Coin chutes"},
	{0x00,	0x82, 0x02,	0x00, "2"},
	{0x02,	0x00, 0x3F,	0x06, NULL},
	{0x00,	0x82, 0x02,	0x02, "4"},
	{0x02,	0x00, 0x3F,	0x06, NULL},

	{0,		0xFE, 0,	5,	  "Commmunicaton"},
	{0x00,	0x01, 0x38,	0x00, "Disabled"},
	{0x00,	0x01, 0x38,	0x08, "Setting 1"},
	{0x00,	0x01, 0x38,	0x10, "Setting 2"},
	{0x00,	0x01, 0x38,	0x18, "Setting 3"},
	{0x00,	0x01, 0x38,	0x20, "Setting 4"},
	{0x00,	0x01, 0x38,	0x28, "Setting 5"},
	{0x00,	0x01, 0x38,	0x30, "Setting 6"},
	{0x00,	0x01, 0x38,	0x38, "Setting 7"},
	{0,		0xFE, 0,	2,	  "Free play"},
	{0x00,	0x01, 0x40,	0x00, "Off"},
	{0x00,	0x01, 0x40,	0x40, "On"},
	{0,		0xFE, 0,	2,	  "Stop mode"},
	{0x00,	0x01, 0x80,	0x00, "Off"},
	{0x00,	0x01, 0x80,	0x80, "On"},

	// Fake DIPs

	// Memory card
	{0,		0xFD, 0,	2,	  "Memory card"},
	{0x02,	0x01, 0x80,	0x80, "Writable"},
	{0x02,	0x01, 0x80,	0x00, "Write-protected"},

	// MVS/AES system
	{0,		0xFD, 0,	2,	  NULL},
	{0x02,	0x02, 0x04,	0x04, "MVS system"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	{0x02,	0x02, 0x04,	0x00, "AES system"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	// Region
	{0,		0xFD, 0,	3,	  "Region"},
	{0x02,	0x02, 0x03,	0x00, "Japan"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	{0x02,	0x02, 0x03,	0x01, "USA"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	{0x02,	0x02, 0x03,	0x02, "Asia / Europe"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	{0x02,	0x02, 0x03,	0x03, "Japan"},
	{0x02,	0x00, 0x30,	0x00, NULL},
	// Custom BIOS
	{0,		0xFD, 0,	3,	  NULL},
	{0x02,	0x01, 0x30,	0x00, "Normal BIOS"},
	{0x02,	0x01, 0x30,	0x10, "Debug BIOS"},
	{0x02,	0x01, 0x30,	0x20, "Universe BIOS"},
};

STDDIPINFOEXT(neogeo, neodefault, neogeo);
STDDIPINFOEXT(neopaddle, neopaddle, neogeo);
STDDIPINFOEXT(neodual, neodual, neogeo);
STDDIPINFOEXT(neomahjong, neomahjong, neogeo);

static struct BurnDIPInfo neotrackballDIPList[] = {
	// Defaults
	{0x0D,	0xFF, 0xFF,	0x00, NULL},
	{0x0E,	0xFF, 0x7F,	0x00, NULL},
	// Fake DIPs
	{0x0F,	0xFF, 0xFF,	0x86, NULL},

	// DIP 1
	{0,		0xFE, 0,	2,	  "Setting mode"},
	{0x0D,	0x01, 0x01,	0x00, "Off"},
	{0x0D,	0x01, 0x01,	0x01, "On"},
	{0,		0xFE, 0,	2,	  "Coin chutes"},
	{0x0D,	0x01, 0x02,	0x00, "1"},
	{0x0D,	0x01, 0x02,	0x02, "2"},
	{0,		0xFE, 0,	2,	  "Autofire"},
	{0x0D,	0x01, 0x04,	0x00, "Off"},
	{0x0D,	0x01, 0x04,	0x04, "On"},
	{0,		0xFE, 0,	5,	  "Commmunicaton"},
	{0x0D,	0x01, 0x38,	0x00, "Disabled"},
	{0x0D,	0x01, 0x38,	0x08, "Setting 1"},
	{0x0D,	0x01, 0x38,	0x10, "Setting 2"},
	{0x0D,	0x01, 0x38,	0x18, "Setting 3"},
	{0x0D,	0x01, 0x38,	0x20, "Setting 4"},
	{0x0D,	0x01, 0x38,	0x28, "Setting 5"},
	{0x0D,	0x01, 0x38,	0x30, "Setting 6"},
	{0x0D,	0x01, 0x38,	0x38, "Setting 7"},
	{0,		0xFE, 0,	2,	  "Free play"},
	{0x0D,	0x01, 0x40,	0x00, "Off"},
	{0x0D,	0x01, 0x40,	0x40, "On"},
	{0,		0xFE, 0,	2,	  "Stop mode"},
	{0x0D,	0x01, 0x80,	0x00, "Off"},
	{0x0D,	0x01, 0x80,	0x80, "On"},

	// Memory card
	{0,		0xFD, 0,	2,	  "Memory card"},
	{0x0F,	0x01, 0x80,	0x80, "Writable"},
	{0x0F,	0x01, 0x80,	0x00, "Write-protected"},

	// MVS/AES system
	{0,		0xFD, 0,	2,	  NULL},
	{0x0F,	0x02, 0x04,	0x04, "MVS system"},
	{0x0F,	0x00, 0x30,	0x00, NULL},
	{0x0F,	0x02, 0x04,	0x00, "AES system"},
	{0x0F,	0x00, 0x30,	0x00, NULL},
	// Region
	{0,		0xFD, 0,	3,	  "Region"},
	{0x0F,	0x01, 0x03,	0x00, "Japan"},
	{0x0F,	0x01, 0x03,	0x01, "USA"},
	{0x0F,	0x01, 0x03,	0x02, "Asia / Europe"},
	{0x0F,	0x01, 0x03,	0x03, "Japan"},
};

STDDIPINFO(neotrackball);

// Rom information
static struct BurnRomInfo neogeoRomDesc[] = {
	{"vs-bios.rom",	0x020000, 0xF0E8F27D, 0xD0}, //	 0 68K BIOS (JP, MVS, ? slot, version 3)
//	{"sp-j2.rom",	0x020000, 0xACEDE59C, 0xD0}, //	 0 68K BIOS (JP, MVS, ? slot, version 2)
	{"usa_2slt.bin",0x020000, 0xE72943DE, 0xD0}, //  1 68K BIOS (US, MVS, 2 slot, version 2)
//	{"sp-e.sp1",	0x020000, 0x2723A5B5, 0xD0}, //  1 68K BIOS (US, MVS, 6 slot, version 1)
	{"asia-s3.rom",	0x020000, 0x91B64BE3, 0x50}, //  2 68K BIOS (AS, MVS, ? slot, version 3)
//	{"sp-s2.sp1",	0x020000, 0x9036D879, 0xD0}, //  2 68K BIOS (AS, MVS, 1 slot, version 2)
//	{"sp-s.sp1",	0x020000, 0xC7F2FA45, 0xD0}, //  2 68K BIOS (AS, MVS, 4 slot, version 1)
	{"", 0, 0, 0},

	{"", 0, 0, 0},								 //	 4 68K BIOS (JP, AES)
	{"", 0, 0, 0},								 //	 5 68K BIOS (US, AES)
	{"aes-bios.bin",0x020000, 0xD27A71F1, 0xD0}, //	 6 68K BIOS (AS, AES)
	{"", 0, 0, 0},

	{"neodebug.bin",0x020000, 0x698EBB7D, 0xD0}, //  8 68K BIOS (JP, devkit)
//	{"236-bios.bin",0x020000, 0x853E6B96, 0xD0}, //  9 68K BIOS	(AS, MVS, supports analog controls)
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

//	{"uni-bios.10",	0x020000, 0x0CE453A0, 0xD0}, //  C Universe BIOS (v1.0)
//	{"uni-bios.11",	0x020000, 0x5DDA0D84, 0xD0}, //  C Universe BIOS (v1.1)
	{"uni-bios.12",	0x020000, 0x4FA698E9, 0xD0}, //  C Universe BIOS (v1.2)
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"sm1.sm1",		0x020000, 0x97Cf998B, 0x10}, // 10 Z80 program
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"sfix.sfx",	0x020000, 0x354029FC,	 1}, // 14 Text layer tiles
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"000-lo.lo",	0x010000, 0xE09E253C,    1}, // 18 Zoom table
};

STD_ROM_PICK(neogeo);
STD_ROM_FN(neogeo);

static struct BurnRomInfo neotrackballRomDesc[] = {
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"", 0, 0, 0},
	{"236-bios.bin",0x020000, 0x853E6B96, 0x40}, //  9 68K BIOS	(EU/AS, MVS, supports analog controls)
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"sm1.sm1",		0x020000, 0x97Cf998B, 0x10}, // 10 Z80 program
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"sfix.sfx",	0x020000, 0x354029FC,	 1}, // 14 Text layer tiles
	{"", 0, 0, 0},
	{"", 0, 0, 0},
	{"", 0, 0, 0},

	{"000-lo.lo",	0x010000, 0xE09E253C,    1}, // 18 Zoom table
};

STD_ROM_PICK(neotrackball);
STD_ROM_FN(neotrackball);

struct BurnDriver BurnDrvNeoGeo = {
	{"neogeo", "Neo Geo", "BIOS only", "SNK", "Neo Geo", "1990", NULL, NULL},
	BDF_BOARDROM, 0, HARDWARE_SNK_NEOGEO,
	NULL, neogeoRomInfo, neogeoRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// ----------------------------------------------------------------------------
// Neo Geo 4 player test cartridge

static struct BurnRomInfo fourplayRomDesc[] = {
	{"4play_p1.rom"   , 0x100000, 0x3C3D741B, 0x10}, //  0 68K code

	{"4play_s1.rom"   , 0x020000, 0xDE828076,	 1}, //  1 Text data

	{"4play_c1.rom"   , 0x020000, 0x7EE8CDCD,    1}, //  2 Sprite data
	{"4play_c2.rom"   , 0x020000, 0x7EE8CDCD,    1}, //  3

	{"4play_m1.rom"   , 0x020000, 0x5132580E, 0x10}, //  4 Z80 code

	{"4play_v1.rom"   , 0x020000, 0x7EE8CDCD,    2}, //  5 Sound data
};

STDROMPICKEXT(fourplay, fourplay, neogeo);
STD_ROM_FN(fourplay);

struct BurnDriverX BurnDrv4play = {
	{"4play", "* 4 player input test", "4 player  input test cartridge", "SNK", "Neo Geo", "???", NULL, "neogeo"},
	BDF_GAME_WORKING, 4, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_4_JOYSTICKS,
	NULL, fourplayRomInfo, fourplayRomName, neodualInputInfo, neodualDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// ----------------------------------------------------------------------------
// Normal Games

// Aicom

// Jyanshin Densetsu - Quest of Jongmaster

static struct BurnRomInfo janshinRomDesc[] = {
	{"048-p1.bin"  , 0x100000, 0x7514cb7a, 0x10}, //  0 68K code

	{"048-s1.bin"  , 0x020000, 0x8285b25a,    1}, //  1 Text layer tiles

	{"048-c1.bin"  , 0x200000, 0x3fa890e9,    1}, //  2 Sprite data
	{"048-c2.bin"  , 0x200000, 0x59c48ad8,    1}, //  3

	{"048-m1.bin"  , 0x010000, 0xe191f955, 0x10}, //  4 Z80 code

	{"048-v1.bin"  , 0x200000, 0xf1947d2b,    2}, //  5 Sound data
};

STDROMPICKEXT(janshin, janshin, neogeo);
STD_ROM_FN(janshin);

struct BurnDriver BurnDrvJanshin = {
	{"janshin", "Jyanshin Densetsu: Quest of Jongmaster", NULL, "Aicom", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_MAHJONG,
	NULL, janshinRomInfo, janshinRomName, neomahjongInputInfo, neomahjongDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Pulstar

static struct BurnRomInfo pulstarRomDesc[] = {
	{"089-p1.bin", 0x100000, 0x5E5847A2, 0x10}, //  0 68K code
	{"089-p2.bin", 0x200000, 0x028B774C, 0x10}, //  1

	{"089-s1.bin", 0x020000, 0xC79FC2C8,    1}, //  2 Text layer tiles

	{"089-c1.bin", 0x400000, 0x63020FC6,    1}, //  3 Sprite data
	{"089-c2.bin", 0x400000, 0x260E9d4D,    1}, //  4
	{"089-c3.bin", 0x400000, 0x21EF41D7,    1}, //  5
	{"089-c4.bin", 0x400000, 0x3B9E288F,    1}, //  6
	{"089-c5.bin", 0x400000, 0x6FE9259C,    1}, //  7
	{"089-c6.bin", 0x400000, 0xDC32F2b4,    1}, //  8
	{"089-c7.bin", 0x200000, 0x6A5618cA,    1}, //  9
	{"089-c8.bin", 0x200000, 0xA223572D,    1}, // 10

	{"089-m1.bin", 0x020000, 0xFF3DF7C7, 0x10}, // 11 Z80 code

	{"089-v1.bin", 0x400000, 0xB458DED2,    2}, // 12	Sound data
	{"089-v2.bin", 0x400000, 0x9D2DB551,    2}, // 13
};

STDROMPICKEXT(pulstar, pulstar, neogeo);
STD_ROM_FN(pulstar);

static int pulstarInit()
{
	nNeoSRAMProtection = 0x035A;
	return NeoInit();
}

struct BurnDriver BurnDrvPulstar = {
	{"pulstar", "Pulstar", NULL, "Aicom", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, pulstarRomInfo, pulstarRomName, neogeoInputInfo, neogeoDIPInfo,
	pulstarInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Alpha Denshi / ADK

// Aggressors of Dark Kombat / Tsuukai GANGAN Koushinkyoku

static struct BurnRomInfo aodkRomDesc[] = {
	{"074-p1.bin"  , 0x200000, 0x62369553, 0x10}, //  0 68K code

	{"074-s1.bin"  , 0x020000, 0x96148D2B,    1}, //  1 Text layer tiles

	{"074-c1.bin"  , 0x200000, 0xA0B39344,    1}, //  2 Sprite data
	{"074-c2.bin"  , 0x200000, 0x203F6074,    1}, //  3
	{"074-c3.bin"  , 0x200000, 0x7FFF4D41,    1}, //  4
	{"074-c4.bin"  , 0x200000, 0x48DB3E0A,    1}, //  5
	{"074-c5.bin"  , 0x200000, 0xC74C5E51,    1}, //  6
	{"074-c6.bin"  , 0x200000, 0x73E8E7E0,    1}, //  7
	{"074-c7.bin"  , 0x200000, 0xAC7DAA01,    1}, //  8
	{"074-c8.bin"  , 0x200000, 0x14E7AD71,    1}, //  9

	{"074-m1.bin"  , 0x020000, 0x5A52A9D1, 0x10}, // 10 Z80 code

	{"074-v1.bin"  , 0x200000, 0x7675B8FA,    2}, // 11 Sound data
	{"074-v2.bin"  , 0x200000, 0xA9DA86E9,    2}, // 12
};

STDROMPICKEXT(aodk, aodk, neogeo);
STD_ROM_FN(aodk);

struct BurnDriver BurnDrvAODK = {
	{"aodk", "Aggressors of Dark Kombat", "Japanese title is Tsuukai GANGAN Koushinkyoku", "ADK / SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, aodkRomInfo, aodkRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Blue's Journey

static struct BurnRomInfo bjourneyRomDesc[] = {
	{"022-p1.bin"  , 0x100000, 0x6A2F6D4A, 0x10}, //  0 68K code

	{"022-s1.bin"  , 0x020000, 0x843C3624,    1}, //  1 Text layer tiles

	{"022-c1.bin"  , 0x100000, 0x4D47A48C,    1}, //  2 Sprite data
	{"022-c2.bin"  , 0x100000, 0xE8C1491A,    1}, //  3
	{"022-c3.bin"  , 0x080000, 0x66E69753,    1}, //  4
	{"022-c4.bin"  , 0x080000, 0x71BFD48A,    1}, //  5

	{"022-m1.bin"  , 0x010000, 0xA9E30496, 0x10}, //  6 Z80 code

	{"022-v1.bin"  , 0x100000, 0x2CB4AD91,    2}, //  7 Sound data
	{"022-v2.bin"  , 0x100000, 0x65A54D13,    2}, //  8
};

STDROMPICKEXT(bjourney, bjourney, neogeo);
STD_ROM_FN(bjourney);

struct BurnDriver BurnDrvBJourney = {
	{"bjourney", "Blue's Journey", "Japanese title is Raguy", "Alpha Denshi Co.", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, bjourneyRomInfo, bjourneyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Crossed Swords

static struct BurnRomInfo crswordRomDesc[] = {
	{"037-p1.bin"  , 0x080000, 0xE7F2553C, 0x10}, //  0 68K code

	{"037-s1.bin"  , 0x020000, 0x74651F27,    1}, //  1 Text layer tiles

	{"037-c1.bin"  , 0x100000, 0x09DF6892,    1}, //  2 Sprite data
	{"037-c2.bin"  , 0x100000, 0xAC122A78,    1}, //  3
	{"037-c3.bin"  , 0x100000, 0x9D7ED1CA,    1}, //  4
	{"037-c4.bin"  , 0x100000, 0x4A24395D,    1}, //  5

	{"037-m1.bin"  , 0x020000, 0x9C384263, 0x10}, //  6 Z80 code

	{"037-v1.bin"  , 0x100000, 0x61FEDF65,    2}, //  7 Sound data
};

STDROMPICKEXT(crsword, crsword, neogeo);
STD_ROM_FN(crsword);

struct BurnDriver BurnDrvCrSword = {
	{"crsword", "Crossed Swords", NULL, "Alpha Denshi Co.", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, crswordRomInfo, crswordRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Magician Lord

static struct BurnRomInfo maglordRomDesc[] = {
	{"005-p1.bin"  , 0x080000, 0xBD0A492D, 0x10}, //  0 68K code

	{"005-s1.bin"  , 0x020000, 0x1C5369A2,    1}, //  1 Text layer tiles

	{"005-c1.bin"  , 0x080000, 0x806AEE34,    1}, //  2 Sprite data
	{"005-c2.bin"  , 0x080000, 0x34AA9A86,    1}, //  3
	{"005-c3.bin"  , 0x080000, 0xC4C2B926,    1}, //  4
	{"005-c4.bin"  , 0x080000, 0x9C46DCF4,    1}, //  5
	{"005-c5.bin"  , 0x080000, 0x69086DEC,    1}, //  6
	{"005-c6.bin"  , 0x080000, 0xAB7AC142,    1}, //  7

	{"005-m1.bin"  , 0x010000, 0x91EE1F73, 0x10}, //  8 Z80 code

	{"005-v11.bin" , 0x080000, 0xCC0455FD,    2}, //  9 Sound data
	{"005-v21.bin" , 0x080000, 0xF94AB5B7,    2}, // 10
	{"005-v22.bin" , 0x080000, 0x232CFD04,    2}, // 11
};

STDROMPICKEXT(maglord, maglord, neogeo);
STD_ROM_FN(maglord);

struct BurnDriver BurnDrvMagLord = {
	{"maglord", "Magician Lord", NULL, "Alpha Denshi Co.", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, maglordRomInfo, maglordRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Magician Lord (set 2)

static struct BurnRomInfo maglordhRomDesc[] = {
	{"005-p1h.bin" , 0x080000, 0x599043C5, 0x10}, //  0 68K code

	{"005-s1.bin"  , 0x020000, 0x1C5369A2,    1}, //  1 Text layer tiles

	{"005-c1.bin"  , 0x080000, 0x806AEE34,    1}, //  2 Sprite data
	{"005-c2.bin"  , 0x080000, 0x34AA9A86,    1}, //  3
	{"005-c3.bin"  , 0x080000, 0xC4C2B926,    1}, //  4
	{"005-c4.bin"  , 0x080000, 0x9C46DCF4,    1}, //  5
	{"005-c5.bin"  , 0x080000, 0x69086DEC,    1}, //  6
	{"005-c6.bin"  , 0x080000, 0xAB7AC142,    1}, //  7

	{"005-m1.bin"  , 0x010000, 0x91EE1F73, 0x10}, //  8 Z80 code

	{"005-v11.bin" , 0x080000, 0xCC0455FD,    2}, //  9 Sound data
	{"005-v21.bin" , 0x080000, 0xF94AB5B7,    2}, // 10
	{"005-v22.bin" , 0x080000, 0x232CFD04,    2}, // 11
};

STDROMPICKEXT(maglordh, maglordh, neogeo);
STD_ROM_FN(maglordh);

struct BurnDriver BurnDrvMagLordh = {
	{"maglordh", "Magician Lord", "Alternate set", "Alpha Denshi Co.", "Neo Geo", "1990", "maglord", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO,
	NULL, maglordhRomInfo, maglordhRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Syougi No Tatsujin - Master of Syougi

static struct BurnRomInfo mosyougiRomDesc[] = {
	{"203-p1.bin"  , 0x100000, 0x7BA70E2D, 0x10}, //  0 68K code

	{"203-s1.bin"  , 0x020000, 0x4E132FAC,    1}, //  1 Text layer tiles

	{"203-c1.bin"  , 0x200000, 0xBBA9E8C0,    1}, //  2 Sprite data
	{"203-c2.bin"  , 0x200000, 0x2574BE03,    1}, //  3

	{"203-m1.bin"  , 0x020000, 0xA602C2C2, 0x10}, //  4 Z80 code

	{"203-v1.bin"  , 0x200000, 0xBAA2B9A5,    2}, //  5 Sound data
};

STDROMPICKEXT(mosyougi, mosyougi, neogeo);
STD_ROM_FN(mosyougi);

struct BurnDriver BurnDrvMOSyougi = {
	{"mosyougi", "Syougi No Tatsujin: Master of Syougi", NULL, "ADK / SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, mosyougiRomInfo, mosyougiRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Ninja Combat

static struct BurnRomInfo ncombatRomDesc[] = {
	{"009-p1.bin"  , 0x080000, 0xB45FCFBF, 0x10}, //  0 68K code

	{"009-s1.bin"  , 0x020000, 0xD49AFEE8,    1}, //  1 Text layer tiles

	{"009-c1.bin"  , 0x080000, 0x33CC838E,    1}, //  2 Sprite data
	{"009-c2.bin"  , 0x080000, 0x26877FEB,    1}, //  3
	{"009-c3.bin"  , 0x080000, 0x3B60A05D,    1}, //  4
	{"009-c4.bin"  , 0x080000, 0x39C2D039,    1}, //  5
	{"009-c5.bin"  , 0x080000, 0x67A4344E,    1}, //  6
	{"009-c6.bin"  , 0x080000, 0x2ECA8B19,    1}, //  7

	{"009-m1.bin"  , 0x020000, 0xB5819863, 0x10}, //  8 Z80 code

	{"009-v11.bin" , 0x080000, 0xCF32A59C,    2}, //  9 Sound data
	{"009-v12.bin" , 0x080000, 0x7B3588B7,    2}, // 10
	{"009-v13.bin" , 0x080000, 0x505A01B5,    2}, // 11
	{"009-v21.bin" , 0x080000, 0x365F9011,    2}, // 12
};

STDROMPICKEXT(ncombat, ncombat, neogeo);
STD_ROM_FN(ncombat);

struct BurnDriver BurnDrvNCombat = {
	{"ncombat", "Ninja Combat", NULL, "Alpha Denshi Co.", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, ncombatRomInfo, ncombatRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Ninja Commando

static struct BurnRomInfo ncommandRomDesc[] = {
	{"050-p1.bin"  , 0x100000, 0x4E097C40, 0x10}, //  0 68K code

	{"050-s1.bin"  , 0x020000, 0xDB8F9C8E,    1}, //  1 Text layer tiles

	{"050-c1.bin"  , 0x100000, 0x87421A0A,    1}, //  2 Sprite data
	{"050-c2.bin"  , 0x100000, 0xC4CF5548,    1}, //  3
	{"050-c3.bin"  , 0x100000, 0x03422C1E,    1}, //  4
	{"050-c4.bin"  , 0x100000, 0x0845EADB,    1}, //  5

	{"050-m1.bin"  , 0x020000, 0x6FCF07D3, 0x10}, //  6 Z80 code

	{"050-v1.bin"  , 0x100000, 0x23C3AB42,    2}, //  7 Sound data
	{"050-v2.bin"  , 0x080000, 0x80B8A984,    2}, //  8
};

STDROMPICKEXT(ncommand, ncommand, neogeo);
STD_ROM_FN(ncommand);

struct BurnDriver BurnDrvNCommand = {
	{"ncommand", "Ninja Commando", NULL, "Alpha Denshi Co.", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, ncommandRomInfo, ncommandRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Ninja Master's

static struct BurnRomInfo ninjamasRomDesc[] = {
	{"217-p1.bin"  , 0x100000, 0x3E97ED69, 0x10}, //  0 68K code
	{"217-p2.bin"  , 0x200000, 0x191FCA88, 0x10}, //  1

	{"217-s1.bin"  , 0x020000, 0x8FF782F0,    1}, //  2 Text layer tiles

	{"217-c1.bin"  , 0x400000, 0x58F91AE0,    1}, //  3 Sprite data
	{"217-c2.bin"  , 0x400000, 0x4258147F,    1}, //  4
	{"217-c3.bin"  , 0x400000, 0x36C29CE3,    1}, //  5
	{"217-c4.bin"  , 0x400000, 0x17E97A6E,    1}, //  6
	{"217-c5.bin"  , 0x400000, 0x4683FFC0,    1}, //  7
	{"217-c6.bin"  , 0x400000, 0xDE004F4A,    1}, //  8
	{"217-c7.bin"  , 0x400000, 0x3E1885C0,    1}, //  9
	{"217-c8.bin"  , 0x400000, 0x5A5DF034,    1}, // 10

	{"217-m1.bin"  , 0x020000, 0xD00FB2AF, 0x10}, // 11 Z80 code

	{"217-v1.bin"  , 0x400000, 0x1C34E013,    2}, // 12 Sound data
	{"217-v2.bin"  , 0x200000, 0x22F1C681,    2}, // 13
};

STDROMPICKEXT(ninjamas, ninjamas, neogeo);
STD_ROM_FN(ninjamas);

struct BurnDriver BurnDrvNinjaMas = {
	{"ninjamas", "Ninja Master's: haoh-ninpo-cho", NULL, "ADK / SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, ninjamasRomInfo, ninjamasRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// OverTop

static struct BurnRomInfo overtopRomDesc[] = {
	{"212-p1.bin"  , 0x200000, 0x16c063a9, 0x10}, //  0 68K code

	{"212-s1.bin"  , 0x020000, 0x481d3ddc,    1}, //  1 Text layer tiles

	{"212-c1.bin"  , 0x400000, 0x50f43087,    1}, //  2 Sprite data
	{"212-c2.bin"  , 0x400000, 0xa5b39807,    1}, //  3
	{"212-c3.bin"  , 0x400000, 0x9252ea02,    1}, //  4
	{"212-c4.bin"  , 0x400000, 0x5f41a699,    1}, //  5
	{"212-c5.bin"  , 0x200000, 0xfc858bef,    1}, //  6
	{"212-c6.bin"  , 0x200000, 0x0589c15e,    1}, //  7

	{"212-m1.bin"  , 0x020000, 0xfcab6191, 0x10}, //  8 Z80 code

	{"212-v1.bin"  , 0x400000, 0x013d4ef9,    2}, //  9 Sound data
};

STDROMPICKEXT(overtop, overtop, neogeo);
STD_ROM_FN(overtop);

struct BurnDriver BurnDrvOvertop = {
	{"overtop", "OverTop", NULL, "ADK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, overtopRomInfo, overtopRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Thrash Rally

static struct BurnRomInfo trallyRomDesc[] = {
	{"038-p1.bin"  , 0x080000, 0x1E52A576, 0x10}, //  0 68K code
	{"038-p2.bin"  , 0x080000, 0xA5193E2F, 0x10}, //  1

	{"038-s1.bin"  , 0x020000, 0xFFF62AE3,    1}, //  2 Text layer tiles

	{"038-c1.bin"  , 0x100000, 0xC58323D4,    1}, //  3 Sprite data
	{"038-c2.bin"  , 0x100000, 0xBBA9C29E,    1}, //  4
	{"038-c3.bin"  , 0x080000, 0x3BB7B9D6,    1}, //  5
	{"038-c4.bin"  , 0x080000, 0xA4513ECF,    1}, //  6

	{"038-m1.bin"  , 0x020000, 0x0908707E, 0x10}, //  7 Z80 code

	{"038-v1.bin"  , 0x100000, 0x5CCD9FD5,    2}, //  8 Sound data
	{"038-v2.bin"  , 0x080000, 0xDDD8D1E6,    2}, //  9
};

STDROMPICKEXT(trally, trally, neogeo);
STD_ROM_FN(trally);

struct BurnDriver BurnDrvTRally = {
	{"trally", "Thrash Rally", NULL, "Alpha Denshi Co.", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, trallyRomInfo, trallyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Twinklestar Sprites

static struct BurnRomInfo twinspriRomDesc[] = {
	{"224-p1.bin"  , 0x200000, 0x7697E445, 0x10}, //  0 68K code

	{"224-s1.bin"  , 0x020000, 0xEEED5758,    1}, //  1 Text layer tiles

	{"224-c1.bin"  , 0x400000, 0x73B2A70B,    1}, //  2 Sprite data
	{"224-c2.bin"  , 0x400000, 0x3A3E506C,    1}, //  3
	{"224-c3.bin"  , 0x100000, 0xC59E4129,    1}, //  4
	{"224-c4.bin"  , 0x100000, 0xB5532E53,    1}, //  5

	{"224-m1.bin"  , 0x020000, 0x364D6F96, 0x10}, //  6 Z80 code

	{"224-v1.bin"  , 0x400000, 0xFF57F088,    2}, //  7 Sound data
	{"224-v2.bin"  , 0x200000, 0x7AD26599,    2}, //  8
};

STDROMPICKEXT(twinspri, twinspri, neogeo);
STD_ROM_FN(twinspri);

struct BurnDriver BurnDrvTwinSpri = {
	{"twinspri", "Twinklestar Sprites", NULL, "ADK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, twinspriRomInfo, twinspriRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// World Heroes

static struct BurnRomInfo wh1RomDesc[] = {
	{"053-p1.bin"  , 0x080000, 0x95B574CB, 0x10}, //  0 68K code
	{"053-p2.bin"  , 0x080000, 0xF198ED45, 0x10}, //  1

	{"053-s1.bin"  , 0x020000, 0x8C2C2D6B,    1}, //  2 Text layer tiles

	{"053-c1.bin"  , 0x200000, 0x85EB5BCE,    1}, //  3 Sprite data
	{"053-c2.bin"  , 0x200000, 0xEC93B048,    1}, //  4
	{"053-c3.bin"  , 0x100000, 0x0DD64965,    1}, //  5
	{"053-c4.bin"  , 0x100000, 0x9270D954,    1}, //  6

	{"053-m1.bin"  , 0x020000, 0x1BD9D04B, 0x10}, //  7 Z80 code

	{"053-v2.bin"  , 0x200000, 0xA68DF485,    2}, //  8 Sound data
	{"053-v4.bin"  , 0x100000, 0x7BEA8F66,    2}, //  9
};

STDROMPICKEXT(wh1, wh1, neogeo);
STD_ROM_FN(wh1);

struct BurnDriver BurnDrvWH1 = {
	{"wh1", "World Heroes", NULL, "Alpha Denshi Co.", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, wh1RomInfo, wh1RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// World Heroes (alternate set)

static struct BurnRomInfo wh1hRomDesc[] = {
	{"053-p1.rom"  , 0x080000, 0xED29FDE2, 0x10}, //  0 68K code
	{"053-p2.rom"  , 0x080000, 0x98F2B158, 0x10}, //  1

	{"053-s1.bin"  , 0x020000, 0x8C2C2D6B,    1}, //  2 Text layer tiles

	{"053-c1.bin"  , 0x200000, 0x85EB5BCE,    1}, //  3 Sprite data
	{"053-c2.bin"  , 0x200000, 0xEC93B048,    1}, //  4
	{"053-c3.bin"  , 0x100000, 0x0DD64965,    1}, //  5
	{"053-c4.bin"  , 0x100000, 0x9270D954,    1}, //  6

	{"053-m1.bin"  , 0x020000, 0x1BD9D04B, 0x10}, //  7 Z80 code

	{"053-v2.bin"  , 0x200000, 0xA68DF485,    2}, //  8 Sound data
	{"053-v4.bin"  , 0x100000, 0x7BEA8F66,    2}, //  9
};

STDROMPICKEXT(wh1h, wh1h, neogeo);
STD_ROM_FN(wh1h);

struct BurnDriver BurnDrvWH1h = {
	{"wh1h", "World Heroes", "Alternate set", "Alpha Denshi Co.", "Neo Geo", "1992", "wh1", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, wh1hRomInfo, wh1hRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// World Heroes 2

static struct BurnRomInfo wh2RomDesc[] = {
	{"057-p1.bin"  , 0x200000, 0x65A891D9, 0x10}, //  0 68K code

	{"057-s1.bin"  , 0x020000, 0xFCAEB3A4,    1}, //  1 Text layer tiles

	{"057-c1.bin"  , 0x200000, 0x21C6BB91,    1}, //  2 Sprite data
	{"057-c2.bin"  , 0x200000, 0xA3999925,    1}, //  3
	{"057-c3.bin"  , 0x200000, 0xB725A219,    1}, //  4
	{"057-c4.bin"  , 0x200000, 0x8D96425E,    1}, //  5
	{"057-c5.bin"  , 0x200000, 0xB20354AF,    1}, //  6
	{"057-c6.bin"  , 0x200000, 0xB13D1DE3,    1}, //  7

	{"057-m1.bin"  , 0x020000, 0x8FA3BC77, 0x10}, //  8 Z80 code

	{"057-v1.bin"  , 0x200000, 0x8877E301,    2}, //  9 Sound data
	{"057-v2.bin"  , 0x200000, 0xC1317FF4,    2}, // 10
};

STDROMPICKEXT(wh2, wh2, neogeo);
STD_ROM_FN(wh2);

struct BurnDriver BurnDrvWH2 = {
	{"wh2", "World Heroes 2", NULL, "ADK", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, wh2RomInfo, wh2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// World Heroes 2 Jet

static struct BurnRomInfo wh2jRomDesc[] = {
	{"064-p1.bin"  , 0x200000, 0x385A2E86, 0x10}, //  0 68K code

	{"064-s1.bin"  , 0x020000, 0x2A03998A,    1}, //  1 Text layer tiles

	{"064-c1.bin"  , 0x200000, 0x2EC87CEA,    1}, //  2 Sprite data
	{"064-c2.bin"  , 0x200000, 0x526B81AB,    1}, //  3
	{"064-c3.bin"  , 0x200000, 0x436D1B31,    1}, //  4
	{"064-c4.bin"  , 0x200000, 0xF9C8DD26,    1}, //  5
	{"064-c5.bin"  , 0x200000, 0x8E34A9F4,    1}, //  6
	{"064-c6.bin"  , 0x200000, 0xA43E4766,    1}, //  7
	{"064-c7.bin"  , 0x200000, 0x59D97215,    1}, //  8
	{"064-c8.bin"  , 0x200000, 0xFC092367,    1}, //  9

	{"064-m1.bin"  , 0x020000, 0xD2EEC9D3, 0x10}, // 10 Z80 code

	{"064-v1.bin"  , 0x200000, 0xAA277109,    2}, // 11 Sound data
	{"064-v2.bin"  , 0x200000, 0xB6527EDD,    2}, // 12
};

STDROMPICKEXT(wh2j, wh2j, neogeo);
STD_ROM_FN(wh2j);

struct BurnDriver BurnDrvWH2J = {
	{"wh2j", "World Heroes 2 Jet", NULL, "ADK / SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, wh2jRomInfo, wh2jRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// World Heroes Perfect

static struct BurnRomInfo whpRomDesc[] = {
	{"090-p1.bin"  , 0x200000, 0xAFAA4702, 0x10}, //  0 68K code

	{"090-s1.bin"  , 0x020000, 0x174A880F,    1}, //  1 Text layer tiles

	{"090-c1.bin"  , 0x400000, 0xAECD5BB1,    1}, //  2 Sprite data
	{"090-c2.bin"  , 0x400000, 0x7566FFC0,    1}, //  3
	{"090-c3.bin"  , 0x200000, 0x436D1B31,    1}, //  4
	{"090-c4.bin"  , 0x200000, 0xF9C8DD26,    1}, //  5
	{"090-c5.bin"  , 0x200000, 0x8E34A9F4,    1}, //  6
	{"090-c6.bin"  , 0x200000, 0xA43E4766,    1}, //  7
	{"090-c7.bin"  , 0x200000, 0x59D97215,    1}, //  8
	{"090-c8.bin"  , 0x200000, 0xFC092367,    1}, //  9

	{"090-m1.bin"  , 0x020000, 0x28065668, 0x10}, // 10 Z80 code

	{"090-v1.bin"  , 0x200000, 0x30CF2709,    2}, // 11 Sound data
	{"090-v2.bin"  , 0x200000, 0xB6527EDD,    2}, // 12
	{"090-v3.bin"  , 0x200000, 0x1908A7CE,    2}, // 13
};

STDROMPICKEXT(whp, whp, neogeo);
STD_ROM_FN(whp);

struct BurnDriver BurnDrvWHP = {
	{"whp", "World Heroes Perfect", NULL, "ADK / SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, whpRomInfo, whpRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Data East Corporation

// Karnov's Revenge

static struct BurnRomInfo karnovrRomDesc[] = {
	{"066-p1.bin"  , 0x100000, 0x8C86FD22, 0x10}, //  0 68K code

	{"066-s1.bin"  , 0x020000, 0xBAE5D5E5,    1}, //  1 Text layer tiles

	{"066-c1.bin"  , 0x200000, 0x09DFE061,    1}, //  2 Sprite data
	{"066-c2.bin"  , 0x200000, 0xE0F6682A,    1}, //  3
	{"066-c3.bin"  , 0x200000, 0xA673B4F7,    1}, //  4
	{"066-c4.bin"  , 0x200000, 0xCB3DC5F4,    1}, //  5
	{"066-c5.bin"  , 0x200000, 0x9A28785D,    1}, //  6
	{"066-c6.bin"  , 0x200000, 0xC15C01ED,    1}, //  7

	{"066-m1.bin"  , 0x020000, 0x030BEAE4, 0x10}, //  8 Z80 code

	{"066-v1.bin"  , 0x200000, 0x0B7EA37A,    2}, //  9 Sound data
};

STDROMPICKEXT(karnovr, karnovr, neogeo);
STD_ROM_FN(karnovr);

struct BurnDriver BurnDrvKarnovR = {
	{"karnovr", "Karnov's Revenge", "Japanse title is Fighter's History Dynamite", "Data East Corporation", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, karnovrRomInfo, karnovrRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Magical Drop II

static struct BurnRomInfo magdrop2RomDesc[] = {
	{"221-p1.bin", 0x080000, 0x7BE82353, 0x10}, //  0 68K code

	{"221-s1.bin", 0x020000, 0x2A4063A3,    1}, //  1 Text layer tiles

	{"221-c1.bin", 0x400000, 0x1F862A14,    1}, //  2 Sprite data
	{"221-c2.bin", 0x400000, 0x14B90536,    1}, //  3

	{"221-m1.bin", 0x020000, 0xBDDAE628, 0x10}, //  4 Z80 code

	{"221-v1.bin", 0x200000, 0x7E5E53E4,    2}, //  5 Sound data
};

STDROMPICKEXT(magdrop2, magdrop2, neogeo);
STD_ROM_FN(magdrop2);

struct BurnDriver BurnDrvMagDrop2 = {
	{"magdrop2", "Magical Drop II", NULL, "Data East Corporation", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, magdrop2RomInfo, magdrop2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Magical Drop III

static struct BurnRomInfo magdrop3RomDesc[] = {
	{"233-p1.bin", 0x100000, 0x931E17FA, 0x10}, //  0 68K code

	{"233-s1.bin", 0x020000, 0x7399E68A,    1}, //  1 Text layer tiles

	{"233-c1.bin", 0x400000, 0x734DB3D6,    1}, //  2 Sprite data
	{"233-c2.bin", 0x400000, 0xD78F50E5,    1}, //  3
	{"233-c3.bin", 0x400000, 0xEC65F472,    1}, //  4
	{"233-c4.bin", 0x400000, 0xF55DDDF3,    1}, //  5

	{"233-m1.bin", 0x020000, 0x5BEAF34E, 0x10}, //  6 Z80 code

	{"233-v1.bin", 0x400000, 0x58839298,    2}, //  7 Sound data
	{"233-v2.bin", 0x080000, 0xD5E30DF4,    2}, //  8
};

STDROMPICKEXT(magdrop3, magdrop3, neogeo);
STD_ROM_FN(magdrop3);

struct BurnDriver BurnDrvMagDrop3 = {
	{"magdrop3", "Magical Drop III", NULL, "Data East Corporation", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, magdrop3RomInfo, magdrop3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Spin Master

static struct BurnRomInfo spinmastRomDesc[] = {
	{"062-p1.bin"  , 0x100000, 0x37ABA1AA, 0x10}, //  0 68K code
	{"062-p2.bin"  , 0x080000, 0x43763AD2, 0x10}, //  1

	{"062-s1.bin"  , 0x020000, 0x289E2BBE,    1}, //  2 Text layer tiles

	{"062-c1.bin"  , 0x100000, 0xA9375AA2,    1}, //  3 Sprite data
	{"062-c2.bin"  , 0x100000, 0x0E73B758,    1}, //  4
	{"062-c3.bin"  , 0x100000, 0xDF51E465,    1}, //  5
	{"062-c4.bin"  , 0x100000, 0x38517E90,    1}, //  6
	{"062-c5.bin"  , 0x100000, 0x7BABD692,    1}, //  7
	{"062-c6.bin"  , 0x100000, 0xCDE5ADE5,    1}, //  8
	{"062-c7.bin"  , 0x100000, 0xBB2FD7C0,    1}, //  9
	{"062-c8.bin"  , 0x100000, 0x8D7BE933,    1}, // 10

	{"062-m1.bin"  , 0x020000, 0x76108B2F, 0x10}, // 11 Z80 code

	{"062-v1.bin"  , 0x100000, 0xCC281AEF,    2}, // 12 Sound data
};

STDROMPICKEXT(spinmast, spinmast, neogeo);
STD_ROM_FN(spinmast);

struct BurnDriver BurnDrvspinmast = {
	{"spinmast", "Spin Master", "Japanese title is Miracle Adventure", "Data East Corporation", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, spinmastRomInfo, spinmastRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Street Hoop / Street Slam / Dunk Dream

static struct BurnRomInfo strhoopRomDesc[] = {
	{"079-p1.bin"  , 0x100000, 0x5E78328E, 0x10}, //  0 68K code

	{"079-s1.bin"  , 0x020000, 0x3AC06665,    1}, //  1 Text layer tiles

	{"079-c1.bin"  , 0x200000, 0x0581C72A,    1}, //  2 Sprite data
	{"079-c2.bin"  , 0x200000, 0x5B9B8FB6,    1}, //  3
	{"079-c3.bin"  , 0x200000, 0xCD65BB62,    1}, //  4
	{"079-c4.bin"  , 0x200000, 0xA4C90213,    1}, //  5

	{"079-m1.bin"  , 0x010000, 0x1A5F08DB, 0x10}, //  6 Z80 code

	{"079-v1.bin"  , 0x200000, 0x718A2400,    2}, //  7 Sound data
	{"079-v2.bin"  , 0x080000, 0xB19884F8,    2}, //  8
};

STDROMPICKEXT(strhoop, strhoop, neogeo);
STD_ROM_FN(strhoop);

struct BurnDriver BurnDrvStrHoop = {
	{"strhoop", "Street Hoop", "US title is Street Slam, Japanese title is Dunk Dream", "Data East Corporation", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, strhoopRomInfo, strhoopRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Windjammers

static struct BurnRomInfo wjammersRomDesc[] = {
	{"065-p1.bin"  , 0x080000, 0xE81E7A31, 0x10}, //  0 68K code

	{"065-s1.bin"  , 0x020000, 0x074B5723,    1}, //  1 Text layer tiles

	{"065-c1.bin"  , 0x100000, 0xC7650204,    1}, //  2 Sprite data
	{"065-c2.bin"  , 0x100000, 0xD9F3E71D,    1}, //  3
	{"065-c3.bin"  , 0x100000, 0x40986386,    1}, //  4
	{"065-c4.bin"  , 0x100000, 0x715E15FF,    1}, //  5

	{"065-m1.bin"  , 0x020000, 0x52C23CFC, 0x10}, //  6 Z80 code

	{"065-v1.bin"  , 0x100000, 0xCE8B3698,    2}, //  7 Sound data
	{"065-v2.bin"  , 0x100000, 0x659F9B96,    2}, //  8
	{"065-v3.bin"  , 0x100000, 0x39F73061,    2}, //  8
	{"065-v4.bin"  , 0x080000, 0x3740EDDE,    2}, //  8
};

STDROMPICKEXT(wjammers, wjammers, neogeo);
STD_ROM_FN(wjammers);

struct BurnDriver BurnDrvWJammers = {
	{"wjammers", "Windjammers", "Japanese title is Flying Power Disc", "Data East Corporation", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, wjammersRomInfo, wjammersRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Eleven

// Nightmare in the Dark

static struct BurnRomInfo nitdRomDesc[] = {
	{"260-p1.bin", 0x080000, 0x61361082, 0x10}, //  0 68K code

	{"260-c1.bin", 0x800000, 0x147B0C7F,    1}, //  1 Sprite data
	{"260-c2.bin", 0x800000, 0xD2B04B0D,    1}, //  2

	{"260-m1.bin", 0x080000, 0x6407C5E5, 0x10}, //  3 Z80 code

	{"260-v1.bin", 0x400000, 0x24B0480C,    2}, //  4 Sound data
};

STDROMPICKEXT(nitd, nitd, neogeo);
STD_ROM_FN(nitd);

static int nitdInit()
{
	nNeoProtectionXor = 0xFF;
	return NeoInit();
}

struct BurnDriver BurnDrvNitD = {
	{"nitd", "Nightmare in the Dark", NULL, "Eleven / Gavaking", "Neo Geo", "2000", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A,
	NULL, nitdRomInfo, nitdRomName, neogeoInputInfo, neogeoDIPInfo,
	nitdInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Face

// Gururin

static struct BurnRomInfo gururinRomDesc[] = {
	{"067-p1.bin"  , 0x080000, 0x4cea8a49, 0x10}, //  0 68K code

	{"067-s1.bin"  , 0x020000, 0x4f0cbd58,    1}, //  1 Text layer tiles

	{"067-c1.bin"  , 0x200000, 0x35866126,    1}, //  2 Sprite data
	{"067-c2.bin"  , 0x200000, 0x9db64084,    1}, //  3

	{"067-m1.bin"  , 0x010000, 0x833cdf1b, 0x10}, //  4 Z80 code

	{"067-v1.bin"  , 0x080000, 0xcf23afd0,    2}, //  5 Sound data
};

STDROMPICKEXT(gururin, gururin, neogeo);
STD_ROM_FN(gururin);

struct BurnDriver BurnDrvGururin = {
	{"gururin", "Gururin", NULL, "Face", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, gururinRomInfo, gururinRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Money Puzzle Exchanger

static struct BurnRomInfo miexchngRomDesc[] = {
	{"231-p1.bin"  , 0x080000, 0x61be1810, 0x10}, //  0 68K code

	{"231-s1.bin"  , 0x020000, 0xfe0c0c53,    1}, //  1 Text layer tiles

	{"231-c1.bin"  , 0x200000, 0x6c403ba3,    1}, //  2 Sprite data
	{"231-c2.bin"  , 0x200000, 0x554bcd9b,    1}, //  3
	{"231-c3.bin"  , 0x080000, 0x14524eb5,    1}, //  4
	{"231-c4.bin"  , 0x080000, 0x1694f171,    1}, //  5

	{"231-m1.bin"  , 0x020000, 0xde41301b, 0x10}, //  6 Z80 code

	{"231-v1.bin"  , 0x400000, 0x113fb898,    2}, //  7 Sound data
};

STDROMPICKEXT(miexchng, miexchng, neogeo);
STD_ROM_FN(miexchng);

struct BurnDriver BurnDrvMiexchng = {
	{"miexchng", "Money Puzzle Exchanger", "Japanese title is Money Idol Exchanger", "Face", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, miexchngRomInfo, miexchngRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Hudson Soft

// Kabuki Klash - Far East of Eden

static struct BurnRomInfo kabukiklRomDesc[] = {
	{"092-p1.bin", 0x200000, 0x28EC9B77, 0x10}, //  0 68K code

	{"092-s1.bin", 0x020000, 0xA3D68EE2,    1}, //  1 Text layer tiles

	{"092-c1.bin", 0x400000, 0x4D896A58,    1}, //  2 Sprite data
	{"092-c2.bin", 0x400000, 0x3CF78A18,    1}, //  3
	{"092-c3.bin", 0x400000, 0x58C454E7,    1}, //  4
	{"092-c4.bin", 0x400000, 0xE1A8AA6A,    1}, //  5

	{"092-m1.bin", 0x020000, 0x91957EF6, 0x10}, //  6 Z80 code

	{"092-v1.bin", 0x200000, 0x69E90596,    2}, //  7 Sound data
	{"092-v2.bin", 0x200000, 0x7ABDB75D,    2}, //  8
	{"092-v3.bin", 0x200000, 0xECCC98D3,    2}, //  9
	{"092-v4.bin", 0x100000, 0xA7C9C949,    2}, // 10
};

STDROMPICKEXT(kabukikl, kabukikl, neogeo);
STD_ROM_FN(kabukikl);

struct BurnDriver BurnDrvKabukiKl = {
	{"kabukikl", "Kabuki Klash: Far East of Eden", "Japanese title is Tengai Makyou Shinden: Far East of Eden", "Hudson Soft", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, kabukiklRomInfo, kabukiklRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Panic Bomber

static struct BurnRomInfo panicbomRomDesc[] = {
	{"073-p1.bin", 0x040000, 0x0b21130d, 0x10}, //  0 68K code

	{"073-s1.bin", 0x020000, 0xb876de7e,    1}, //  1 Text layer tiles

	{"073-c1.bin", 0x100000, 0x8582e1b5,    1}, //  2 Sprite data
	{"073-c2.bin", 0x100000, 0xe15a093b,    1}, //  3

	{"073-m1.bin", 0x020000, 0x3cdf5d88, 0x10}, //  4 Z80 code

	{"073-v1.bin", 0x200000, 0x7fc86d2f,    2}, //  5 Sound data
	{"073-v2.bin", 0x100000, 0x082adfc7,    2}, //  6
};

STDROMPICKEXT(panicbom, panicbom, neogeo);
STD_ROM_FN(panicbom);

struct BurnDriver BurnDrvPanicbom = {
	{"panicbom", "Panic Bomber", NULL, "Hudson Soft", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, panicbomRomInfo, panicbomRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Neo Bomberman

static struct BurnRomInfo neobombeRomDesc[] = {
	{"093-p1.bin", 0x100000, 0xa1a71d0d, 0x10}, //  0 68K code

	{"093-s1.bin", 0x020000, 0x4b3fa119,    1}, //  1 Text layer tiles

	{"093-c1.bin", 0x400000, 0xb90ebed4,    1}, //  2 Sprite data
	{"093-c2.bin", 0x400000, 0x41e62b4f,    1}, //  3
	{"093-c3.bin", 0x080000, 0xe37578c5,    1}, //  4
	{"093-c4.bin", 0x080000, 0x59826783,    1}, //  5

	{"093-m1.bin", 0x020000, 0xe81e780b, 0x10}, //  6 Z80 code

	{"093-v1.bin", 0x400000, 0x43057e99,    2}, //  7 Sound data
	{"093-v2.bin", 0x200000, 0xa92b8b3d,    2}, //  8
};

STDROMPICKEXT(neobombe, neobombe, neogeo);
STD_ROM_FN(neobombe);

struct BurnDriver BurnDrvNeobombe = {
	{"neobombe", "Neo Bomberman", NULL, "Hudson Soft", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPV,
	NULL, neobombeRomInfo, neobombeRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Monolith Corp.

// Minnasanno Okagesamadesu

static struct BurnRomInfo minasanRomDesc[] = {
	{"027-p1.bin", 0x080000, 0xC8381327, 0x10}, //  0 68K code

	{"027-s1.bin", 0x020000, 0xE5824BAA,    1}, //  1 Text layer tiles

	{"027-c1.bin", 0x100000, 0xD0086F94,    1}, //  2 Sprite data
	{"027-c2.bin", 0x100000, 0xDA61F5A6,    1}, //  3
	{"027-c3.bin", 0x100000, 0x08DF1228,    1}, //  4
	{"027-c4.bin", 0x100000, 0x54E87696,    1}, //  5

	{"027-m1.bin", 0x020000, 0xADD5A226, 0x10}, //  6 Z80 code

	{"027-v11.bin", 0x100000, 0x59AD4459,    2}, //  7 Sound data
	{"027-v21.bin", 0x100000, 0xDF5B4EEB,    2}, //  8
};

STDROMPICKEXT(minasan, minasan, neogeo);
STD_ROM_FN(minasan);

struct BurnDriver BurnDrvMinasan = {
	{"minasan", "Minnasanno Okagesamadesu", NULL, "Monolith Corp.", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_MAHJONG,
	NULL, minasanRomInfo, minasanRomName, neomahjongInputInfo, neomahjongDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Bakatonosama Mahjong Manyuki

static struct BurnRomInfo bakatonoRomDesc[] = {
	{"036-p1.bin", 0x080000, 0x1c66b6fa, 0x10}, //  0 68K code

	{"036-s1.bin", 0x020000, 0xf3ef4485,    1}, //  1 Text layer tiles

	{"036-c1.bin", 0x100000, 0xfe7f1010,    1}, //  2 Sprite data
	{"036-c2.bin", 0x100000, 0xbbf003f5,    1}, //  3
	{"036-c3.bin", 0x100000, 0x9ac0708e,    1}, //  4
	{"036-c4.bin", 0x100000, 0xf2577d22,    1}, //  5

	{"036-m1.bin", 0x020000, 0xf1385b96, 0x10}, //  6 Z80 code

	{"036-v1.bin", 0x100000, 0x1c335dce,    2}, //  7 Sound data
	{"036-v2.bin", 0x100000, 0xbbf79342,    2}, //  8
};

STDROMPICKEXT(bakatono, bakatono, neogeo);
STD_ROM_FN(bakatono);

struct BurnDriver BurnDrvBakatono = {
	{"bakatono", "Bakatonosama Mahjong Manyuki", NULL, "Monolith Corp.", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_MAHJONG | HARDWARE_SNK_SWAPC,
	NULL, bakatonoRomInfo, bakatonoRomName, neomahjongInputInfo, neomahjongDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Nazca

// Metal Slug - Super Vehicle-001

static struct BurnRomInfo mslugRomDesc[] = {
	{"201-p1.bin", 0x200000, 0x08D8DAA5, 0x10}, //  0 68K code

	{"201-s1.bin", 0x020000, 0x2F55958D,    1}, //  1 Text layer tiles

	{"201-c1.bin", 0x400000, 0xD00BD152,    1}, //  2 Sprite data
	{"201-c2.bin", 0x400000, 0xDDFF1DEA,    1}, //  3
	{"201-c3.bin", 0x400000, 0xD3D5F9E5,    1}, //  4
	{"201-c4.bin", 0x400000, 0x5AC1D497,    1}, //  5

	{"201-m1.bin", 0x020000, 0xC28B3253, 0x10}, //  6 Z80 code

	{"201-v1.bin", 0x400000, 0x23D22ED1,    2}, //  7 Sound data
	{"201-v2.bin", 0x400000, 0x472CF9DB,    2}, //  8
};

STDROMPICKEXT(mslug, mslug, neogeo);
STD_ROM_FN(mslug);

struct BurnDriver BurnDrvMSlug = {
	{"mslug", "Metal Slug: Super Vehicle-001", NULL, "Nazca", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, mslugRomInfo, mslugRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Neo Turf Masters

static struct BurnRomInfo turfmastRomDesc[] = {
	{"200-p1.bin"  , 0x200000, 0x28C83048, 0x10}, //  0 68K code

	{"200-s1.bin"  , 0x020000, 0x9A5402B2,    1}, //  3 Text layer tiles

	{"200-c1.bin"  , 0x400000, 0x8C6733F2,    1}, //  4 Sprite data
	{"200-c2.bin"  , 0x400000, 0x596CC256,    1}, //  5

	{"200-m1.bin"  , 0x020000, 0x9994AC00, 0x10}, // 10 Z80 code

	{"200-v1.bin"  , 0x200000, 0x00FD48D2,    2}, // 11	Sound data
	{"200-v2.bin"  , 0x200000, 0x082ACB31,    2}, // 12
	{"200-v3.bin"  , 0x200000, 0x7ABCA053,    2}, // 13
	{"200-v4.bin"  , 0x200000, 0x6C7B4902,    2}, // 14
};

STDROMPICKEXT(turfmast, turfmast, neogeo);
STD_ROM_FN(turfmast);

struct BurnDriver BurnDrvTurfmast = {
	{"turfmast", "Neo Turf Masters", "Japanese title is Big Tournament Golf", "Nazca", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, turfmastRomInfo, turfmastRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// NMK

// Zed Blade

static struct BurnRomInfo zedbladeRomDesc[] = {
	{"076-p1.bin"  , 0x080000, 0xd7c1effd, 0x10}, //  0 68K code

	{"076-s1.bin"  , 0x020000, 0xf4c25dd5,    1}, //  1 Text layer tiles

	{"076-c1.bin"  , 0x200000, 0x4d9cb038,    1}, //  2 Sprite data
	{"076-c2.bin"  , 0x200000, 0x09233884,    1}, //  3
	{"076-c3.bin"  , 0x200000, 0xd06431e3,    1}, //  4
	{"076-c4.bin"  , 0x200000, 0x4b1c089b,    1}, //  5

	{"076-m1.bin"  , 0x020000, 0x7b5f3d0a, 0x10}, //  6 Z80 code

	{"076-v1.bin"  , 0x200000, 0x1a21d90c,    2}, //  7	Sound data
	{"076-v2.bin"  , 0x200000, 0xb61686c3,    2}, //  8
	{"076-v3.bin"  , 0x100000, 0xb90658fa,    2}, //  9
};

STDROMPICKEXT(zedblade, zedblade, neogeo);
STD_ROM_FN(zedblade);

struct BurnDriver BurnDrvZedblade = {
	{"zedblade", "Zed Blade", "Japanese title is Operation Ragnarok", "NMK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, zedbladeRomInfo, zedbladeRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Psikyo

// Strikers 1945 plus

static struct BurnRomInfo s1945pRomDesc[] = {
	{"254-p1.bin", 0x100000, 0xFF8EFCFF, 0x10}, //  0 68K code
	{"254-p2.bin", 0x400000, 0xEFDFD4DD, 0x10}, //  1

	{"254-c1.bin", 0x800000, 0xAE6FC8EF,    1}, //  2 Sprite data
	{"254-c2.bin", 0x800000, 0x436FA176,    1}, //  3
	{"254-c3.bin", 0x800000, 0xE53FF2DC,    1}, //  4
	{"254-c4.bin", 0x800000, 0x818672F0,    1}, //  5
	{"254-c5.bin", 0x800000, 0x4580EACD,    1}, //  6
	{"254-c6.bin", 0x800000, 0xE34970FC,    1}, //  7
	{"254-c7.bin", 0x800000, 0xF2323239,    1}, //  8
	{"254-c8.bin", 0x800000, 0x66848C7D,    1}, //  9

	{"254-m1.bin", 0x020000, 0x994B4487, 0x10}, // 10 Z80 code

	{"254-v1.bin", 0x400000, 0x844F58FB,    2}, // 11 Sound data
	{"254-v2.bin", 0x400000, 0xD9A248F0,    2}, // 12
	{"254-v3.bin", 0x400000, 0x0B0D2D33,    2}, // 13
	{"254-v4.bin", 0x400000, 0x6D13DC91,    2}, // 14
};

STDROMPICKEXT(s1945p, s1945p, neogeo);
STD_ROM_FN(s1945p);

static int s1945pInit()
{
	nNeoProtectionXor = 0x05;
	return NeoInit();
}

struct BurnDriver BurnDrvs1945p = {
	{"s1945p", "Strikers 1945 plus", NULL, "Psikyo", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SWAPC,
	NULL, s1945pRomInfo, s1945pRomName, neogeoInputInfo, neogeoDIPInfo,
	s1945pInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Saurus

// Operation Ragnagard

static struct BurnRomInfo ragnagrdRomDesc[] = {
	{"218-p1.bin", 0x200000, 0xCA372303, 0x10}, //  0 68K code

	{"218-s1.bin", 0x020000, 0x7D402F9A,    1}, //  1 Text layer tiles

	{"218-c1.bin", 0x400000, 0x18F61D79,    1}, //  2 Sprite data
	{"218-c2.bin", 0x400000, 0xDBF4FF4B,    1}, //  3
	{"218-c3.bin", 0x400000, 0x108D5589,    1}, //  4
	{"218-c4.bin", 0x400000, 0x7962D5AC,    1}, //  5
	{"218-c5.bin", 0x400000, 0x4B74021A,    1}, //  6
	{"218-c6.bin", 0x400000, 0xF5CF90BC,    1}, //  7
	{"218-c7.bin", 0x400000, 0x32189762,    1}, //  8
	{"218-c8.bin", 0x400000, 0xD5915828,    1}, //  9

	{"218-m1.bin", 0x020000, 0x17028BCF, 0x10}, // 10 Z80 code

	{"218-v1.bin", 0x400000, 0x61EEE7F4,    2}, // 11 Sound data
	{"218-v2.bin", 0x400000, 0x6104E20B,    2}, // 12
};

STDROMPICKEXT(ragnagrd, ragnagrd, neogeo);
STD_ROM_FN(ragnagrd);

struct BurnDriver BurnDrvragnagrd = {
	{"ragnagrd", "Operation Ragnagard", "Japanese title is Shin-Oh-Ken", "Saurus", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPP,
	NULL, ragnagrdRomInfo, ragnagrdRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Pleasure Goal

static struct BurnRomInfo pgoalRomDesc[] = {
	{"219-p1.bin"  , 0x200000, 0x6af0e574, 0x10}, //  0 68K code

	{"219-s1.bin"  , 0x020000, 0x002f3c88,    1}, //  1 Text layer tiles

	{"219-c1.bin"  , 0x200000, 0x2dc69faf,    1}, //  2 Sprite data
	{"219-c2.bin"  , 0x200000, 0x5db81811,    1}, //  3
	{"219-c3.bin"  , 0x200000, 0x9dbfece5,    1}, //  4
	{"219-c4.bin"  , 0x200000, 0xc9f4324c,    1}, //  5
	{"219-c5.bin"  , 0x200000, 0x5fdad0a5,    1}, //  6
	{"219-c6.bin"  , 0x200000, 0xf57b4a1c,    1}, //  7

	{"219-m1.bin"  , 0x020000, 0x958efdc8, 0x10}, //  8 Z80 code

	{"219-v1.bin"  , 0x200000, 0x2cc1bd05,    2}, //  9 Sound data
	{"219-v2.bin"  , 0x200000, 0x06ac1d3f,    2}, //  10
};

STDROMPICKEXT(pgoal, pgoal, neogeo);
STD_ROM_FN(pgoal);

struct BurnDriver BurnDrvPgoal = {
	{"pgoal", "Pleasure Goal: 5 on 5 Mini Soccer", "Japanese title is Futsal: 5 on 5 Mini Soccer", "Saurus", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, pgoalRomInfo, pgoalRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Quiz King of Fighters

static struct BurnRomInfo quizkofRomDesc[] = {
	{"080-p1.bin"  , 0x100000, 0x4440315e, 0x10}, //  0 68K code

	{"080-s1.bin"  , 0x020000, 0xd7b86102,    1}, //  1 Text layer tiles

	{"080-c1.bin"  , 0x200000, 0xea1d764a,    1}, //  2 Sprite data
	{"080-c2.bin"  , 0x200000, 0xc78c49da,    1}, //  3
	{"080-c3.bin"  , 0x200000, 0xb4851bfe,    1}, //  4
	{"080-c4.bin"  , 0x200000, 0xca6f5460,    1}, //  5

	{"080-m1.bin"  , 0x020000, 0xf5f44172, 0x10}, //  6 Z80 code

	{"080-v1.bin"  , 0x200000, 0x0be18f60,    2}, //  7 Sound data
	{"080-v2.bin"  , 0x200000, 0x4abde3ff,    2}, //  8
	{"080-v3.bin"  , 0x200000, 0xf02844e2,    2}, //  9
};

STDROMPICKEXT(quizkof, quizkof, neogeo);
STD_ROM_FN(quizkof);

struct BurnDriver BurnDrvQuizkof = {
	{"quizkof", "Quiz King of Fighters", NULL, "Saurus", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, quizkofRomInfo, quizkofRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Shock Troopers

static struct BurnRomInfo shocktroRomDesc[] = {
	{"238-p1.bin", 0x100000, 0x5677456F, 0x10}, //  0 68K code
	{"238-p2.bin", 0x400000, 0x646F6C76, 0x10}, //  1

	{"238-s1.bin", 0x020000, 0x1F95CEDB,    1}, //  2 Text layer tiles

	{"238-c1.bin", 0x400000, 0xAAD087FC,    1}, //  3 Sprite data
	{"238-c2.bin", 0x400000, 0x7E39DF1F,    1}, //  4
	{"238-c3.bin", 0x400000, 0x6682A458,    1}, //  5
	{"238-c4.bin", 0x400000, 0xCBEF1F17,    1}, //  6
	{"238-c5.bin", 0x400000, 0xE17762b1,    1}, //  7
	{"238-c6.bin", 0x400000, 0x28BEAB71,    1}, //  8
	{"238-c7.bin", 0x400000, 0xA47E62d2,    1}, //  9
	{"238-c8.bin", 0x400000, 0xE8E890FB,    1}, // 10

	{"238-m1.bin", 0x020000, 0x075B9518, 0x10}, // 11 Z80 code

	{"238-v1.bin", 0x400000, 0x260C0BEF,    2}, // 12 Sound data
	{"238-v2.bin", 0x200000, 0x4AD7D59E,    2}, // 13
};

STDROMPICKEXT(shocktro, shocktro, neogeo);
STD_ROM_FN(shocktro);

struct BurnDriver BurnDrvshocktro = {
	{"shocktro", "Shock Troopers", NULL, "Saurus", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPP,
	NULL, shocktroRomInfo, shocktroRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Shock Troopers (Alternate version)

static struct BurnRomInfo shocktraRomDesc[] = {
	{"238-pg1.p1", 0x100000, 0xefedf8dc, 0x10}, //  0 68K code
	{"238-p2.bin", 0x400000, 0x646F6C76, 0x10}, //  1

	{"238-s1.bin", 0x020000, 0x1F95CEDB,    1}, //  2 Text layer tiles

	{"238-c1.bin", 0x400000, 0xAAD087FC,    1}, //  3 Sprite data
	{"238-c2.bin", 0x400000, 0x7E39DF1F,    1}, //  4
	{"238-c3.bin", 0x400000, 0x6682A458,    1}, //  5
	{"238-c4.bin", 0x400000, 0xCBEF1F17,    1}, //  6
	{"238-c5.bin", 0x400000, 0xE17762b1,    1}, //  7
	{"238-c6.bin", 0x400000, 0x28BEAB71,    1}, //  8
	{"238-c7.bin", 0x400000, 0xA47E62d2,    1}, //  9
	{"238-c8.bin", 0x400000, 0xE8E890FB,    1}, // 10

	{"238-m1.bin", 0x020000, 0x075B9518, 0x10}, // 11 Z80 code

	{"238-v1.bin", 0x400000, 0x260C0BEF,    2}, // 12 Sound data
	{"238-v2.bin", 0x200000, 0x4AD7D59E,    2}, // 13
};

STDROMPICKEXT(shocktra, shocktra, neogeo);
STD_ROM_FN(shocktra);

struct BurnDriver BurnDrvShocktra = {
	{"shocktra", "Shock Troopers", "Alternate version", "Saurus", "Neo Geo", "1997", "shocktro", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, shocktraRomInfo, shocktraRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Shock Troopers: 2nd Squad

static struct BurnRomInfo shocktr2RomDesc[] = {
	{"246-p1.bin", 0x100000, 0x6D4B7781, 0x10}, //  0 68K code
	{"246-p2.bin", 0x400000, 0x72EA04C3, 0x10}, //  1

	{"246-s1.bin", 0x020000, 0x2A360637,    1}, //  2 Text layer tiles

	{"246-c1.bin", 0x800000, 0x47AC9EC5,    1}, //  3 Sprite data
	{"246-c2.bin", 0x800000, 0x7bCAB64F,    1}, //  4
	{"246-c3.bin", 0x800000, 0xDB2F73E8,    1}, //  5
	{"246-c4.bin", 0x800000, 0x5503854E,    1}, //  6
	{"246-c5.bin", 0x800000, 0x055B3701,    1}, //  7
	{"246-c6.bin", 0x800000, 0x7E2CAAE1,    1}, //  8

	{"246-m1.bin", 0x020000, 0xD0604AD1, 0x10}, //  9 Z80 code

	{"246-v1.bin", 0x400000, 0x16986FC6,    2}, // 10 Sound data
	{"246-v2.bin", 0x400000, 0xADA41E83,    2}, // 11
	{"246-v3.bin", 0x200000, 0xA05BA5DB,    2}, // 12
};

STDROMPICKEXT(shocktr2, shocktr2, neogeo);
STD_ROM_FN(shocktr2);

struct BurnDriver BurnDrvshocktr2 = {
	{"shocktr2", "Shock Troopers: 2nd Squad", NULL, "Saurus", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, shocktr2RomInfo, shocktr2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Stakes Winner

static struct BurnRomInfo stakwinRomDesc[] = {
	{"088-p1.bin"  , 0x200000, 0xbd5814f6, 0x10}, //  0 68K code

	{"088-s1.bin"  , 0x020000, 0x073cb208,    1}, //  1 Text layer tiles

	{"088-c1.bin"  , 0x200000, 0x6e733421,    1}, //  2 Sprite data
	{"088-c2.bin"  , 0x200000, 0x4d865347,    1}, //  3
	{"088-c3.bin"  , 0x200000, 0x8fa5a9eb,    1}, //  4
	{"088-c4.bin"  , 0x200000, 0x4604f0dc,    1}, //  5

	{"088-m1.bin"  , 0x020000, 0x2fe1f499, 0x10}, //  6 Z80 code

	{"088-v1.bin"  , 0x200000, 0xb7785023,    2}, //  7 Sound data
};

STDROMPICKEXT(stakwin, stakwin, neogeo);
STD_ROM_FN(stakwin);

struct BurnDriver BurnDrvStakwin = {
	{"stakwin", "Stakes Winner", "Japanese title is Stakes Winner: GI kinzen seihae no michi", "Saurus", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, stakwinRomInfo, stakwinRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Stakes Winner 2

static struct BurnRomInfo stakwin2RomDesc[] = {
	{"227-p1.bin"  , 0x200000, 0xdaf101d2, 0x10}, //  0 68K code

	{"227-s1.bin"  , 0x020000, 0x2a8c4462,    1}, //  1 Text layer tiles

	{"227-c1.bin"  , 0x400000, 0x7d6c2af4,    1}, //  2 Sprite data
	{"227-c2.bin"  , 0x400000, 0x7e402d39,    1}, //  3
	{"227-c3.bin"  , 0x200000, 0x93dfd660,    1}, //  4
	{"227-c4.bin"  , 0x200000, 0x7efea43a,    1}, //  5

	{"227-m1.bin"  , 0x020000, 0xc8e5e0f9, 0x10}, //  6 Z80 code

	{"227-v1.bin"  , 0x400000, 0xb8f24181,    2}, //  7 Sound data
	{"227-v2.bin"  , 0x400000, 0xee39e260,    2}, //  8
};

STDROMPICKEXT(stakwin2, stakwin2, neogeo);
STD_ROM_FN(stakwin2);

struct BurnDriver BurnDrvStakwin2 = {
	{"stakwin2", "Stakes Winner 2", NULL, "Saurus", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, stakwin2RomInfo, stakwin2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// SNK

// 2020 Super Baseball

static struct BurnRomInfo bb2020RomDesc[] = {
	{"030-p1.bin"   , 0x080000, 0xd396c9cb, 0x10}, //  0 68K code

	{"030-s1.bin"   , 0x020000, 0x7015b8fc,    1}, //  1 Text layer tiles

	{"030-c1.bin"   , 0x100000, 0x4f5e19bd,    1}, //  2 Sprite data
	{"030-c2.bin"   , 0x100000, 0xd6314bf0,    1}, //  3
	{"030-c3.bin"   , 0x080000, 0x6a87ae30,    1}, //  4
	{"030-c4.bin"   , 0x080000, 0xbef75dd0,    1}, //  5

	{"030-m1.bin"   , 0x020000, 0x4cf466ec, 0x10}, //  6 Z80 code

	{"030-v1.bin"   , 0x100000, 0xd4ca364e,    2}, //  7 Sound data
	{"030-v2.bin"   , 0x100000, 0x54994455,    2}, //  8
};

STDROMPICKEXT(bb2020, bb2020, neogeo);
STD_ROM_FN(bb2020);

struct BurnDriver BurnDrvbb2020 = {
	{"2020bb", "2020 Super Baseball", NULL, "SNK / Pallas", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, bb2020RomInfo, bb2020RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// 2020 Super Baseball (set 2)

static struct BurnRomInfo bbh2020RomDesc[] = {
	{"030-p1h.bin"  , 0x080000, 0x12d048d7, 0x10}, //  0 68K code

	{"030-s1.bin"   , 0x020000, 0x7015b8fc,    1}, //  1 Text layer tiles

	{"030-c1.bin"   , 0x100000, 0x4f5e19bd,    1}, //  2 Sprite data
	{"030-c2.bin"   , 0x100000, 0xd6314bf0,    1}, //  3
	{"030-c3.bin"   , 0x080000, 0x6a87ae30,    1}, //  4
	{"030-c4.bin"   , 0x080000, 0xbef75dd0,    1}, //  5

	{"030-m1.bin"   , 0x020000, 0x4cf466ec, 0x10}, //  6 Z80 code

	{"030-v1.bin"   , 0x100000, 0xd4ca364e,    2}, //  7 Sound data
	{"030-v2.bin"   , 0x100000, 0x54994455,    2}, //  8
};

STDROMPICKEXT(bbh2020, bbh2020, neogeo);
STD_ROM_FN(bbh2020);

struct BurnDriver BurnDrvbbh2020 = {
	{"2020bbh", "2020 Super Baseball", "Alternate set", "SNK / Pallas", "Neo Geo", "1991", "2020bb", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, bbh2020RomInfo, bbh2020RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// 3 Count Bout

static struct BurnRomInfo countb3RomDesc[] = {
	{"043-p1.bin"   , 0x080000, 0xeb2714c4, 0x10}, //  0 68K code
	{"043-p2.bin"   , 0x080000, 0x5e764567, 0x10}, //  1

	{"043-s1.bin"   , 0x020000, 0xc362d484,    1}, //  2 Text layer tiles

	{"043-c1.bin"   , 0x200000, 0xd290cc33,    1}, //  3 Sprite data
	{"043-c2.bin"   , 0x200000, 0x0b28095d,    1}, //  4
	{"043-c3.bin"   , 0x200000, 0xbcc0cb35,    1}, //  5
	{"043-c4.bin"   , 0x200000, 0x4d1ff7b9,    1}, //  6

	{"043-m1.bin"   , 0x020000, 0x3377cda3, 0x10}, //  7 Z80 code

	{"043-v1.bin"   , 0x200000, 0x63688ce8,    2}, //  8 Sound data
	{"043-v2.bin"   , 0x200000, 0xc69a827b,    2}, //  9
};

STDROMPICKEXT(countb3, countb3, neogeo);
STD_ROM_FN(countb3);

struct BurnDriver BurnDrv3Countb = {
	{"3countb", "3 Count Bout", "Japanese title is Fire Suplex", "SNK", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, countb3RomInfo, countb3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Alpha Mission II

static struct BurnRomInfo alpham2RomDesc[] = {
	{"007-p1.bin"   , 0x080000, 0x5b266f47, 0x10}, //  0 68K code
	{"007-p2.bin"   , 0x020000, 0xeb9c1044, 0x10}, //  1

	{"007-s1.bin"   , 0x020000, 0x85ec9acf,    1}, //  2 Text layer tiles

	{"007-c1.bin"   , 0x100000, 0x8fba8ff3,    1}, //  3 Sprite data
	{"007-c2.bin"   , 0x100000, 0x4dad2945,    1}, //  4
	{"007-c3.bin"   , 0x080000, 0x68c2994e,    1}, //  5
	{"007-c4.bin"   , 0x080000, 0x7d588349,    1}, //  6

	{"007-m1.bin"   , 0x020000, 0x28dfe2cd, 0x10}, //  7 Z80 code

	{"007-v1.bin"   , 0x100000, 0xcd5db931,    2}, //  8 Sound data
	{"007-v2.bin"   , 0x100000, 0x63e9b574,    2}, //  9
};

STDROMPICKEXT(alpham2, alpham2, neogeo);
STD_ROM_FN(alpham2);

struct BurnDriver BurnDrvAlpham2 = {
	{"alpham2", "Alpha Mission II", "Japanese title is ASO II: Last Guardian", "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, alpham2RomInfo, alpham2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Art of Fighting

static struct BurnRomInfo aofRomDesc[] = {
	{"044-p1.bin"   , 0x080000, 0xca9f7a6d, 0x10}, //  0 68K code

	{"044-s1.bin"   , 0x020000, 0x89903f39,    1}, //  1 Text layer tiles

	{"044-c1.bin"   , 0x200000, 0xddab98a7,    1}, //  2 Sprite data
	{"044-c2.bin"   , 0x200000, 0xd8ccd575,    1}, //  3
	{"044-c3.bin"   , 0x200000, 0x403e898a,    1}, //  4
	{"044-c4.bin"   , 0x200000, 0x6235fbaa,    1}, //  5

	{"044-m1.bin"   , 0x020000, 0x981345f8, 0x10}, //  6 Z80 code

	{"044-v2.bin"   , 0x200000, 0x3ec632ea,    2}, //  7 Sound data
	{"044-v4.bin"   , 0x200000, 0x4b0f8e23,    2}, //  8
};

STDROMPICKEXT(aof, aof, neogeo);
STD_ROM_FN(aof);

struct BurnDriver BurnDrvAof = {
	{"aof", "Art of Fighting", "Japanese title is Ryuuko no Ken", "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, aofRomInfo, aofRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Art of Fighting 2

static struct BurnRomInfo aof2RomDesc[] = {
	{"056-p1.bin"   , 0x100000, 0xa3b1d021, 0x10}, //  0 68K code

	{"056-s1.bin"   , 0x020000, 0x8b02638e,    1}, //  1 Text layer tiles

	{"056-c1.bin"   , 0x200000, 0x17b9cbd2,    1}, //  2 Sprite data
	{"056-c2.bin"   , 0x200000, 0x5fd76b67,    1}, //  3
	{"056-c3.bin"   , 0x200000, 0xd2c88768,    1}, //  4
	{"056-c4.bin"   , 0x200000, 0xdb39b883,    1}, //  5
	{"056-c5.bin"   , 0x200000, 0xc3074137,    1}, //  6
	{"056-c6.bin"   , 0x200000, 0x31de68d3,    1}, //  7
	{"056-c7.bin"   , 0x200000, 0x3f36df57,    1}, //  8
	{"056-c8.bin"   , 0x200000, 0xe546d7a8,    1}, //  9

	{"056-m1.bin"   , 0x020000, 0xf27e9d52, 0x10}, // 10 Z80 code

	{"056-v1.bin"   , 0x200000, 0x4628fde0,    2}, // 11 Sound data
	{"056-v2.bin"   , 0x200000, 0xb710e2f2,    2}, // 12
	{"056-v3.bin"   , 0x100000, 0xd168c301,    2}, // 13
};

STDROMPICKEXT(aof2, aof2, neogeo);
STD_ROM_FN(aof2);

struct BurnDriver BurnDrvAof2 = {
	{"aof2", "Art of Fighting 2", "Japanese title is Ryuuko no Ken 2", "SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, aof2RomInfo, aof2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Art of Fighting 3: The Path of the Warrior

static struct BurnRomInfo aof3RomDesc[] = {
	{"096-p1.bin"   , 0x100000, 0x9edb420d, 0x10}, //  0 68K code
	{"096-p2.bin"   , 0x200000, 0x4d5a2602, 0x10}, //  1

	{"096-s1.bin"   , 0x020000, 0xcc7fd344,    1}, //  2 Text layer tiles

	{"096-c1.bin"   , 0x400000, 0xf6c74731,    1}, //  3 Sprite data
	{"096-c2.bin"   , 0x400000, 0xf587f149,    1}, //  4
	{"096-c3.bin"   , 0x400000, 0x7749f5e6,    1}, //  5
	{"096-c4.bin"   , 0x400000, 0xcbd58369,    1}, //  6
	{"096-c5.bin"   , 0x400000, 0x1718bdcd,    1}, //  7
	{"096-c6.bin"   , 0x400000, 0x4fca967f,    1}, //  8
	{"096-c7.bin"   , 0x200000, 0x51bd8ab2,    1}, //  9
	{"096-c8.bin"   , 0x200000, 0x9a34f99c,    1}, // 10

	{"096-m1.bin"   , 0x020000, 0xcb07b659, 0x10}, // 11 Z80 code

	{"096-v1.bin"   , 0x200000, 0xe2c32074,    2}, // 12 Sound data
	{"096-v2.bin"   , 0x200000, 0xa290eee7,    2}, // 13
	{"096-v3.bin"   , 0x200000, 0x199d12ea,    2}, // 13
};

STDROMPICKEXT(aof3, aof3, neogeo);
STD_ROM_FN(aof3);

struct BurnDriver BurnDrvAof3 = {
	{"aof3", "Art of Fighting 3: The Path of the Warrior", "Japanese title is Art of Fighting: Ryuuko no Ken Gaiden", "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, aof3RomInfo, aof3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Baseball Stars Professional

static struct BurnRomInfo bstarsRomDesc[] = {
	{"002-p1.bin"   , 0x080000, 0x3bc7790e, 0x10}, //  0 68K code

	{"002-s1.bin"   , 0x020000, 0x1a7fd0c6,    1}, //  1 Text layer tiles

	{"002-c1.bin"   , 0x080000, 0xaaff2a45,    1}, //  2 Sprite data
	{"002-c2.bin"   , 0x080000, 0x3ba0f7e4,    1}, //  3
	{"002-c3.bin"   , 0x080000, 0x96f0fdfa,    1}, //  4
	{"002-c4.bin"   , 0x080000, 0x5fd87f2f,    1}, //  5
	{"002-c5.bin"   , 0x080000, 0x807ed83b,    1}, //  6
	{"002-c6.bin"   , 0x080000, 0x5a3cad41,    1}, //  7

	{"002-m1.bin"   , 0x010000, 0x79a8f4c2, 0x10}, //  8 Z80 code

	{"002-v11.bin"  , 0x080000, 0xb7b925bd,    2}, //  9 Sound data
	{"002-v12.bin"  , 0x080000, 0x329f26fc,    2}, // 10
	{"002-v13.bin"  , 0x080000, 0x0c39f3c8,    2}, // 11
	{"002-v14.bin"  , 0x080000, 0xc7e11c38,    2}, // 12
	{"002-v21.bin"  , 0x080000, 0x04a733d1,    2}, // 13
};

STDROMPICKEXT(bstars, bstars, neogeo);
STD_ROM_FN(bstars);

struct BurnDriver BurnDrvBstars = {
	{"bstars", "Baseball Stars Professional", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, bstarsRomInfo, bstarsRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Baseball Stars 2

static struct BurnRomInfo bstars2RomDesc[] = {
	{"041-p1.bin"  , 0x080000, 0x523567fd, 0x10}, //  0 68K code

	{"041-s1.bin"  , 0x020000, 0x015c5c94,    1}, //  1 Text layer tiles

	{"041-c1.bin"  , 0x100000, 0xb39a12e1,    1}, //  2 Sprite data
	{"041-c2.bin"  , 0x100000, 0x766cfc2f,    1}, //  3
	{"041-c3.bin"  , 0x100000, 0xfb31339d,    1}, //  4
	{"041-c4.bin"  , 0x100000, 0x70457a0c,    1}, //  5

	{"041-m1.bin"  , 0x010000, 0xb2611c03, 0x10}, //  6 Z80 code

	{"041-v1.bin"  , 0x100000, 0xcb1da093,    2}, //  7 Sound data
	{"041-v2.bin"  , 0x100000, 0x1c954a9d,    2}, //  8
	{"041-v3.bin"  , 0x080000, 0xafaa0180,    2}, //  9
};

STDROMPICKEXT(bstars2, bstars2, neogeo);
STD_ROM_FN(bstars2);

struct BurnDriver BurnDrvBstars2 = {
	{"bstars2", "Baseball Stars 2", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_NEOGEO,
	NULL, bstars2RomInfo, bstars2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Burning Fight

static struct BurnRomInfo burningfRomDesc[] = {
	{"018-p1.bin"   , 0x080000, 0x4092c8db, 0x10}, //  0 68K code

	{"018-s1.bin"   , 0x020000, 0x6799ea0d,    1}, //  1 Text layer tiles

	{"018-c1.bin"   , 0x100000, 0x25a25e9b,    1}, //  2 Sprite data
	{"018-c2.bin"   , 0x100000, 0xd4378876,    1}, //  3
	{"018-c3.bin"   , 0x100000, 0x862b60da,    1}, //  4
	{"018-c4.bin"   , 0x100000, 0xe2e0aff7,    1}, //  5

	{"018-m1.bin"   , 0x020000, 0x0c939ee2, 0x10}, //  6 Z80 code

	{"018-v1.bin"   , 0x100000, 0x508c9ffc,    2}, //  7 Sound data
	{"018-v2.bin"   , 0x100000, 0x854ef277,    2}, //  8
};

STDROMPICKEXT(burningf, burningf, neogeo);
STD_ROM_FN(burningf);

struct BurnDriver BurnDrvBurningf = {
	{"burningf", "Burning Fight", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, burningfRomInfo, burningfRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Burning Fight (set 2)

static struct BurnRomInfo burninghRomDesc[] = {
	{"018-p1h.bin"  , 0x080000, 0xddffcbf4, 0x10}, //  0 68K code

	{"018-s1.bin"   , 0x020000, 0x6799ea0d,    1}, //  1 Text layer tiles

	{"018-c1.bin"   , 0x100000, 0x25a25e9b,    1}, //  2 Sprite data
	{"018-c2.bin"   , 0x100000, 0xd4378876,    1}, //  3
	{"018-c3.bin"   , 0x100000, 0x862b60da,    1}, //  4
	{"018-c4.bin"   , 0x100000, 0xe2e0aff7,    1}, //  5

	{"018-m1.bin"   , 0x020000, 0x0c939ee2, 0x10}, //  6 Z80 code

	{"018-v1.bin"   , 0x100000, 0x508c9ffc,    2}, //  7 Sound data
	{"018-v2.bin"   , 0x100000, 0x854ef277,    2}, //  8
};

STDROMPICKEXT(burningh, burningh, neogeo);
STD_ROM_FN(burningh);

struct BurnDriver BurnDrvBurningh = {
	{"burningh", "Burning Fight", "Alternate version", "SNK", "Neo Geo", "1991", "burningf", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, burninghRomInfo, burninghRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Cyber-Lip

static struct BurnRomInfo cyberlipRomDesc[] = {
	{"010-p1.bin"   , 0x080000, 0x69a6b42d, 0x10}, //  0 68K code

	{"010-s1.bin"   , 0x020000, 0x79a35264,    1}, //  1 Text layer tiles

	{"010-c1.bin"   , 0x080000, 0x8bba5113,    1}, //  2 Sprite data
	{"010-c2.bin"   , 0x080000, 0xcbf66432,    1}, //  3
	{"010-c3.bin"   , 0x080000, 0xe4f86efc,    1}, //  4
	{"010-c4.bin"   , 0x080000, 0xf7be4674,    1}, //  5
	{"010-c5.bin"   , 0x080000, 0xe8076da0,    1}, //  6
	{"010-c6.bin"   , 0x080000, 0xc495c567,    1}, //  7

	{"010-m1.bin"   , 0x010000, 0x47980d3a, 0x10}, //  8 Z80 code

	{"010-v11.bin"  , 0x080000, 0x90224d22,    2}, //  9 Sound data
	{"010-v12.bin"  , 0x080000, 0xa0cf1834,    2}, // 10
	{"010-v13.bin"  , 0x080000, 0xae38bc84,    2}, // 11
	{"010-v14.bin"  , 0x080000, 0x70899bd2,    2}, // 12
	{"010-v21.bin"  , 0x080000, 0x586f4cb2,    2}, // 13
};

STDROMPICKEXT(cyberlip, cyberlip, neogeo);
STD_ROM_FN(cyberlip);

struct BurnDriver BurnDrvCyberlip = {
	{"cyberlip", "Cyber-Lip", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, cyberlipRomInfo, cyberlipRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Eight Man

static struct BurnRomInfo eightmanRomDesc[] = {
	{"025-p1.bin"   , 0x080000, 0x43344cb0, 0x10}, //  0 68K code

	{"025-s1.bin"   , 0x020000, 0xa402202b,    1}, //  1 Text layer tiles

	{"025-c1.bin"   , 0x100000, 0x555e16a4,    1}, //  2 Sprite data
	{"025-c2.bin"   , 0x100000, 0xe1ee51c3,    1}, //  3
	{"025-c3.bin"   , 0x080000, 0x0923d5b0,    1}, //  4
	{"025-c4.bin"   , 0x080000, 0xe3eca67b,    1}, //  5

	{"025-m1.bin"   , 0x020000, 0x9927034c, 0x10}, //  6 Z80 code

	{"025-v1.bin"   , 0x100000, 0x4558558a,    2}, //  7 Sound data
	{"025-v2.bin"   , 0x100000, 0xc5e052e9,    2}, //  8
};

STDROMPICKEXT(eightman, eightman, neogeo);
STD_ROM_FN(eightman);

struct BurnDriver BurnDrvEightman = {
	{"eightman", "Eight Man", NULL, "SNK / Pallas", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, eightmanRomInfo, eightmanRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fatal Fury

static struct BurnRomInfo fatfury1RomDesc[] = {
	{"033-p1.bin", 0x080000, 0x47EBDC2F, 0x10}, //  0 68K code
	{"033-p2.bin", 0x020000, 0xC473AF1C, 0x10}, //  1

	{"033-s1.bin", 0x020000, 0x3C3BDF8C,    1}, //  2 Text layer tiles

	{"033-c1.bin", 0x100000, 0x74317E54,    1}, //  3 Sprite data
	{"033-c2.bin", 0x100000, 0x5BB952F3,    1}, //  4
	{"033-c3.bin", 0x100000, 0x9B714A7C,    1}, //  5
	{"033-c4.bin", 0x100000, 0x9397476A,    1}, //  6

	{"033-m1.bin", 0x020000, 0xA8603979, 0x10}, //  7 Z80 code

	{"033-v1.bin", 0x100000, 0x212FD20D,    2}, //  8	Sound data
	{"033-v2.bin", 0x100000, 0xFA2AE47F,    2}, //  9
};

STDROMPICKEXT(fatfury1, fatfury1, neogeo);
STD_ROM_FN(fatfury1);

struct BurnDriver BurnDrvFatFury1 = {
	{"fatfury1", "Fatal Fury: king of fighters", "Japanese title is Garou Denetsu: shukumei no tatakai", "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, fatfury1RomInfo, fatfury1RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fatal Fury 2

static struct BurnRomInfo fatfury2RomDesc[] = {
	{"047-p1.bin"   , 0x080000, 0xbe40ea92, 0x10}, //  0 68K code
	{"047-p2.bin"   , 0x080000, 0x2a9beac5, 0x10}, //  1

	{"047-s1.bin"   , 0x020000, 0xd7dbbf39,    1}, //  2 Text layer tiles

	{"047-c1.bin"   , 0x200000, 0xf72a939e,    1}, //  3 Sprite data
	{"047-c2.bin"   , 0x200000, 0x05119a0d,    1}, //  4
	{"047-c3.bin"   , 0x200000, 0x01e00738,    1}, //  5
	{"047-c4.bin"   , 0x200000, 0x9fe27432,    1}, //  6

	{"047-m1.bin"   , 0x020000, 0x820b0ba7, 0x10}, //  7 Z80 code

	{"047-v1.bin"   , 0x200000, 0xd9d00784,    2}, //  8 Sound data
	{"047-v2.bin"   , 0x200000, 0x2c9a4b33,    2}, //  9
};

STDROMPICKEXT(fatfury2, fatfury2, neogeo);
STD_ROM_FN(fatfury2);

static int prot_data;

unsigned char __fastcall fatfury2ReadByteProtection(unsigned int sekAddress)
{
	unsigned short res = (prot_data >> 24) & 0xFF;

	switch (sekAddress) {
		case 0x255551:
		case 0x2FFFF1:
		case 0x200001:
		case 0x2FF001:
		case 0x236001:
		case 0x236009:
			return res;

		case 0x236005:
		case 0x23600D:
			return ((res & 0xF0) >> 4) | ((res & 0x0F) << 4);

//		default:
//			printf("  - prot %06X read", sekAddress);
	}

	return 0;
}

void __fastcall fatfury2WriteByteProtection(unsigned int sekAddress, unsigned char /*byteValue*/)
{
	switch (sekAddress) {
		case 0x255553:				// data == 0x5555; read back from 55550, ffff0, 00000, ff000
			prot_data = 0xFF00FF00;
			break;

		case 0x256783:				// data == 0x1234; read back from 36000 *or* 36004
			prot_data = 0xF05A3601;
			break;

		case 0x242813:				// data == 0x1824; read back from 36008 *or* 3600c
			prot_data = 0x81422418;
			break;

		case 0x255551:
		case 0x2FFFF1:
		case 0x2FF001:
		case 0x236001:
		case 0x236005:
		case 0x236009:
		case 0x23600D:
			prot_data <<= 8;
			break;

//		default:
//			printf("  - prot %06X -> %02X", sekAddress, byteValue);
	}
}

static void fatfury2Patch()
{
	*((unsigned short*)(Neo68KROM01 + 0xB820)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0xB822)) = 0x4E71;
}

static int fatfury2Init()
{
	int nRet;

	pNeoInitCallback = fatfury2Patch;

	nRet = NeoInit();

	if (nRet == 0) {
		// Install protection handler
		SekMapHandler(5,	0x200000, 0x2FFFFF, SM_WRITE);
		SekSetWriteByteHandler(5, fatfury2WriteByteProtection);
		SekSetReadByteHandler(5, fatfury2ReadByteProtection);
	}

	return nRet;
}

struct BurnDriver BurnDrvFatfury2 = {
	{"fatfury2", "Fatal Fury 2", "Japanese title is: Garou Densetsu 2: arata-naru tatakai", "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, fatfury2RomInfo, fatfury2RomName, neogeoInputInfo, neogeoDIPInfo,
	fatfury2Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fatal Fury Special

static struct BurnRomInfo fatfurspRomDesc[] = {
	{"058-p1.bin"   , 0x100000, 0x2f585ba2, 0x10}, //  0 68K code
	{"058-p2.bin"   , 0x080000, 0xd7c71a6b, 0x10}, //  1

	{"058-s1.bin"   , 0x020000, 0x2df03197,    1}, //  2 Text layer tiles

	{"058-c1.bin"   , 0x200000, 0x044ab13c,    1}, //  3 Sprite data
	{"058-c2.bin"   , 0x200000, 0x11e6bf96,    1}, //  4
	{"058-c3.bin"   , 0x200000, 0x6f7938d5,    1}, //  5
	{"058-c4.bin"   , 0x200000, 0x4ad066ff,    1}, //  6
	{"058-c5.bin"   , 0x200000, 0x49c5e0bf,    1}, //  7
	{"058-c6.bin"   , 0x200000, 0x8ff1f43d,    1}, //  8

	{"058-m1.bin"   , 0x020000, 0xccc5186e, 0x10}, //  9 Z80 code

	{"058-v1.bin"   , 0x200000, 0x55d7ce84,    2}, // 10 Sound data
	{"058-v2.bin"   , 0x200000, 0xee080b10,    2}, // 11
	{"058-v3.bin"   , 0x100000, 0xf9eb3d4a,    2}, // 12
};

STDROMPICKEXT(fatfursp, fatfursp, neogeo);
STD_ROM_FN(fatfursp);

struct BurnDriver BurnDrvFatfursp = {
	{"fatfursp", "Fatal Fury Special", "Japanese title is Garou Densetsu Special", "SNK", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, fatfurspRomInfo, fatfurspRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fatal Fury Special (alternate set)

static struct BurnRomInfo fatfurspaRomDesc[] = {
	{"058-ep1.bin"  , 0x100000, 0x36be707d, 0x10}, //  0 68K code
	{"058-p2.bin"   , 0x080000, 0xd7c71a6b, 0x10}, //  1

	{"058-s1.bin"   , 0x020000, 0x2df03197,    1}, //  2 Text layer tiles

	{"058-c1.bin"   , 0x200000, 0x044ab13c,    1}, //  3 Sprite data
	{"058-c2.bin"   , 0x200000, 0x11e6bf96,    1}, //  4
	{"058-c3.bin"   , 0x200000, 0x6f7938d5,    1}, //  5
	{"058-c4.bin"   , 0x200000, 0x4ad066ff,    1}, //  6
	{"058-c5.bin"   , 0x200000, 0x49c5e0bf,    1}, //  7
	{"058-c6.bin"   , 0x200000, 0x8ff1f43d,    1}, //  8

	{"058-m1.bin"   , 0x020000, 0xccc5186e, 0x10}, //  9 Z80 code

	{"058-v1.bin"   , 0x200000, 0x55d7ce84,    2}, // 10 Sound data
	{"058-v2.bin"   , 0x200000, 0xee080b10,    2}, // 11
	{"058-v3.bin"   , 0x100000, 0xf9eb3d4a,    2}, // 12
};

STDROMPICKEXT(fatfurspa, fatfurspa, neogeo);
STD_ROM_FN(fatfurspa);

struct BurnDriver BurnDrvFatfurspa = {
	{"fatfurspa", "Fatal Fury Special", "Alternate set, Japanese title is Garou Densetsu Special", "SNK", "Neo Geo", "1993", "fatfursp", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO,
	NULL, fatfurspaRomInfo, fatfurspaRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fatal Fury 3

static struct BurnRomInfo fatfury3RomDesc[] = {
	{"069-p1.bin"   , 0x100000, 0xa8bcfbbc, 0x10}, //  0 68K code
	{"069-p2.bin"   , 0x200000, 0xdbe963ed, 0x10}, //  1

	{"069-s1.bin"   , 0x020000, 0x0b33a800,    1}, //  2 Text layer tiles

	{"069-c1.bin"   , 0x400000, 0xe302f93c,    1}, //  3 Sprite data
	{"069-c2.bin"   , 0x400000, 0x1053a455,    1}, //  4
	{"069-c3.bin"   , 0x400000, 0x1c0fde2f,    1}, //  5
	{"069-c4.bin"   , 0x400000, 0xa25fc3d0,    1}, //  6
	{"069-c5.bin"   , 0x200000, 0xb3ec6fa6,    1}, //  7
	{"069-c6.bin"   , 0x200000, 0x69210441,    1}, //  8

	{"069-m1.bin"   , 0x020000, 0xfce72926, 0x10}, //  9 Z80 code

	{"069-v1.bin"   , 0x400000, 0x2bdbd4db,    2}, // 10 Sound data
	{"069-v2.bin"   , 0x400000, 0xa698a487,    2}, // 11
	{"069-v3.bin"   , 0x200000, 0x581c5304,    2}, // 12
};

STDROMPICKEXT(fatfury3, fatfury3, neogeo);
STD_ROM_FN(fatfury3);

struct BurnDriver BurnDrvFatfury3 = {
	{"fatfury3", "Fatal Fury 3: Road to the Final Victory", "Japanese title is Garou Densetsu 3: haruka-naru tatakai", "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, fatfury3RomInfo, fatfury3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Football Frenzy

static struct BurnRomInfo fbfrenzyRomDesc[] = {
	{"034-p1.bin"   , 0x080000, 0xcdef6b19, 0x10}, //  0 68K code

	{"034-s1.bin"   , 0x020000, 0x8472ed44,    1}, //  1 Text layer tiles

	{"034-c1.bin"   , 0x100000, 0x91c56e78,    1}, //  2 Sprite data
	{"034-c2.bin"   , 0x100000, 0x9743ea2f,    1}, //  3
	{"034-c3.bin"   , 0x080000, 0xe5aa65f5,    1}, //  4
	{"034-c4.bin"   , 0x080000, 0x0eb138cc,    1}, //  5

	{"034-m1.bin"   , 0x020000, 0xf41b16b8, 0x10}, //  6 Z80 code

	{"034-v1.bin"   , 0x100000, 0x50c9d0dd,    2}, //  7 Sound data
	{"034-v2.bin"   , 0x100000, 0x5aa15686,    2}, //  8
};

STDROMPICKEXT(fbfrenzy, fbfrenzy, neogeo);
STD_ROM_FN(fbfrenzy);

struct BurnDriver BurnDrvFbfrenzy = {
	{"fbfrenzy", "Football Frenzy", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, fbfrenzyRomInfo, fbfrenzyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Garou

static struct BurnRomInfo garouRomDesc[] = {
	{"253-sma.bin"  , 0x040000, 0x98bc93dc, 0x10}, //  0 68K code
	{"253-ep1.p1"   , 0x200000, 0xea3171a4, 0x10}, //  1
	{"253-ep2.p2"   , 0x200000, 0x382f704b, 0x10}, //  2
	{"253-ep3.p3"   , 0x200000, 0xe395bfdd, 0x10}, //  3
	{"253-ep4.p4"   , 0x200000, 0xda92c08e, 0x10}, //  4

	{"253-c1.bin"   , 0x800000, 0x0603e046,    1}, //  5 Sprite data
	{"253-c2.bin"   , 0x800000, 0x0917d2a4,    1}, //  6
	{"253-c3.bin"   , 0x800000, 0x6737c92d,    1}, //  7
	{"253-c4.bin"   , 0x800000, 0x5ba92ec6,    1}, //  8
	{"253-c5.bin"   , 0x800000, 0x3eab5557,    1}, //  9
	{"253-c6.bin"   , 0x800000, 0x308d098b,    1}, // 10
	{"253-c7.bin"   , 0x800000, 0xc0e995ae,    1}, // 11
	{"253-c8.bin"   , 0x800000, 0x21a11303,    1}, // 12

	{"253-m1.bin"   , 0x040000, 0x36a806be, 0x10}, // 13 Z80 code

	{"253-v1.bin"   , 0x400000, 0x263e388c,    2}, // 14 Sound data
	{"253-v2.bin"   , 0x400000, 0x2c6bc7be,    2}, // 15
	{"253-v3.bin"   , 0x400000, 0x0425b27d,    2}, // 16
	{"253-v4.bin"   , 0x400000, 0xa54be8a9,    2}, // 17
};

STDROMPICKEXT(garou, garou, neogeo);
STD_ROM_FN(garou);

static void garouSMADecrypt()
{
	for (int i = 0; i < 0x800000 / 2; i++) {
		((unsigned short*)Neo68KROM02)[i] = BITSWAP16(((unsigned short*)Neo68KROM02)[i], 13, 12, 14, 10, 8, 2, 3, 1, 5, 9, 11, 4, 15, 0, 6, 7);
	}

	for (int i = 0; i < 0x0C0000 / 2; i++) {
		((unsigned short*)Neo68KROM01)[i] = ((unsigned short*)Neo68KROM01)[0x710000 / 2 + BITSWAP24(i, 23, 22, 21, 20, 19, 18, 4, 5, 16, 14, 7, 9, 6, 13, 17, 15, 3, 1, 2, 12, 11, 8, 10, 0)];
	}

	for (int i = 0; i < 0x800000 / 2; i += 0x8000 / 2) {
		unsigned short nBuffer[0x8000 / 2];
		memcpy(nBuffer, &((unsigned short*)Neo68KROM02)[i], 0x8000);
		for (int j = 0; j < 0x8000 / 2; j++) {
			((unsigned short*)Neo68KROM02)[i + j] = nBuffer[BITSWAP24(j, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 9, 4, 8, 3, 13, 6, 2, 7, 0, 12, 1, 11, 10, 5)];
		}
	}
}

void __fastcall garouWriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{
	if (sekAddress == 0x2FFFC0) {
		static unsigned int bankoffset[64] = {
			0x000000, 0x100000, 0x200000, 0x300000, // 00
			0x280000, 0x380000, 0x2d0000, 0x3d0000, // 04
			0x2f0000, 0x3f0000, 0x400000, 0x500000, // 08
			0x420000, 0x520000, 0x440000, 0x540000, // 12
			0x498000, 0x598000, 0x4a0000, 0x5a0000, // 16
			0x4a8000, 0x5a8000, 0x4b0000, 0x5b0000, // 20
			0x4b8000, 0x5b8000, 0x4c0000, 0x5c0000, // 24
			0x4c8000, 0x5c8000, 0x4d0000, 0x5d0000, // 28
			0x458000, 0x558000, 0x460000, 0x560000, // 32
			0x468000, 0x568000, 0x470000, 0x570000, // 36
			0x478000, 0x578000, 0x480000, 0x580000, // 40
			0x488000, 0x588000, 0x490000, 0x590000, // 44
			0x5d0000, 0x5d8000, 0x5e0000, 0x5e8000, // 48
			0x5f0000, 0x5f8000, 0x600000, /* rest not used? */
		};

		// Unscramble bank number
		int nBank =
			(((wordValue >>  5) & 1) << 0) +
			(((wordValue >>  9) & 1) << 1) +
			(((wordValue >>  7) & 1) << 2) +
			(((wordValue >>  6) & 1) << 3) +
			(((wordValue >> 14) & 1) << 4) +
			(((wordValue >> 12) & 1) << 5);

		if (bankoffset[nBank] != nNeo68KROMBank) {
			nNeo68KROMBank = bankoffset[nBank];
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank,			  0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFBFF, SM_ROM);
		}
	}
}

static int garouInit()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0x06;

	nNeoSMARNGAddress[0] = 0x2FFFCC; nNeoSMARNGAddress[1] = 0x2FFFF0;
	pNeoSMABankswitch = garouWriteWordBankswitch;
	pNeoInitCallback = garouSMADecrypt;

	return NeoInit();
}

struct BurnDriver BurnDrvGarou = {
	{"garou", "Garou: Mark Of The Wolves", NULL, "SNK", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, garouRomInfo, garouRomName, neogeoInputInfo, neogeoDIPInfo,
	garouInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Garou [Set 2]

static struct BurnRomInfo garouoRomDesc[] = {
	{"253-smao.bin" , 0x040000, 0x96c72233, 0x10}, //  0 68K code
	{"253-p1.bin"   , 0x400000, 0x18ae5d7e, 0x10}, //  1
	{"253-p2.bin"   , 0x400000, 0xafffa779, 0x10}, //  2

	{"253-c1.bin"   , 0x800000, 0x0603e046,    1}, //  3 Sprite data
	{"253-c2.bin"   , 0x800000, 0x0917d2a4,    1}, //  4
	{"253-c3.bin"   , 0x800000, 0x6737c92d,    1}, //  5
	{"253-c4.bin"   , 0x800000, 0x5ba92ec6,    1}, //  6
	{"253-c5.bin"   , 0x800000, 0x3eab5557,    1}, //  7
	{"253-c6.bin"   , 0x800000, 0x308d098b,    1}, //  8
	{"253-c7.bin"   , 0x800000, 0xc0e995ae,    1}, //  9
	{"253-c8.bin"   , 0x800000, 0x21a11303,    1}, // 10

	{"253-m1.bin"   , 0x040000, 0x36a806be, 0x10}, // 11 Z80 code

	{"253-v1.bin"   , 0x400000, 0x263e388c,    2}, // 12 Sound data
	{"253-v2.bin"   , 0x400000, 0x2c6bc7be,    2}, // 13
	{"253-v3.bin"   , 0x400000, 0x0425b27d,    2}, // 14
	{"253-v4.bin"   , 0x400000, 0xa54be8a9,    2}, // 15
};

STDROMPICKEXT(garouo, garouo, neogeo);
STD_ROM_FN(garouo);

static void garouoSMADecrypt()
{
	for (int i = 0; i < 0x800000 / 2; i++) {
		((unsigned short*)Neo68KROM02)[i] = BITSWAP16(((unsigned short*)Neo68KROM02)[i], 14, 5, 1, 11, 7, 4, 10, 15, 3, 12, 8, 13, 0, 2, 9, 6);
	}

	for (int i = 0; i < 0x0C0000 / 2; i++) {
		((unsigned short*)Neo68KROM01)[i] = ((unsigned short*)Neo68KROM01)[0x7F8000 / 2 + BITSWAP24(i, 23, 22, 21, 20, 19, 18, 5, 16, 11, 2, 6, 7, 17, 3, 12, 8, 14, 4, 0, 9, 1, 10, 15, 13)];
	}

	for (int i = 0; i < 0x800000 / 2; i += 0x8000 / 2) {
		unsigned short nBuffer[0x8000 / 2];
		memcpy(nBuffer, &((unsigned short*)Neo68KROM02)[i], 0x8000);
		for (int j = 0; j < 0x8000 / 2; j++) {
			((unsigned short*)Neo68KROM02)[i + j] = nBuffer[BITSWAP24(j, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 12, 8, 1, 7, 11, 3, 13, 10, 6, 9, 5, 4, 0, 2)];
		}
	}
}

void __fastcall garouoWriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{
	if (sekAddress == 0x2FFFC0) {
		static unsigned int bankoffset[64] = {
			0x000000, 0x100000, 0x200000, 0x300000, // 00
			0x280000, 0x380000, 0x2d0000, 0x3d0000, // 04
			0x2c8000, 0x3c8000, 0x400000, 0x500000, // 08
			0x420000, 0x520000, 0x440000, 0x540000, // 12
			0x598000, 0x698000, 0x5a0000, 0x6a0000, // 16
			0x5a8000, 0x6a8000, 0x5b0000, 0x6b0000, // 20
			0x5b8000, 0x6b8000, 0x5c0000, 0x6c0000, // 24
			0x5c8000, 0x6c8000, 0x5d0000, 0x6d0000, // 28
			0x458000, 0x558000, 0x460000, 0x560000, // 32
			0x468000, 0x568000, 0x470000, 0x570000, // 36
			0x478000, 0x578000, 0x480000, 0x580000, // 40
			0x488000, 0x588000, 0x490000, 0x590000, // 44
			0x5d8000, 0x6d8000, 0x5e0000, 0x6e0000, // 48
			0x5e8000, 0x6e8000, 0x6e8000, 0x000000, // 52
			0x000000, 0x000000, 0x000000, 0x000000, // 56
			0x000000, 0x000000, 0x000000, 0x000000, // 60
		};

		// Unscramble bank number
		int nBank =
			(((wordValue >>  4) & 1) << 0) +
			(((wordValue >>  8) & 1) << 1) +
			(((wordValue >> 14) & 1) << 2) +
			(((wordValue >>  2) & 1) << 3) +
			(((wordValue >> 11) & 1) << 4) +
			(((wordValue >> 13) & 1) << 5);

		if (bankoffset[nBank] != nNeo68KROMBank) {
			nNeo68KROMBank = bankoffset[nBank];
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank,			  0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFBFF, SM_ROM);
		}
	}
}

static int garouoInit()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0x06;

	nNeoSMARNGAddress[0] = 0x2FFFCC; nNeoSMARNGAddress[1] = 0x2FFFF0;
	pNeoSMABankswitch = garouoWriteWordBankswitch;
	pNeoInitCallback = garouoSMADecrypt;

	return NeoInit();
}

struct BurnDriver BurnDrvGarouo = {
	{"garouo", "Garou: Mark Of The Wolves", "Alternate version", "SNK", "Neo Geo", "1999", "garou", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, garouoRomInfo, garouoRomName, neogeoInputInfo, neogeoDIPInfo,
	garouoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Garou [Prototype version]

static struct BurnRomInfo garoupRomDesc[] = {
	{"253-p1p.bin"  , 0x100000, 0xc72f0c16, 0x10}, //  0 68K code
	{"253-p2p.bin"  , 0x400000, 0xbf8de565, 0x10}, //  1

	{"253-s1p.bin"  , 0x020000, 0x779989de,    1}, //  2 Text layer tiles

	{"253-c1p.bin"  , 0x800000, 0x5bb5d137,    1}, //  3 Sprite data
	{"253-c2p.bin"  , 0x800000, 0x5c8d2960,    1}, //  4
	{"253-c3p.bin"  , 0x800000, 0x234d16fc,    1}, //  5
	{"253-c4p.bin"  , 0x800000, 0xb9b5b993,    1}, //  6
	{"253-c5p.bin"  , 0x800000, 0x722615d2,    1}, //  7
	{"253-c6p.bin"  , 0x800000, 0x0a6fab38,    1}, //  8
	{"253-c7p.bin"  , 0x800000, 0xd68e806f,    1}, //  9
	{"253-c8p.bin"  , 0x800000, 0xf778fe99,    1}, // 10

	{"253-m1p.bin"  , 0x040000, 0xbbe464f7, 0x10}, // 11 Z80 code

	{"253-v1p.bin"  , 0x400000, 0x274f3923,    2}, // 12	Sound data
	{"253-v2p.bin"  , 0x400000, 0x8f86dabe,    2}, // 13
	{"253-v3p.bin"  , 0x400000, 0x05fd06cd,    2}, // 14
	{"253-v4p.bin"  , 0x400000, 0x14984063,    2}, // 15
};

STDROMPICKEXT(garoup, garoup, neogeo);
STD_ROM_FN(garoup);

struct BurnDriver BurnDrvGaroup = {
	{"garoup", "Garou: Mark Of The Wolves", NULL, "SNK", "Neo Geo", "1999", "garou", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE | BDF_PROTOTYPE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, garoupRomInfo, garoupRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Ghost Pilots

static struct BurnRomInfo gpilotsRomDesc[] = {
	{"020-p1.bin"   , 0x080000, 0xe6f2fe64, 0x10}, //  0 68K code
	{"020-p2.bin"   , 0x020000, 0xedcb22ac, 0x10}, //  1

	{"020-s1.bin"   , 0x020000, 0xa6d83d53,    1}, //  2 Text layer tiles

	{"020-c1.bin"   , 0x100000, 0xbd6fe78e,    1}, //  3 Sprite data
	{"020-c2.bin"   , 0x100000, 0x5f4a925c,    1}, //  4
	{"020-c3.bin"   , 0x100000, 0xd1e42fd0,    1}, //  5
	{"020-c4.bin"   , 0x100000, 0xedde439b,    1}, //  6

	{"020-m1.bin"   , 0x020000, 0x48409377, 0x10}, //  7 Z80 code

	{"020-v11.bin"  , 0x100000, 0x1b526c8b,    2}, //  8 Sound data
	{"020-v12.bin"  , 0x080000, 0x4a9e6f03,    2}, //  9
	{"020-v21.bin"  , 0x080000, 0x7abf113d,    2}, // 10
};

STDROMPICKEXT(gpilots, gpilots, neogeo);
STD_ROM_FN(gpilots);

struct BurnDriver BurnDrvGpilots = {
	{"gpilots", "Ghost Pilots", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, gpilotsRomInfo, gpilotsRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// King of the Monsters

static struct BurnRomInfo kotmRomDesc[] = {
	{"016-p1.bin"   , 0x080000, 0x1B818731, 0x10}, //  0 68K code
	{"016-p2.bin"   , 0x020000, 0x12AFDC2B, 0x10}, //  1

	{"016-s1.bin"   , 0x020000, 0x1A2EEEB3,    1}, //  2 Text layer tiles

	{"016-c1.bin"   , 0x100000, 0x71471C25,    1}, //  3 Sprite data
	{"016-c2.bin"   , 0x100000, 0x320DB048,    1}, //  4
	{"016-c3.bin"   , 0x100000, 0x98DE7995,    1}, //  5
	{"016-c4.bin"   , 0x100000, 0x070506E2,    1}, //  6

	{"016-m1.bin"   , 0x020000, 0x0296ABCB, 0x10}, //  7 Z80 code

	{"016-v1.bin"   , 0x100000, 0x86C0A502,    2}, //  8 Sound data
	{"016-v2.bin"   , 0x100000, 0x5BC23EC5,    2}, //  9
};

STDROMPICKEXT(kotm, kotm, neogeo);
STD_ROM_FN(kotm);

struct BurnDriver BurnDrvKotm = {
	{"kotm", "King of the Monsters", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, kotmRomInfo, kotmRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// King of the Monsters (alternate version)

static struct BurnRomInfo kotmhRomDesc[] = {
	{"016-hp1.bin"  , 0x080000, 0xB774621E, 0x10}, //  0 68K code
	{"016-p2.bin"   , 0x020000, 0x12AFDC2B, 0x10}, //  1

	{"016-s1.bin"   , 0x020000, 0x1A2EEEB3,    1}, //  2 Text layer tiles

	{"016-c1.bin"   , 0x100000, 0x71471C25,    1}, //  3 Sprite data
	{"016-c2.bin"   , 0x100000, 0x320DB048,    1}, //  4
	{"016-c3.bin"   , 0x100000, 0x98DE7995,    1}, //  5
	{"016-c4.bin"   , 0x100000, 0x070506E2,    1}, //  6

	{"016-m1.bin"   , 0x020000, 0x0296ABCB, 0x10}, //  7 Z80 code

	{"016-v1.bin"   , 0x100000, 0x86C0A502,    2}, //  8 Sound data
	{"016-v2.bin"   , 0x100000, 0x5BC23EC5,    2}, //  9
};

STDROMPICKEXT(kotmh, kotmh, neogeo);
STD_ROM_FN(kotmh);

struct BurnDriver BurnDrvKotmh = {
	{"kotmh", "King of the Monsters", "Alternate version", "SNK", "Neo Geo", "1991", "kotm", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, kotmhRomInfo, kotmhRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// King of the Monsters 2

static struct BurnRomInfo kotm2RomDesc[] = {
	{"039-p1.bin"   , 0x080000, 0xb372d54c, 0x10}, //  0 68K code
	{"039-p2.bin"   , 0x080000, 0x28661afe, 0x10}, //  1

	{"039-s1.bin"   , 0x020000, 0x63ee053a,    1}, //  2 Text layer tiles

	{"039-c1.bin"   , 0x200000, 0x6d1c4aa9,    1}, //  3 Sprite data
	{"039-c2.bin"   , 0x200000, 0xf7b75337,    1}, //  4
	{"039-c3.bin"   , 0x200000, 0x40156dca,    1}, //  5
	{"039-c4.bin"   , 0x200000, 0xb0d44111,    1}, //  6

	{"039-m1.bin"   , 0x020000, 0x0c5b2ad5, 0x10}, //  7 Z80 code

	{"039-v1.bin"   , 0x200000, 0x86d34b25,    2}, //  8 Sound data
	{"039-v2.bin"   , 0x100000, 0x8fa62a0b,    2}, //  9
};

STDROMPICKEXT(kotm2, kotm2, neogeo);
STD_ROM_FN(kotm2);

struct BurnDriver BurnDrvKotm2 = {
	{"kotm2", "King of the Monsters 2: The Next Thing", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, kotm2RomInfo, kotm2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Kizuna Encounter

static struct BurnRomInfo kizunaRomDesc[] = {
	{"216-p1.bin"   , 0x200000, 0x75d2b3de, 0x10}, //  0 68K code

	{"216-s1.bin"   , 0x020000, 0xefdc72d7,    1}, //  1 Text layer tiles

	{"216-c1.bin"   , 0x200000, 0x763ba611,    1}, //  2 Sprite data
	{"216-c2.bin"   , 0x200000, 0xe05e8ca6,    1}, //  3
	{"216-c3.bin"   , 0x400000, 0x665c9f16,    1}, //  4
	{"216-c4.bin"   , 0x400000, 0x7f5d03db,    1}, //  5
	{"216-c5.bin"   , 0x200000, 0x59013f9e,    1}, //  6
	{"216-c6.bin"   , 0x200000, 0x1c8d5def,    1}, //  7
	{"216-c7.bin"   , 0x200000, 0xc88f7035,    1}, //  8
	{"216-c8.bin"   , 0x200000, 0x484ce3ba,    1}, //  9

	{"216-m1.bin"   , 0x020000, 0x1b096820, 0x10}, // 10 Z80 code

	{"216-v1.bin"   , 0x200000, 0x530c50fd,    2}, // 11 Sound data
	{"216-v2.bin"   , 0x200000, 0x03667a8d,    2}, // 12
	{"216-v3.bin"   , 0x200000, 0x7038c2f9,    2}, // 13
	{"216-v4.bin"   , 0x200000, 0x31b99bd6,    2}, // 14
};

STDROMPICKEXT(kizuna, kizuna, neogeo);
STD_ROM_FN(kizuna);

struct BurnDriver BurnDrvKizuna = {
	{"kizuna", "Kizuna Encounter: Super Tag Battle", "Japanese title is Fu'un Super Tag Battle", "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SRAM,
	NULL, kizunaRomInfo, kizunaRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Last Resort

static struct BurnRomInfo lresortRomDesc[] = {
	{"024-p1.bin"   , 0x080000, 0x89c4ab97, 0x10}, //  0 68K code

	{"024-s1.bin"   , 0x020000, 0x5cef5cc6,    1}, //  1 Text layer tiles

	{"024-c1.bin"   , 0x100000, 0x3617c2dc,    1}, //  2 Sprite data
	{"024-c2.bin"   , 0x100000, 0x3f0a7fd8,    1}, //  3
	{"024-c3.bin"   , 0x080000, 0xe9f745f8,    1}, //  4
	{"024-c4.bin"   , 0x080000, 0x7382fefb,    1}, //  5

	{"024-m1.bin"   , 0x020000, 0xcec19742, 0x10}, //  6 Z80 code

	{"024-v1.bin"   , 0x100000, 0xefdfa063,    2}, //  7 Sound data
	{"024-v2.bin"   , 0x100000, 0x3c7997c0,    2}, //  8
};

STDROMPICKEXT(lresort, lresort, neogeo);
STD_ROM_FN(lresort);

struct BurnDriver BurnDrvLresort = {
	{"lresort", "Last Resort", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, lresortRomInfo, lresortRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// League Bowling

static struct BurnRomInfo lbowlingRomDesc[] = {
	{"019-p1.bin"   , 0x080000, 0xa2de8445, 0x10}, //  0 68K code

	{"019-s1.bin"   , 0x020000, 0x5fcdc0ed,    1}, //  1 Text layer tiles

	{"019-c1.bin"   , 0x080000, 0x4ccdef18,    1}, //  2 Sprite data
	{"019-c2.bin"   , 0x080000, 0xd4dd0802,    1}, //  3

	{"019-m1.bin"   , 0x020000, 0x589d7f25, 0x10}, //  4 Z80 code

	{"019-v11.bin"  , 0x080000, 0x0fb74872,    2}, //  5 Sound data
	{"019-v12.bin"  , 0x080000, 0x029faa57,    2}, //  6
	{"019-v21.bin"  , 0x080000, 0x2efd5ada,    2}, //  7
};

STDROMPICKEXT(lbowling, lbowling, neogeo);
STD_ROM_FN(lbowling);

struct BurnDriver BurnDrvLbowling = {
	{"lbowling", "League Bowling", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, lbowlingRomInfo, lbowlingRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Legend of Success Joe

static struct BurnRomInfo legendosRomDesc[] = {
	{"029-p1.bin"   , 0x080000, 0x9d563f19, 0x10}, //  0 68K code

	{"029-s1.bin"   , 0x020000, 0xbcd502f0,    1}, //  1 Text layer tiles

	{"029-c1.bin"   , 0x100000, 0x2f5ab875,    1}, //  2 Sprite data
	{"029-c2.bin"   , 0x100000, 0x318b2711,    1}, //  3
	{"029-c3.bin"   , 0x100000, 0x6bc52cb2,    1}, //  4
	{"029-c4.bin"   , 0x100000, 0x37ef298c,    1}, //  5

	{"029-m1.bin"   , 0x010000, 0x909d4ed9, 0x10}, //  6 Z80 code

	{"029-v1.bin"   , 0x100000, 0x85065452,    2}, //  7 Sound data
};

STDROMPICKEXT(legendos, legendos, neogeo);
STD_ROM_FN(legendos);

struct BurnDriver BurnDrvLegendos = {
	{"legendos", "Legend of Success Joe", "Japanese title is Ashitano Joe Densetsu", "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, legendosRomInfo, legendosRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Mahjong Kyoretsuden

static struct BurnRomInfo mahretsuRomDesc[] = {
	{"004-p1.bin"  , 0x080000, 0xfc6f53db, 0x10}, //  0 68K code

	{"004-s1.bin"  , 0x010000, 0xb0d16529,    1}, //  1 Text layer tiles

	{"004-c1.bin"  , 0x080000, 0xf1ae16bc,    1}, //  2 Sprite data
	{"004-c2.bin"  , 0x080000, 0xbdc13520,    1}, //  3
	{"004-c3.bin"  , 0x080000, 0x9c571a37,    1}, //  4
	{"004-c4.bin"  , 0x080000, 0x7e81cb29,    1}, //  5

	{"004-m1.bin"  , 0x010000, 0x37965a73, 0x10}, //  6 Z80 code

	{"004-v1.bin"  , 0x080000, 0xb2fb2153,    2}, //  7 Sound data
	{"004-v2.bin"  , 0x080000, 0x8503317b,    2}, //  8
	{"004-v3.bin"  , 0x080000, 0x4999fb27,    2}, //  9
	{"004-v4.bin"  , 0x080000, 0x776fa2a2,    2}, // 10
	{"004-v5.bin"  , 0x080000, 0xb3e7eeea,    2}, // 11
};

STDROMPICKEXT(mahretsu, mahretsu, neogeo);
STD_ROM_FN(mahretsu);

struct BurnDriver BurnDrvMahretsu = {
	{"mahretsu", "Mahjong Kyoretsuden", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_MAHJONG,
	NULL, mahretsuRomInfo, mahretsuRomName, neomahjongInputInfo, neomahjongDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Metal Slug 2

static struct BurnRomInfo mslug2RomDesc[] = {
	{"241-p1.bin", 0x100000, 0x2a53c5da, 0x10}, //  0 68K code
	{"241-p2.bin", 0x200000, 0x38883f44, 0x10}, //  1

	{"241-s1.bin", 0x020000, 0xf3d32f0f,    1}, //  2 Text layer tiles

	{"241-c1.bin", 0x800000, 0x394b5e0d,    1}, //  3 Sprite data
	{"241-c2.bin", 0x800000, 0xe5806221,    1}, //  4
	{"241-c3.bin", 0x800000, 0x9f6bfa6f,    1}, //  5
	{"241-c4.bin", 0x800000, 0x7d3e306f,    1}, //  6

	{"241-m1.bin", 0x020000, 0x94520ebd, 0x10}, //  7 Z80 code

	{"241-v1.bin", 0x400000, 0x99ec20e8,    2}, //  8 Sound data
	{"241-v2.bin", 0x400000, 0xecb16799,    2}, //  9
};

STDROMPICKEXT(mslug2, mslug2, neogeo);
STD_ROM_FN(mslug2);

struct BurnDriver BurnDrvMSlug2 = {
	{"mslug2", "Metal Slug 2: Super Vehicle-001/II", NULL, "SNK", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, mslug2RomInfo, mslug2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Metal Slug X

static struct BurnRomInfo mslugxRomDesc[] = {
	{"250-p1.bin", 0x100000, 0x81f1f60b, 0x10}, //  0 68K code
	{"250-p2.bin", 0x400000, 0x1fda2e12, 0x10}, //  1

	{"250-s1.bin", 0x020000, 0xfb6f441d,    1}, //  2 Text layer tiles

	{"250-c1.bin", 0x800000, 0x09a52c6f,    1}, //  3 Sprite data
	{"250-c2.bin", 0x800000, 0x31679821,    1}, //  4
	{"250-c3.bin", 0x800000, 0xfd602019,    1}, //  5
	{"250-c4.bin", 0x800000, 0x31354513,    1}, //  6
	{"250-c5.bin", 0x800000, 0xa4b56124,    1}, //  7
	{"250-c6.bin", 0x800000, 0x83e3e69d,    1}, //  8

	{"250-m1.bin", 0x020000, 0xfd42a842, 0x10}, //  9 Z80 code

	{"250-v1.bin", 0x400000, 0xc79ede73,    2}, // 10 Sound data
	{"250-v2.bin", 0x400000, 0xea9aabe1,    2}, // 11
	{"250-v3.bin", 0x200000, 0x2ca65102,    2}, // 12
};

STDROMPICKEXT(mslugx, mslugx, neogeo);
STD_ROM_FN(mslugx);

static void mslugxPatch()
{
	for (int i = 0; i < 0x100000 - 8; i += 2) {
		if (*((unsigned short*)(Neo68KROM01 + i + 0)) == 0x0243 && *((unsigned short*)(Neo68KROM01 + i + 2)) == 0x0001 && *((unsigned short*)(Neo68KROM01 + i + 4)) == 0x6600) {
			*((unsigned short*)(Neo68KROM01 + i + 4)) = 0x4E71;
			*((unsigned short*)(Neo68KROM01 + i + 6)) = 0x4E71;
		}
	}
	*((unsigned short*)(Neo68KROM01 + 0x3BDC)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3BDE)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3BE0)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3C0C)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3C0E)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3C10)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3C36)) = 0x4E71;
	*((unsigned short*)(Neo68KROM01 + 0x3C38)) = 0x4E71;
}

static int mslugxInit()
{
	pNeoInitCallback = mslugxPatch;

	return NeoInit();
}

struct BurnDriver BurnDrvMSlugX = {
	{"mslugx", "Metal Slug X: Super Vehicle-001", NULL, "SNK", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, mslugxRomInfo, mslugxRomName, neogeoInputInfo, neogeoDIPInfo,
	mslugxInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Metal Slug 3 (encrypted code & grahics)

static struct BurnRomInfo mslug3RomDesc[] = {
	{"256-sma.bin",0x040000, 0x9CD55736, 0x10}, //  0 68K code
	{"256-p1.bin", 0x400000, 0xB07EDFD5, 0x10}, //  1
	{"256-p2.bin", 0x400000, 0x6097C26B, 0x10}, //  2

	{"256-c1.bin", 0x800000, 0x5A79C34E,    1}, //  3 Sprite data
	{"256-c2.bin", 0x800000, 0x944C362C,    1}, //  4
	{"256-c3.bin", 0x800000, 0x6E69D36F,    1}, //  5
	{"256-c4.bin", 0x800000, 0xB755B4EB,    1}, //  6
	{"256-c5.bin", 0x800000, 0x7AACAB47,    1}, //  7
	{"256-c6.bin", 0x800000, 0xC698FD5D,    1}, //  8
	{"256-c7.bin", 0x800000, 0xCFCEDDD2,    1}, //  9
	{"256-c8.bin", 0x800000, 0x4D9BE34C,    1}, // 10

	{"256-m1.bin", 0x080000, 0xEAEEC116, 0x10}, // 11 Z80 code

	{"256-v1.bin", 0x400000, 0xF2690241,    2}, // 12 Sound data
	{"256-v2.bin", 0x400000, 0x7E2A10BD,    2}, // 13
	{"256-v3.bin", 0x400000, 0x0EAEC17C,    2}, // 14
	{"256-v4.bin", 0x400000, 0x9B4B22D4,    2}, // 15
};

STDROMPICKEXT(mslug3, mslug3, neogeo);
STD_ROM_FN(mslug3);

static void mslug3SMADecrypt()
{
	for (int i = 0; i < 0x800000 / 2; i++) {
		((unsigned short*)Neo68KROM02)[i] = BITSWAP16(((unsigned short*)Neo68KROM02)[i], 4, 11, 14, 3, 1, 13, 0, 7, 2, 8, 12, 15, 10, 9, 5, 6);
	}

	for (int i = 0; i < 0x0C0000 / 2; i++) {
		((unsigned short*)Neo68KROM01)[i] = ((unsigned short*)Neo68KROM01)[0x5D0000 / 2 + BITSWAP24(i, 23, 22, 21, 20, 19, 18, 15, 2, 1, 13, 3, 0, 9, 6, 16, 4, 11, 5, 7, 12, 17, 14, 10, 8)];
	}

	for (int i = 0; i < 0x800000 / 2; i += 0x010000 / 2) {
		unsigned short nBuffer[0x010000 / 2];
		memcpy(nBuffer, &((unsigned short*)Neo68KROM02)[i], 0x010000);
		for (int j = 0; j < 0x010000 / 2; j++) {
			((unsigned short*)Neo68KROM02)[i + j] = nBuffer[BITSWAP24(j, 23, 22, 21, 20, 19, 18, 17, 16, 15, 2, 11, 0, 14, 6, 4, 13, 8, 9, 3, 10, 7, 5, 12, 1)];
		}
	}
}

void __fastcall mslug3WriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{

//	printf(" -- bankswitch: 0x%08X -> 0x%04X\n", sekAddress, wordValue);

	if (sekAddress == 0x2FFFE4) {
		static unsigned int bankoffset[64] = {
			0x000000, 0x020000, 0x040000, 0x060000, // 00
			0x070000, 0x090000, 0x0b0000, 0x0d0000, // 04
			0x0e0000, 0x0f0000, 0x120000, 0x130000, // 08
			0x140000, 0x150000, 0x180000, 0x190000, // 12
			0x1a0000, 0x1b0000, 0x1e0000, 0x1f0000, // 16
			0x200000, 0x210000, 0x240000, 0x250000, // 20
			0x260000, 0x270000, 0x2a0000, 0x2b0000, // 24
			0x2c0000, 0x2d0000, 0x300000, 0x310000, // 28
			0x320000, 0x330000, 0x360000, 0x370000, // 32
			0x380000, 0x390000, 0x3c0000, 0x3d0000, // 36
			0x400000, 0x410000, 0x440000, 0x450000, // 40
			0x460000, 0x470000, 0x4a0000, 0x4b0000, // 44
			0x4c0000, /* rest not used? */
		};

		// Unscramble bank number
		int nBank =
			(((wordValue >> 14) & 1) << 0) +
			(((wordValue >> 12) & 1) << 1) +
			(((wordValue >> 15) & 1) << 2) +
			(((wordValue >>  6) & 1) << 3) +
			(((wordValue >>  3) & 1) << 4) +
			(((wordValue >>  9) & 1) << 5);

		if (bankoffset[nBank] != nNeo68KROMBank) {
			nNeo68KROMBank = bankoffset[nBank];
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank,			  0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFFFF, SM_ROM);
		}
	}
}

static int mslug3Init()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0xAD;

//	nNeoSMARNGAddress[0] = nNeoSMARNGAddress[1] = 0;
	pNeoSMABankswitch = mslug3WriteWordBankswitch;
	pNeoInitCallback = mslug3SMADecrypt;

	return NeoInit();
}

struct BurnDriver BurnDrvmslug3 = {
	{"mslug3", "Metal Slug 3", NULL, "SNK", "Neo Geo", "2000", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, mslug3RomInfo, mslug3RomName, neogeoInputInfo, neogeoDIPInfo,
	mslug3Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Metal Slug 3 (encrypted grahics)

static struct BurnRomInfo mslug3nRomDesc[] = {
	{"256-ph1.rom",0x100000, 0x9C42CA85, 0x10}, //  0 68K code
	{"256-ph2.rom",0x400000, 0x1F3D8CE8, 0x10}, //  1

	{"256-c1.bin", 0x800000, 0x5A79C34E,    1}, //  2 Sprite data
	{"256-c2.bin", 0x800000, 0x944C362C,    1}, //  3
	{"256-c3.bin", 0x800000, 0x6E69D36F,    1}, //  4
	{"256-c4.bin", 0x800000, 0xB755B4EB,    1}, //  5
	{"256-c5.bin", 0x800000, 0x7AACAB47,    1}, //  6
	{"256-c6.bin", 0x800000, 0xC698FD5D,    1}, //  7
	{"256-c7.bin", 0x800000, 0xCFCEDDD2,    1}, //  8
	{"256-c8.bin", 0x800000, 0x4D9BE34C,    1}, //  9

	{"256-m1.bin", 0x080000, 0xEAEEC116, 0x10}, // 10 Z80 code

	{"256-v1.bin", 0x400000, 0xF2690241,    2}, // 11 Sound data
	{"256-v2.bin", 0x400000, 0x7E2A10BD,    2}, // 12
	{"256-v3.bin", 0x400000, 0x0EAEC17C,    2}, // 13
	{"256-v4.bin", 0x400000, 0x9B4B22D4,    2}, // 14
};

STDROMPICKEXT(mslug3n, mslug3n, neogeo);
STD_ROM_FN(mslug3n);

static int mslug3nInit()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0xAD;
	return NeoInit();
}

struct BurnDriver BurnDrvmslug3n = {
	{"mslug3n", "Metal Slug 3", "Non-encrypted P-ROMs", "SNK", "Neo Geo", "2000", "mslug3", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A,
	NULL, mslug3nRomInfo, mslug3nRomName, neogeoInputInfo, neogeoDIPInfo,
	mslug3nInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Mutation Nation

static struct BurnRomInfo mutnatRomDesc[] = {
	{"014-p1.bin"   , 0x080000, 0x6f1699c8, 0x10}, //  0 68K code

	{"014-s1.bin"   , 0x020000, 0x99419733,    1}, //  1 Text layer tiles

	{"014-c1.bin"   , 0x100000, 0x5e4381bf,    1}, //  2 Sprite data
	{"014-c2.bin"   , 0x100000, 0x69ba4e18,    1}, //  3
	{"014-c3.bin"   , 0x100000, 0x890327d5,    1}, //  4
	{"014-c4.bin"   , 0x100000, 0xe4002651,    1}, //  5

	{"014-m1.bin"   , 0x020000, 0xb6683092, 0x10}, //  6 Z80 code

	{"014-v1.bin"   , 0x100000, 0x25419296,    2}, //  7 Sound data
	{"014-v2.bin"   , 0x100000, 0x0de53d5e,    2}, //  8
};

STDROMPICKEXT(mutnat, mutnat, neogeo);
STD_ROM_FN(mutnat);

struct BurnDriver BurnDrvMutnat = {
	{"mutnat", "Mutation Nation", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, mutnatRomInfo, mutnatRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Nam - 1975

static struct BurnRomInfo nam1975RomDesc[] = {
	{"001-p1.bin"   , 0x080000, 0xcc9fc951, 0x10}, //  0 68K code

	{"001-s1.bin"   , 0x010000, 0x8ded55a5,    1}, //  1 Text layer tiles

	{"001-c1.bin"   , 0x080000, 0x32ea98e1,    1}, //  2 Sprite data
	{"001-c2.bin"   , 0x080000, 0xcbc4064c,    1}, //  3
	{"001-c3.bin"   , 0x080000, 0x0151054c,    1}, //  4
	{"001-c4.bin"   , 0x080000, 0x0a32570d,    1}, //  5
	{"001-c5.bin"   , 0x080000, 0x90b74cc2,    1}, //  6
	{"001-c6.bin"   , 0x080000, 0xe62bed58,    1}, //  7

	{"001-m1.bin"   , 0x010000, 0xcd088502, 0x10}, //  8 Z80 code

	{"001-v11.bin"  , 0x080000, 0xa7c3d5e5,    2}, //  9 Sound data
	{"001-v21.bin"  , 0x080000, 0x55e670b3,    2}, // 10
	{"001-v22.bin"  , 0x080000, 0xab0d8368,    2}, // 11
	{"001-v23.bin"  , 0x080000, 0xdf468e28,    2}, // 12
};

STDROMPICKEXT(nam1975, nam1975, neogeo);
STD_ROM_FN(nam1975);

struct BurnDriver BurnDrvNam1975 = {
	{"nam1975", "NAM - 1975", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, nam1975RomInfo, nam1975RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Neo-Geo Cup '98

static struct BurnRomInfo neocup98RomDesc[] = {
	{"244-p1.bin"   , 0x200000, 0xf8fdb7a5, 0x10}, //  0 68K code

	{"244-s1.bin"   , 0x020000, 0x9bddb697,    1}, //  1 Text layer tiles

	{"244-c1.bin"   , 0x800000, 0xd2c40ec7,    1}, //  3 Sprite data
	{"244-c2.bin"   , 0x800000, 0x33aa0f35,    1}, //  4

	{"244-m1.bin"   , 0x020000, 0xa701b276, 0x10}, // 11 Z80 code

	{"244-v1.bin"   , 0x400000, 0x79def46d,    2}, // 12 Sound data
	{"244-v2.bin"   , 0x200000, 0xb231902f,    2}, // 13
};

STDROMPICKEXT(neocup98, neocup98, neogeo);
STD_ROM_FN(neocup98);

struct BurnDriver BurnDrvNeocup98 = {
	{"neocup98", "Neo-Geo Cup '98: The Road to the Victory", NULL, "SNK", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, neocup98RomInfo, neocup98RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Puzzled

static struct BurnRomInfo joyjoyRomDesc[] = {
	{"021-p1.bin"   , 0x080000, 0x39c3478f, 0x10}, //  0 68K code

	{"021-s1.bin"   , 0x020000, 0x6956d778,    1}, //  1 Text layer tiles

	{"021-c1.bin"   , 0x080000, 0x509250ec,    1}, //  2 Sprite data
	{"021-c2.bin"   , 0x080000, 0x09ed5258,    1}, //  3

	{"021-m1.bin"   , 0x010000, 0x058683ec, 0x10}, //  4 Z80 code

	{"021-v1.bin"   , 0x080000, 0x66c1e5c4,    2}, //  5 Sound data
	{"021-v2.bin"   , 0x080000, 0x8ed20a86,    2}, //  6
};

STDROMPICKEXT(joyjoy, joyjoy, neogeo);
STD_ROM_FN(joyjoy);

struct BurnDriver BurnDrvJoyjoy = {
	{"joyjoy", "Puzzled", "Japanese title is Joy Joy Kid", "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, joyjoyRomInfo, joyjoyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Quiz Daisousa Sen

static struct BurnRomInfo quizdaisRomDesc[] = {
	{"023-p1.bin"   , 0x100000, 0xc488fda3, 0x10}, //  0 68K code

	{"023-s1.bin"   , 0x020000, 0xac31818a,    1}, //  1 Text layer tiles

	{"023-c1.bin"   , 0x100000, 0x2999535a,    1}, //  2 Sprite data
	{"023-c2.bin"   , 0x100000, 0x876a99e6,    1}, //  3

	{"023-m1.bin"   , 0x020000, 0x2a2105e0, 0x10}, //  4 Z80 code

	{"023-v1.bin"   , 0x100000, 0xa53e5bd3,    2}, //  5 Sound data
};

STDROMPICKEXT(quizdais, quizdais, neogeo);
STD_ROM_FN(quizdais);

struct BurnDriver BurnDrvQuizdais = {
	{"quizdais", "Quiz Daisousa Sen: The Last Count Down", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, quizdaisRomInfo, quizdaisRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Quiz Meintantei Neo Geo

static struct BurnRomInfo quizdai2RomDesc[] = {
	{"042-p1.bin"   , 0x100000, 0xed719dcf, 0x10}, //  0 68K code

	{"042-s1.bin"   , 0x020000, 0x164fd6e6,    1}, //  1 Text layer tiles

	{"042-c1.bin"   , 0x100000, 0xcb5809a1,    1}, //  2 Sprite data
	{"042-c2.bin"   , 0x100000, 0x1436dfeb,    1}, //  3
	{"042-c3.bin"   , 0x080000, 0xbcd4a518,    1}, //  4
	{"042-c4.bin"   , 0x080000, 0xd602219b,    1}, //  5

	{"042-m1.bin"   , 0x020000, 0xbb19995d, 0x10}, //  6 Z80 code

	{"042-v1.bin"   , 0x100000, 0xaf7f8247,    2}, //  7 Sound data
	{"042-v2.bin"   , 0x100000, 0xc6474b59,    2}, //  8
};

STDROMPICKEXT(quizdai2, quizdai2, neogeo);
STD_ROM_FN(quizdai2);

struct BurnDriver BurnDrvQuizdai2 = {
	{"quizdai2", "Quiz Meintantei Neo Geo: Quiz Daisousa Sen Part 2", NULL, "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, quizdai2RomInfo, quizdai2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Real Bout Fatal Fury

static struct BurnRomInfo rbff1RomDesc[] = {
	{"095-p1.bin", 0x100000, 0x63B4D8AE, 0x10}, //  0 68K code
	{"095-p2.bin", 0x200000, 0xCC15826E, 0x10}, //  1

	{"095-s1.bin", 0x020000, 0xB6BF5E08,    1}, //  2 Text layer tiles

	{"069-c1.bin", 0x400000, 0xE302F93C,    1}, //  3 Sprite data
	{"069-c2.bin", 0x400000, 0x1053A455,    1}, //  4
	{"069-c3.bin", 0x400000, 0x1C0FDE2F,    1}, //  5
	{"069-c4.bin", 0x400000, 0xA25FC3D0,    1}, //  6
	{"095-c5.bin", 0x400000, 0x8B9B65DF,    1}, //  7
	{"095-c6.bin", 0x400000, 0x3E164718,    1}, //  8
	{"095-c7.bin", 0x200000, 0xCA605E12,    1}, //  9
	{"095-c8.bin", 0x200000, 0x4E6BEB6C,    1}, // 10

	{"095-m1.bin", 0x020000, 0x653492A7, 0x10}, // 11 Z80 code

	{"069-v1.bin", 0x400000, 0x2BDBD4DB,    2}, // 10	Sound data
	{"069-v2.bin", 0x400000, 0xA698A487,    2}, // 11
	{"095-v3.bin", 0x400000, 0x189D1C6C,    2}, // 12
};

STDROMPICKEXT(rbff1, rbff1, neogeo);
STD_ROM_FN(rbff1);

struct BurnDriver BurnDrvrbff1 = {
	{"rbff1", "Real Bout Fatal Fury", "Japanese title is Real Bout Garou Densetsu", "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, rbff1RomInfo, rbff1RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Real Bout Fatal Fury Special

static struct BurnRomInfo rbffspecRomDesc[] = {
	{"223-p1.bin", 0x100000, 0xF84A2D1D, 0x10}, //  0 68K code
	{"223-p2.bin", 0x400000, 0x27E3E54B, 0x10}, //  1

	{"223-s1.bin", 0x020000, 0x7ECD6E8C,    1}, //  2 Text layer tiles

	{"223-c1.bin", 0x400000, 0x436EDAD4,    1}, //  3 Sprite data
	{"223-c2.bin", 0x400000, 0xCC7DC384,    1}, //  4
	{"223-c3.bin", 0x400000, 0x375954EA,    1}, //  5
	{"223-c4.bin", 0x400000, 0xC1A98DD7,    1}, //  6
	{"223-c5.bin", 0x400000, 0x12C5418E,    1}, //  7
	{"223-c6.bin", 0x400000, 0xC8AD71D5,    1}, //  8
	{"223-c7.bin", 0x400000, 0x5C33D1D8,    1}, //  9
	{"223-c8.bin", 0x400000, 0xEFDEB140,    1}, // 10

	{"223-m1.bin", 0x020000, 0x3FEE46BF, 0x10}, // 11 Z80 code

	{"223-v1.bin", 0x400000, 0x76673869,    2}, // 10	Sound data
	{"223-v2.bin", 0x400000, 0x7A275ACD,    2}, // 11
	{"223-v3.bin", 0x400000, 0x5A797FD2,    2}, // 12
};

STDROMPICKEXT(rbffspec, rbffspec, neogeo);
STD_ROM_FN(rbffspec);

struct BurnDriver BurnDrvrbffspec = {
	{"rbffspec", "Real Bout Fatal Fury Special", "Japanese title is Real Bout Garou Densetsu Special", "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, rbffspecRomInfo, rbffspecRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Real Bout Fatal Fury 2

static struct BurnRomInfo rbff2RomDesc[] = {
	{"240-p1.bin", 0x100000, 0xB6969780, 0x10}, //  0 68K code
	{"240-p2.bin", 0x400000, 0x960AA88D, 0x10}, //  1

	{"240-s1.bin", 0x020000, 0xDA3B40DE,    1}, //  2 Text layer tiles

	{"240-c1.bin", 0x800000, 0xEFFAC504,    1}, //  3 Sprite data
	{"240-c2.bin", 0x800000, 0xED182D44,    1}, //  4
	{"240-c3.bin", 0x800000, 0x22E0330A,    1}, //  5
	{"240-c4.bin", 0x800000, 0xC19A07EB,    1}, //  6
	{"240-c5.bin", 0x800000, 0x244DFF5A,    1}, //  7
	{"240-c6.bin", 0x800000, 0x4609E507,    1}, //  8

	{"240-m1.bin", 0x040000, 0xED482791, 0x10}, // 11 Z80 code

	{"240-v1.bin", 0x400000, 0xF796265A,    2}, // 10	Sound data
	{"240-v2.bin", 0x400000, 0x2CB3F3BB,    2}, // 11
	{"240-v3.bin", 0x400000, 0xDF77B7FA,    2}, // 12
	{"240-v4.bin", 0x400000, 0x33A356EE,    2}, // 13
};

STDROMPICKEXT(rbff2, rbff2, neogeo);
STD_ROM_FN(rbff2);

struct BurnDriver BurnDrvrbff2 = {
	{"rbff2", "Real Bout Fatal Fury 2: The Newcomers", "Japanese title is Real Bout Garou Densetsu: The Newcomers", "SNK", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, rbff2RomInfo, rbff2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Real Bout Fatal Fury 2 (alternate set)

static struct BurnRomInfo rbff2aRomDesc[] = {
	{"240-p1.rom", 0x100000, 0x80E41205, 0x10}, //  0 68K code
	{"240-p2.bin", 0x400000, 0x960AA88D, 0x10}, //  1

	{"240-s1.bin", 0x020000, 0xDA3B40DE,    1}, //  2 Text layer tiles

	{"240-c1.bin", 0x800000, 0xEFFAC504,    1}, //  3 Sprite data
	{"240-c2.bin", 0x800000, 0xED182D44,    1}, //  4
	{"240-c3.bin", 0x800000, 0x22E0330A,    1}, //  5
	{"240-c4.bin", 0x800000, 0xC19A07EB,    1}, //  6
	{"240-c5.bin", 0x800000, 0x244DFF5A,    1}, //  7
	{"240-c6.bin", 0x800000, 0x4609E507,    1}, //  8

	{"240-m1.bin", 0x040000, 0xED482791, 0x10}, // 11 Z80 code

	{"240-v1.bin", 0x400000, 0xF796265A,    2}, // 10	Sound data
	{"240-v2.bin", 0x400000, 0x2CB3F3BB,    2}, // 11
	{"240-v3.bin", 0x400000, 0xDF77B7FA,    2}, // 12
	{"240-v4.bin", 0x400000, 0x33A356EE,    2}, // 13
};

STDROMPICKEXT(rbff2a, rbff2a, neogeo);
STD_ROM_FN(rbff2a);

struct BurnDriver BurnDrvrbff2a = {
	{"rbff2a", "Real Bout Fatal Fury 2: The Newcomers", "Alternate version, Japanese title is Real Bout Garou Densetsu: The Newcomers", "SNK", "Neo Geo", "1998", "rbff2", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, rbff2aRomInfo, rbff2aRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Riding Hero

static struct BurnRomInfo ridheroRomDesc[] = {
	{"006-p1.bin"   , 0x080000, 0xd4aaf597, 0x10}, //  0 68K code

	{"006-s1.bin"   , 0x010000, 0x197d1a28,    1}, //  1 Text layer tiles

	{"006-c1.bin"   , 0x080000, 0x4a5c7f78,    1}, //  2 Sprite data
	{"006-c2.bin"   , 0x080000, 0xe0b70ece,    1}, //  3
	{"006-c3.bin"   , 0x080000, 0x8acff765,    1}, //  4
	{"006-c4.bin"   , 0x080000, 0x205e3208,    1}, //  5

	{"006-m1.bin"   , 0x020000, 0xf0b6425d, 0x10}, //  6 Z80 code

	{"006-v11.bin"  , 0x080000, 0xcdf74a42,    2}, //  7 Sound data
	{"006-v12.bin"  , 0x080000, 0xe2fd2371,    2}, //  8
	{"006-v21.bin"  , 0x080000, 0x94092bce,    2}, //  9
	{"006-v22.bin"  , 0x080000, 0x4e2cd7c3,    2}, // 10
	{"006-v23.bin"  , 0x080000, 0x069c71ed,    2}, // 11
	{"006-v24.bin"  , 0x080000, 0x89fbb825,    2}, // 12
};

STDROMPICKEXT(ridhero, ridhero, neogeo);
STD_ROM_FN(ridhero);

struct BurnDriver BurnDrvRidhero = {
	{"ridhero", "Riding Hero", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, ridheroRomInfo, ridheroRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Riding Hero (set 2)

static struct BurnRomInfo ridherohRomDesc[] = {
	{"006-p1h.bin"  , 0x080000, 0x52445646, 0x10}, //  0 68K code

	{"006-s1.bin"   , 0x010000, 0x197d1a28,    1}, //  1 Text layer tiles

	{"006-c1.bin"   , 0x080000, 0x4a5c7f78,    1}, //  2 Sprite data
	{"006-c2.bin"   , 0x080000, 0xe0b70ece,    1}, //  3
	{"006-c3.bin"   , 0x080000, 0x8acff765,    1}, //  4
	{"006-c4.bin"   , 0x080000, 0x205e3208,    1}, //  5

	{"006-m1.bin"   , 0x020000, 0xf0b6425d, 0x10}, //  6 Z80 code

	{"006-v11.bin"  , 0x080000, 0xcdf74a42,    2}, //  7 Sound data
	{"006-v12.bin"  , 0x080000, 0xe2fd2371,    2}, //  8
	{"006-v21.bin"  , 0x080000, 0x94092bce,    2}, //  9
	{"006-v22.bin"  , 0x080000, 0x4e2cd7c3,    2}, // 10
	{"006-v23.bin"  , 0x080000, 0x069c71ed,    2}, // 11
	{"006-v24.bin"  , 0x080000, 0x89fbb825,    2}, // 12
};

STDROMPICKEXT(ridheroh, ridheroh, neogeo);
STD_ROM_FN(ridheroh);

struct BurnDriver BurnDrvRidheroh = {
	{"ridheroh", "Riding Hero", "Alternate version", "SNK", "Neo Geo", "1990", "ridhero", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, ridherohRomInfo, ridherohRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Robo Army

static struct BurnRomInfo roboarmyRomDesc[] = {
	{"032-p1.bin"   , 0x080000, 0xcd11cbd4, 0x10}, //  0 68K code

	{"032-s1.bin"   , 0x020000, 0xac0daa1b,    1}, //  1 Text layer tiles

	{"032-c1.bin"   , 0x080000, 0xe17fa618,    1}, //  2 Sprite data
	{"032-c2.bin"   , 0x080000, 0xd5ebdb4d,    1}, //  3
	{"032-c3.bin"   , 0x080000, 0xaa4d7695,    1}, //  4
	{"032-c4.bin"   , 0x080000, 0x8d4ebbe3,    1}, //  5
	{"032-c5.bin"   , 0x080000, 0x40adfccd,    1}, //  6
	{"032-c6.bin"   , 0x080000, 0x462571de,    1}, //  7

	{"032-m1.bin"   , 0x020000, 0x98edc671, 0x10}, //  8 Z80 code

	{"032-v1.bin"   , 0x080000, 0xdaff9896,    2}, //  9 Sound data
	{"032-v2.bin"   , 0x080000, 0x8781b1bc,    2}, // 10
	{"032-v3.bin"   , 0x080000, 0xb69c1da5,    2}, // 11
	{"032-v4.bin"   , 0x080000, 0x2c929c17,    2}, // 12
};

STDROMPICKEXT(roboarmy, roboarmy, neogeo);
STD_ROM_FN(roboarmy);

struct BurnDriver BurnDrvRoboarmy = {
	{"roboarmy", "Robo Army", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, roboarmyRomInfo, roboarmyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Samurai Shodown

static struct BurnRomInfo samshoRomDesc[] = {
	{"045-p1.bin", 0x080000, 0x80AA6C97, 0x10}, //  0 68K code
	{"045-p2.bin", 0x080000, 0x71768728, 0x10}, //  1
	{"045-p3.bin", 0x080000, 0x38EE9bA9, 0x10}, //  2

	{"045-s1.bin", 0x020000, 0x9142A4D3,    1}, //  3 Text layer tiles

	{"045-c1.bin", 0x200000, 0x2E5873A4,    1}, //  4 Sprite data
	{"045-c2.bin", 0x200000, 0x04FEBB10,    1}, //  5
	{"045-c3.bin", 0x200000, 0xF3DABD1E,    1}, //  6
	{"045-c4.bin", 0x200000, 0x935C62F0,    1}, //  7
	{"045-c5.bin", 0x080000, 0xA2BB8284,    1}, //  8
	{"045-c6.bin", 0x080000, 0x4FA71252,    1}, //  9

	{"045-m1.bin", 0x020000, 0x95170640, 0x10}, // 10 Z80 code

	{"045-v1.bin", 0x200000, 0x37F78A9B,    2}, // 11	Sound data
	{"045-v2.bin", 0x200000, 0x568B20CF,    2}, // 12
};

STDROMPICKEXT(samsho, samsho, neogeo);
STD_ROM_FN(samsho);

struct BurnDriver BurnDrvSamSho = {
	{"samsho", "Samurai Shodown", "Japanese title is Samurai Spirits", "SNK", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, samshoRomInfo, samshoRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Samurai Shodown 2

static struct BurnRomInfo samsho2RomDesc[] = {
	{"063-p1.bin", 0x200000, 0x22368892, 0x10}, //  0 68K code

	{"063-s1.bin", 0x020000, 0x64A5CD66,    1}, //  1 Text layer tiles

	{"063-c1.bin", 0x200000, 0x86CD307C,    1}, //  2 Sprite data
	{"063-c2.bin", 0x200000, 0xCDFCC4CA,    1}, //  3
	{"063-c3.bin", 0x200000, 0x7A63CCC7,    1}, //  4
	{"063-c4.bin", 0x200000, 0x751025CE,    1}, //  5
	{"063-c5.bin", 0x200000, 0x20D3A475,    1}, //  6
	{"063-c6.bin", 0x200000, 0xAE4C0A88,    1}, //  7
	{"063-c7.bin", 0x200000, 0x2DF3CBCF,    1}, //  8
	{"063-c8.bin", 0x200000, 0x1FFC6DFA,    1}, //  9

	{"063-m1.bin", 0x020000, 0x56675098, 0x10}, // 10 Z80 code

	{"063-v1.bin", 0x200000, 0x37703F91,    2}, // 11	Sound data
	{"063-v2.bin", 0x200000, 0x0142BDE8,    2}, // 12
	{"063-v3.bin", 0x200000, 0xD07FA5CA,    2}, // 13
	{"063-v4.bin", 0x100000, 0x24AAB4BB,    2}, // 14
};

STDROMPICKEXT(samsho2, samsho2, neogeo);
STD_ROM_FN(samsho2);

struct BurnDriver BurnDrvSamSho2 = {
	{"samsho2", "Samurai Shodown II", "Japanese title is Shin Samurai Spirits: Haohmaru jigokuhen", "SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, samsho2RomInfo, samsho2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Samurai Shodown 3

static struct BurnRomInfo samsho3RomDesc[] = {
	{"087-p1.bin", 0x100000, 0x282A336E, 0x10}, //  0 68K code
	{"087-p2.bin", 0x200000, 0x9BBE27E0, 0x10}, //  1

	{"087-s1.bin", 0x020000, 0x74EC7D9F,    1}, //  2 Text layer tiles

	{"087-c1.bin", 0x400000, 0xE079F767,    1}, //  3 Sprite data
	{"087-c2.bin", 0x400000, 0xFC045909,    1}, //  4
	{"087-c3.bin", 0x400000, 0xC61218d7,    1}, //  5
	{"087-c4.bin", 0x400000, 0x054EC754,    1}, //  6
	{"087-c5.bin", 0x400000, 0x05FEEE47,    1}, //  7
	{"087-c6.bin", 0x400000, 0xEF7D9E29,    1}, //  8
	{"087-c7.bin", 0x080000, 0x7A01F666,    1}, //  9
	{"087-c8.bin", 0x080000, 0xFFd009C2,    1}, // 10

	{"087-m1.bin", 0x020000, 0x8E6440EB, 0x10}, // 11 Z80 code

	{"087-v1.bin", 0x400000, 0x84BDD9A0,    2}, // 12	Sound data
	{"087-v2.bin", 0x200000, 0xAC0F261A,    2}, // 13
};

STDROMPICKEXT(samsho3, samsho3, neogeo);
STD_ROM_FN(samsho3);

struct BurnDriver BurnDrvSamSho3 = {
	{"samsho3", "Samurai Shodown III", "Japanese title is Samurai Spirits: Zankurou Musouken", "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, samsho3RomInfo, samsho3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Samurai Shodown 4

static struct BurnRomInfo samsho4RomDesc[] = {
	{"222-p1.bin", 0x100000, 0x1A5CB56D, 0x10}, //  0 68K code
	{"222-p2.bin", 0x400000, 0x7587F09B, 0x10}, //  1

	{"222-s1.bin", 0x020000, 0x8D3D3BF9,    1}, //  2 Text layer tiles

	{"222-c1.bin", 0x400000, 0x289100FA,    1}, //  3 Sprite data
	{"222-c2.bin", 0x400000, 0xC2716EA0,    1}, //  4
	{"222-c3.bin", 0x400000, 0x6659734F,    1}, //  5
	{"222-c4.bin", 0x400000, 0x91EBEA00,    1}, //  6
	{"222-c5.bin", 0x400000, 0xE22254ED,    1}, //  7
	{"222-c6.bin", 0x400000, 0x00947b2E,    1}, //  8
	{"222-c7.bin", 0x400000, 0xE3E3b0CD,    1}, //  9
	{"222-c8.bin", 0x400000, 0xF33967F1,    1}, // 10

	{"222-m1.bin", 0x020000, 0x7615BC1B, 0x10}, // 11 Z80 code

	{"222-v1.bin", 0x400000, 0x7D6bA95F,    2}, // 12	Sound data
	{"222-v2.bin", 0x400000, 0x6C33BB5D,    2}, // 13
	{"222-v3.bin", 0x200000, 0x831EA8C0,    2}, // 14
};

STDROMPICKEXT(samsho4, samsho4, neogeo);
STD_ROM_FN(samsho4);

struct BurnDriver BurnDrvSamSho4 = {
	{"samsho4", "Samurai Shodown IV: Amakusa's Revenge", "Japanese title is Samurai Spirits: Amakusa Kourin", "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SRAM,
	NULL, samsho4RomInfo, samsho4RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Savage Reign

static struct BurnRomInfo savagereRomDesc[] = {
	{"059-p1.bin"   , 0x200000, 0x01d4e9c0, 0x10}, //  0 68K code

	{"059-s1.bin"   , 0x020000, 0xe08978ca,    1}, //  1 Text layer tiles

	{"059-c1.bin"   , 0x200000, 0x763ba611,    1}, //  2 Sprite data
	{"059-c2.bin"   , 0x200000, 0xe05e8ca6,    1}, //  3
	{"059-c3.bin"   , 0x200000, 0x3e4eba4b,    1}, //  4
	{"059-c4.bin"   , 0x200000, 0x3c2a3808,    1}, //  5
	{"059-c5.bin"   , 0x200000, 0x59013f9e,    1}, //  6
	{"059-c6.bin"   , 0x200000, 0x1c8d5def,    1}, //  7
	{"059-c7.bin"   , 0x200000, 0xc88f7035,    1}, //  8
	{"059-c8.bin"   , 0x200000, 0x484ce3ba,    1}, //  9

	{"059-m1.bin"   , 0x020000, 0x29992eba, 0x10}, // 10 Z80 code

	{"059-v1.bin"   , 0x200000, 0x530c50fd,    2}, // 11 Sound data
	{"059-v2.bin"   , 0x200000, 0xeb6f1cdb,    2}, // 12
	{"059-v3.bin"   , 0x200000, 0x7038c2f9,    2}, // 13
};

STDROMPICKEXT(savagere, savagere, neogeo);
STD_ROM_FN(savagere);

struct BurnDriver BurnDrvSavagere = {
	{"savagere", "Savage Reign", "Japanese title is Fu'un Mokushiroku: kakutou sousei", "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, savagereRomInfo, savagereRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sengoku

static struct BurnRomInfo sengokuRomDesc[] = {
	{"017-p1.bin"   , 0x080000, 0xf8a63983, 0x10}, //  0 68K code
	{"017-p2.bin"   , 0x020000, 0x3024bbb3, 0x10}, //  1

	{"017-s1.bin"   , 0x020000, 0xb246204d,    1}, //  2 Text layer tiles

	{"017-c1.bin"   , 0x100000, 0xb4eb82a1,    1}, //  3 Sprite data
	{"017-c2.bin"   , 0x100000, 0xd55c550d,    1}, //  4
	{"017-c3.bin"   , 0x100000, 0xed51ef65,    1}, //  5
	{"017-c4.bin"   , 0x100000, 0xf4f3c9cb,    1}, //  6

	{"017-m1.bin"   , 0x020000, 0x9b4f34c6, 0x10}, //  7 Z80 code

	{"017-v1.bin"   , 0x100000, 0x23663295,    2}, //  8 Sound data
	{"017-v2.bin"   , 0x100000, 0xf61e6765,    2}, //  9
};

STDROMPICKEXT(sengoku, sengoku, neogeo);
STD_ROM_FN(sengoku);

struct BurnDriver BurnDrvSengoku = {
	{"sengoku", "Sengoku", "Japanese title is Sengoku Denshou", "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, sengokuRomInfo, sengokuRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sengoku

static struct BurnRomInfo sengokhRomDesc[] = {
	{"017-p1h.bin"  , 0x080000, 0x33eccae0, 0x10}, //  0 68K code
	{"017-p2.bin"   , 0x020000, 0x3024bbb3, 0x10}, //  1

	{"017-s1.bin"   , 0x020000, 0xb246204d,    1}, //  2 Text layer tiles

	{"017-c1.bin"   , 0x100000, 0xb4eb82a1,    1}, //  3 Sprite data
	{"017-c2.bin"   , 0x100000, 0xd55c550d,    1}, //  4
	{"017-c3.bin"   , 0x100000, 0xed51ef65,    1}, //  5
	{"017-c4.bin"   , 0x100000, 0xf4f3c9cb,    1}, //  6

	{"017-m1.bin"   , 0x020000, 0x9b4f34c6, 0x10}, //  7 Z80 code

	{"017-v1.bin"   , 0x100000, 0x23663295,    2}, //  8 Sound data
	{"017-v2.bin"   , 0x100000, 0xf61e6765,    2}, //  9
};

STDROMPICKEXT(sengokh, sengokh, neogeo);
STD_ROM_FN(sengokh);

struct BurnDriver BurnDrvSengokh = {
	{"sengokh", "Sengoku", "Alternate version, Japanese title is Sengoku Denshou", "SNK", "Neo Geo", "1991", "sengoku", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, sengokhRomInfo, sengokhRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sengoku 2

static struct BurnRomInfo sengoku2RomDesc[] = {
	{"040-p1.bin"   , 0x080000, 0xcc245299, 0x10}, //  0 68K code
	{"040-p2.bin"   , 0x080000, 0x2e466360, 0x10}, //  1

	{"040-s1.bin"   , 0x020000, 0xcd9802a3,    1}, //  2 Text layer tiles

	{"040-c1.bin"   , 0x200000, 0x3cacd552,    1}, //  3 Sprite data
	{"040-c2.bin"   , 0x200000, 0xe2aadef3,    1}, //  4
	{"040-c3.bin"   , 0x200000, 0x037614d5,    1}, //  5
	{"040-c4.bin"   , 0x200000, 0xe9947e5b,    1}, //  6

	{"040-m1.bin"   , 0x020000, 0x9902dfa2, 0x10}, //  7 Z80 code

	{"040-v1.bin"   , 0x100000, 0xb3725ced,    2}, //  8 Sound data
	{"040-v2.bin"   , 0x100000, 0xb5e70a0e,    2}, //  9
	{"040-v3.bin"   , 0x100000, 0xc5cece01,    2}, // 10
};

STDROMPICKEXT(sengoku2, sengoku2, neogeo);
STD_ROM_FN(sengoku2);

struct BurnDriver BurnDrvSengoku2 = {
	{"sengoku2", "Sengoku 2", "Japanese title is Sengoku Denshou 2", "SNK", "Neo Geo", "1993", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_NEOGEO,
	NULL, sengoku2RomInfo, sengoku2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Soccer Brawl

static struct BurnRomInfo socbrawlRomDesc[] = {
	{"031-p1.bin"  , 0x080000, 0xa2801c24, 0x10}, //  0 68K code

	{"031-s1.bin"  , 0x010000, 0x2db38c3b,    1}, //  1 Text layer tiles

	{"031-c1.bin"  , 0x100000, 0xbd0a4eb8,    1}, //  2 Sprite data
	{"031-c2.bin"  , 0x100000, 0xefde5382,    1}, //  3
	{"031-c3.bin"  , 0x080000, 0x580f7f33,    1}, //  4
	{"031-c4.bin"  , 0x080000, 0xed297de8,    1}, //  5

	{"031-m1.bin"  , 0x010000, 0x2f38d5d3, 0x10}, //  6 Z80 code

	{"031-v1.bin"  , 0x100000, 0xcc78497e,    2}, //  7 Sound data
	{"031-v2.bin"  , 0x100000, 0xdda043c6,    1}, //  8
};

STDROMPICKEXT(socbrawl, socbrawl, neogeo);
STD_ROM_FN(socbrawl);

struct BurnDriver BurnDrvSocbrawl = {
	{"socbrawl", "Soccer Brawl", NULL, "SNK", "Neo Geo", "1991", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, socbrawlRomInfo, socbrawlRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Super Sidekicks

static struct BurnRomInfo ssidekiRomDesc[] = {
	{"052-p1.bin"  , 0x080000, 0x9cd97256, 0x10}, //  0 68K code

	{"052-s1.bin"  , 0x020000, 0x97689804,    1}, //  1 Text layer tiles

	{"052-c1.bin"  , 0x200000, 0x53e1c002,    1}, //  2 Sprite data
	{"052-c2.bin"  , 0x200000, 0x776a2d1f,    1}, //  3

	{"052-m1.bin"  , 0x020000, 0x49f17d2d, 0x10}, //  4 Z80 code

	{"052-v1.bin"  , 0x200000, 0x22c097a5,    2}, //  5 Sound data
};

STDROMPICKEXT(ssideki, ssideki, neogeo);
STD_ROM_FN(ssideki);

static void ssidekiPatch()
{
	*((unsigned short*)(Neo68KROM01 + 0x2240)) = 0x4E71;
}

static int ssidekiInit()
{
	pNeoInitCallback = ssidekiPatch;

	return NeoInit();
}

struct BurnDriver BurnDrvSsideki = {
	{"ssideki", "Super Sidekicks", "Japanese title is Tokuten Ou", "SNK", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, ssidekiRomInfo, ssidekiRomName, neogeoInputInfo, neogeoDIPInfo,
	ssidekiInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Super Sidekicks 2

static struct BurnRomInfo ssideki2RomDesc[] = {
	{"061-p1.bin"  , 0x100000, 0x5969e0dc, 0x10}, //  0 68K code

	{"061-s1.bin"  , 0x020000, 0x226d1b68,    1}, //  1 Text layer tiles

	{"061-c1.bin"  , 0x200000, 0xa626474f,    1}, //  2 Sprite data
	{"061-c2.bin"  , 0x200000, 0xc3be42ae,    1}, //  3
	{"061-c3.bin"  , 0x200000, 0x2a7b98b9,    1}, //  4
	{"061-c4.bin"  , 0x200000, 0xc0be9a1f,    1}, //  5

	{"061-m1.bin"  , 0x020000, 0x156f6951, 0x10}, //  6 Z80 code

	{"061-v1.bin"  , 0x200000, 0xf081c8d3,    2}, //  7 Sound data
	{"061-v2.bin"  , 0x200000, 0x7cd63302,    2}, //  8
};

STDROMPICKEXT(ssideki2, ssideki2, neogeo);
STD_ROM_FN(ssideki2);

struct BurnDriver BurnDrvSsideki2 = {
	{"ssideki2", "Super Sidekicks 2: The World Championship", "Japanese title is Tokuten Ou 2: Real Fight Football", "SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, ssideki2RomInfo, ssideki2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Super Sidekicks 3

static struct BurnRomInfo ssideki3RomDesc[] = {
	{"081-p1.bin"  , 0x200000, 0x6bc27a3d, 0x10}, //  0 68K code

	{"081-s1.bin"  , 0x020000, 0x7626da34,    1}, //  1 Text layer tiles

	{"081-c1.bin"  , 0x200000, 0x1fb68ebe,    1}, //  2 Sprite data
	{"081-c2.bin"  , 0x200000, 0xb28d928f,    1}, //  3
	{"081-c3.bin"  , 0x200000, 0x3b2572e8,    1}, //  4
	{"081-c4.bin"  , 0x200000, 0x47d26a7c,    1}, //  5
	{"081-c5.bin"  , 0x200000, 0x17d42f0d,    1}, //  6
	{"081-c6.bin"  , 0x200000, 0x6b53fb75,    1}, //  7

	{"081-m1.bin"  , 0x020000, 0x82fcd863, 0x10}, //  8 Z80 code

	{"081-v1.bin"  , 0x200000, 0x201fa1e1,    2}, //  9 Sound data
	{"081-v2.bin"  , 0x200000, 0xacf29d96,    2}, //  10
	{"081-v3.bin"  , 0x200000, 0xe524e415,    2}, //  11
};

STDROMPICKEXT(ssideki3, ssideki3, neogeo);
STD_ROM_FN(ssideki3);

struct BurnDriver BurnDrvSsideki3 = {
	{"ssideki3", "Super Sidekicks 3: The Next Glory", "Japanese title is Tokuten Ou 3: eikoue no michi", "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, ssideki3RomInfo, ssideki3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Super Sidekicks 4

static struct BurnRomInfo ssideki4RomDesc[] = {
	{"215-p1.bin"  , 0x200000, 0x519b4ba3, 0x10}, //  0 68K code

	{"215-s1.bin"  , 0x020000, 0xf0fe5c36,    1}, //  1 Text layer tiles

	{"215-c1.bin"  , 0x400000, 0x288a9225,    1}, //  2 Sprite data
	{"215-c2.bin"  , 0x400000, 0x3fc9d1c4,    1}, //  3
	{"215-c3.bin"  , 0x400000, 0xfedfaebe,    1}, //  4
	{"215-c4.bin"  , 0x400000, 0x877a5bb2,    1}, //  5
	{"215-c5.bin"  , 0x200000, 0x0c6f97ec,    1}, //  6
	{"215-c6.bin"  , 0x200000, 0x329c5e1b,    1}, //  7

	{"215-m1.bin"  , 0x020000, 0xa932081d, 0x10}, //  8 Z80 code

	{"215-v1.bin"  , 0x400000, 0xc4bfed62,    2}, //  9 Sound data
	{"215-v2.bin"  , 0x200000, 0x1bfa218b,    2}, //  10
};

STDROMPICKEXT(ssideki4, ssideki4, neogeo);
STD_ROM_FN(ssideki4);

struct BurnDriver BurnDrvSsideki4 = {
	{"ssideki4", "The Ultimate 11: SNK Football Championship", "Japanese title is Tokuten Ou: Honoo no Libero", "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPV,
	NULL, ssideki4RomInfo, ssideki4RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The Irritating Maze

static struct BurnRomInfo irrmazeRomDesc[] = {
	{"236-p1.bin"   , 0x200000, 0x6d536c6e, 0x10}, //  0 68K code

	{"236-s1.bin"   , 0x020000, 0x5d1ca640,    1}, //  1 Text layer tiles

	{"236-c1.bin"   , 0x400000, 0xc1d47902,    1}, //  2 Sprite data
	{"236-c2.bin"   , 0x400000, 0xe15f972e,    1}, //  3

	{"236-m1.bin"   , 0x020000, 0x880a1abd, 0x10}, //  4 Z80 code

	{"236-v1.bin"   , 0x200000, 0x5f89c3b4,    2}, //  5 Sound data
	{"236-v2.bin"   , 0x100000, 0x1e843567,    2}, //  6
};

STDROMPICKEXT(irrmaze, irrmaze, neotrackball)
STD_ROM_FN(irrmaze);

struct BurnDriver BurnDrvIrrmaze = {
	{"irrmaze", "The Irritating Maze", "Japanese title is Ultra Denryu Iraira Bou", "SNK / Saurus", "Neo Geo", "1997", NULL, "neogeo"},
	1, 1, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_TRACKBALL,
	NULL, irrmazeRomInfo, irrmazeRomName, neotrackballInputInfo, neotrackballDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King Of Fighters 2000 (encrypted code & grahics)

static struct BurnRomInfo kof2000RomDesc[] = {
	{"257-sma.bin",0x040000, 0x71C6E6BB, 0x10}, //  0 68K code
	{"257-p1.bin", 0x400000, 0x60947B4C, 0x10}, //  1
	{"257-p2.bin", 0x400000, 0x1B7EC415, 0x10}, //  2

	{"257-c1.bin", 0x800000, 0xCEF1CDFA,    1}, //  3 Sprite data
	{"257-c2.bin", 0x800000, 0xF7BF0003,    1}, //  4
	{"257-c3.bin", 0x800000, 0x101E6560,    1}, //  5
	{"257-c4.bin", 0x800000, 0xBD2FC1B1,    1}, //  6
	{"257-c5.bin", 0x800000, 0x89775412,    1}, //  7
	{"257-c6.bin", 0x800000, 0xFA7200D5,    1}, //  8
	{"257-c7.bin", 0x800000, 0x7DA11FE4,    1}, //  9
	{"257-c8.bin", 0x800000, 0xB1AFA60B,    1}, // 10

	{"257-m1d.bin",0x040000, 0xD404DB70, 0x10}, // 11 Z80 code (decrypted)
	{"257-m1.bin", 0x040000, 0x4B749113, 0x10}, // 11 Z80 code

	{"257-v1.bin", 0x400000, 0x17CDE847,    2}, // 12 Sound data
	{"257-v2.bin", 0x400000, 0x1aFB20FF,    2}, // 13
	{"257-v3.bin", 0x400000, 0x4605036A,    2}, // 14
	{"257-v4.bin", 0x400000, 0x764BBD6B,    2}, // 15
};

STDROMPICKEXT(kof2000, kof2000, neogeo);
STD_ROM_FN(kof2000);

static void kof2000SMADecrypt()
{
	for (int i = 0; i < 0x800000 / 2; i++) {
		((unsigned short*)Neo68KROM02)[i] = BITSWAP16(((unsigned short*)Neo68KROM02)[i], 12, 8, 11, 3, 15, 14, 7, 0, 10, 13, 6, 5, 9, 2, 1, 4);
	}

	for (int i = 0; i < 0x0C0000 / 2; i++) {
		((unsigned short*)Neo68KROM01)[i] = ((unsigned short*)Neo68KROM01)[0x73A000 / 2 + BITSWAP24(i, 23, 22, 21, 20, 19, 18, 8, 4, 15, 13, 3, 14, 16, 2, 6, 17, 7, 12, 10, 0, 5, 11, 1, 9)];
	}

	for (int i = 0; i < 0x63A000 / 2; i += 0x0800 / 2) {
		unsigned short nBuffer[0x0800 / 2];
		memcpy(nBuffer, &((unsigned short*)Neo68KROM02)[i], 0x0800);
		for (int j = 0; j < 0x0800 / 2; j++) {
			((unsigned short*)Neo68KROM02)[i + j] = nBuffer[BITSWAP24(j, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 4, 1, 3, 8, 6, 2, 7, 0, 9, 5)];
		}
	}
}

void __fastcall kof2000WriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{
	if (sekAddress == 0x2FFFEC) {
		static unsigned int bankoffset[64] = {
			0x000000, 0x100000, 0x200000, 0x300000, // 00
			0x3f7800, 0x4f7800, 0x3ff800, 0x4ff800, // 04
			0x407800, 0x507800, 0x40f800, 0x50f800, // 08
			0x416800, 0x516800, 0x41d800, 0x51d800, // 12
			0x424000, 0x524000, 0x523800, 0x623800, // 16
			0x526000, 0x626000, 0x528000, 0x628000, // 20
			0x52a000, 0x62a000, 0x52b800, 0x62b800, // 24
			0x52d000, 0x62d000, 0x52e800, 0x62e800, // 28
			0x618000, 0x619000, 0x61a000, 0x61a800, // 32
		};

		// Unscramble bank number
		int nBank =
			(((wordValue >> 15) & 1) << 0) +
			(((wordValue >> 14) & 1) << 1) +
			(((wordValue >>  7) & 1) << 2) +
			(((wordValue >>  3) & 1) << 3) +
			(((wordValue >> 10) & 1) << 4) +
			(((wordValue >>  5) & 1) << 5);

		if (bankoffset[nBank] != nNeo68KROMBank) {
			nNeo68KROMBank = bankoffset[nBank];
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank,			  0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFBFF, SM_ROM);
		}
	}
}

static int kof2000Init()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0x00;

	nNeoSMARNGAddress[0] = 0x2FFFD8; nNeoSMARNGAddress[1] = 0x2FFFDA;
	pNeoSMABankswitch = kof2000WriteWordBankswitch;
	pNeoInitCallback = kof2000SMADecrypt;

	return NeoInit();
}

struct BurnDriver BurnDrvkof2000 = {
	{"kof2000", "The King of Fighters 2000", NULL, "SNK", "Neo Geo", "2000", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_B | HARDWARE_SNK_ALTERNATE_TEXT | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, kof2000RomInfo, kof2000RomName, neogeoInputInfo, neogeoDIPInfo,
	kof2000Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King Of Fighters 2000 (encrypted grahics)

static struct BurnRomInfo kof2000nRomDesc[] = {
	{"257-p1n.bin",0x100000, 0x5F809DBE, 0x10}, //  0 68K code
	{"257-p2n.bin",0x400000, 0x693C2C5E, 0x10}, //  1

	{"257-c1.bin", 0x800000, 0xCEF1CDFA,    1}, //  2 Sprite data
	{"257-c2.bin", 0x800000, 0xF7BF0003,    1}, //  3
	{"257-c3.bin", 0x800000, 0x101E6560,    1}, //  4
	{"257-c4.bin", 0x800000, 0xBD2FC1B1,    1}, //  5
	{"257-c5.bin", 0x800000, 0x89775412,    1}, //  6
	{"257-c6.bin", 0x800000, 0xFA7200D5,    1}, //  7
	{"257-c7.bin", 0x800000, 0x7DA11FE4,    1}, //  8
	{"257-c8.bin", 0x800000, 0xB1AFA60B,    1}, //  9

	{"257-m1d.bin",0x040000, 0xD404DB70, 0x10}, // 10 Z80 code (decrypted)
	{"257-m1.bin", 0x040000, 0x4B749113, 0x10}, // 10 Z80 code

	{"257-v1.bin", 0x400000, 0x17CDE847,    2}, // 11 Sound data
	{"257-v2.bin", 0x400000, 0x1aFB20FF,    2}, // 12
	{"257-v3.bin", 0x400000, 0x4605036A,    2}, // 13
	{"257-v4.bin", 0x400000, 0x764BBD6B,    2}, // 14
};

STDROMPICKEXT(kof2000n, kof2000n, neogeo);
STD_ROM_FN(kof2000n);

static int kof2000nInit()
{
	nNeoTextROMSize = 0x080000;
	nNeoProtectionXor = 0x00;
	return NeoInit();
}

struct BurnDriver BurnDrvkof2000n = {
	{"kof2000n", "The King of Fighters 2000", "Non-encrypted P-ROMs", "SNK", "Neo Geo", "2000", "kof2000", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_B | HARDWARE_SNK_ALTERNATE_TEXT | HARDWARE_SNK_SRAM,
	NULL, kof2000nRomInfo, kof2000nRomName, neogeoInputInfo, neogeoDIPInfo,
	kof2000nInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '94

static struct BurnRomInfo kof94RomDesc[] = {
	{"055-p1.bin"   , 0x200000, 0xf10a2042, 0x10}, //  0 68K code

	{"055-s1.bin"   , 0x020000, 0x825976c1,    1}, //  1 Text layer tiles

	{"055-c1.bin"   , 0x200000, 0xb96ef460,    1}, //  2 Sprite data
	{"055-c2.bin"   , 0x200000, 0x15e096a7,    1}, //  3
	{"055-c3.bin"   , 0x200000, 0x54f66254,    1}, //  4
	{"055-c4.bin"   , 0x200000, 0x0b01765f,    1}, //  5
	{"055-c5.bin"   , 0x200000, 0xee759363,    1}, //  6
	{"055-c6.bin"   , 0x200000, 0x498da52c,    1}, //  7
	{"055-c7.bin"   , 0x200000, 0x62f66888,    1}, //  8
	{"055-c8.bin"   , 0x200000, 0xfe0a235d,    1}, //  9

	{"055-m1.bin"   , 0x020000, 0xf6e77cf5, 0x10}, // 10 Z80 code

	{"055-v1.bin"   , 0x200000, 0x8889596d,    2}, // 11 Sound data
	{"055-v2.bin"   , 0x200000, 0x25022b27,    2}, // 12
	{"055-v3.bin"   , 0x200000, 0x83cf32c0,    2}, // 13
};

STDROMPICKEXT(kof94, kof94, neogeo);
STD_ROM_FN(kof94);

struct BurnDriver BurnDrvKof94 = {
	{"kof94", "The King of Fighters '94", NULL, "SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, kof94RomInfo, kof94RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '95

static struct BurnRomInfo kof95RomDesc[] = {
	{"084-p1.bin"   , 0x200000, 0x5E54CF95, 0x10}, //  0 68K code

	{"084-s1.bin"   , 0x020000, 0xDE716f8A,    1}, //  1 Text layer tiles

	{"084-c1.bin"   , 0x400000, 0xFE087E32,    1}, //  2 Sprite data
	{"084-c2.bin"   , 0x400000, 0x07864E09,    1}, //  3
	{"084-c3.bin"   , 0x400000, 0xA4E65D1B,    1}, //  4
	{"084-c4.bin"   , 0x400000, 0xC1ACE468,    1}, //  5
	{"084-c5.bin"   , 0x200000, 0x8A2C1EDC,    1}, //  6
	{"084-c6.bin"   , 0x200000, 0xF593AC35,    1}, //  7
	{"084-c7.bin"   , 0x100000, 0x9904025F,    1}, //  8
	{"084-c8.bin"   , 0x100000, 0x78EB0F9B,    1}, //  9

	{"084-m1.bin"   , 0x020000, 0x6F2d7429, 0x10}, // 10 Z80 code

	{"084-v1.bin"   , 0x400000, 0x84861B56,    2}, // 11 Sound data
	{"084-v2.bin"   , 0x200000, 0xB38a2803,    2}, // 12
	{"084-v3.bin"   , 0x100000, 0xD683A338,    2}, // 13
};

STDROMPICKEXT(kof95, kof95, neogeo);
STD_ROM_FN(kof95);

struct BurnDriver BurnDrvKof95 = {
	{"kof95", "The King of Fighters '95", NULL, "SNK", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SRAM,
	NULL, kof95RomInfo, kof95RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '95 (alternate set)

static struct BurnRomInfo kof95aRomDesc[] = {
	{"084a-p1.bin"  , 0x200000, 0x2CBA2716, 0x10}, //  0 68K code

	{"084-s1.bin"   , 0x020000, 0xDE716f8A,    1}, //  1 Text layer tiles

	{"084-c1.bin"   , 0x400000, 0xFE087E32,    1}, //  2 Sprite data
	{"084-c2.bin"   , 0x400000, 0x07864E09,    1}, //  3
	{"084-c3.bin"   , 0x400000, 0xA4E65D1B,    1}, //  4
	{"084-c4.bin"   , 0x400000, 0xC1ACE468,    1}, //  5
	{"084-c5.bin"   , 0x200000, 0x8A2C1EDC,    1}, //  6
	{"084-c6.bin"   , 0x200000, 0xF593AC35,    1}, //  7
	{"084-c7.bin"   , 0x100000, 0x9904025F,    1}, //  8
	{"084-c8.bin"   , 0x100000, 0x78EB0F9B,    1}, //  9

	{"084-m1.bin"   , 0x020000, 0x6F2d7429, 0x10}, // 10 Z80 code

	{"084-v1.bin"   , 0x400000, 0x84861B56,    2}, // 11 Sound data
	{"084-v2.bin"   , 0x200000, 0xB38a2803,    2}, // 12
	{"084-v3.bin"   , 0x100000, 0xD683A338,    2}, // 13
};

STDROMPICKEXT(kof95a, kof95a, neogeo);
STD_ROM_FN(kof95a);

struct BurnDriver BurnDrvKof95a = {
	{"kof95a", "The King of Fighters '95", "Alternate version", "SNK", "Neo Geo", "1995", "kof95", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SRAM,
	NULL, kof95aRomInfo, kof95aRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '96

static struct BurnRomInfo kof96RomDesc[] = {
	{"214-p1.bin"   , 0x100000, 0x52755d74, 0x10}, //  0 68K code
	{"214-p2.bin"   , 0x200000, 0x002ccb73, 0x10}, //  1

	{"214-s1.bin"   , 0x020000, 0x1254cbdb,    1}, //  2 Text layer tiles

	{"214-c1.bin"   , 0x400000, 0x7ecf4aa2,    1}, //  3 Sprite data
	{"214-c2.bin"   , 0x400000, 0x05b54f37,    1}, //  4
	{"214-c3.bin"   , 0x400000, 0x64989a65,    1}, //  5
	{"214-c4.bin"   , 0x400000, 0xafbea515,    1}, //  6
	{"214-c5.bin"   , 0x400000, 0x2a3bbd26,    1}, //  7
	{"214-c6.bin"   , 0x400000, 0x44d30dc7,    1}, //  8
	{"214-c7.bin"   , 0x400000, 0x3687331b,    1}, //  9
	{"214-c8.bin"   , 0x400000, 0xfa1461ad,    1}, // 10

	{"214-m1.bin"   , 0x020000, 0xdabc427c, 0x10}, // 11 Z80 code

	{"214-v1.bin"   , 0x400000, 0x63f7b045,    2}, // 12 Sound data
	{"214-v2.bin"   , 0x400000, 0x25929059,    2}, // 13
	{"214-v3.bin"   , 0x200000, 0x92a2257d,    2}, // 14
};

STDROMPICKEXT(kof96, kof96, neogeo);
STD_ROM_FN(kof96);

struct BurnDriver BurnDrvKof96 = {
	{"kof96", "The King of Fighters '96", NULL, "SNK", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof96RomInfo, kof96RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '96 (alternate set)

static struct BurnRomInfo kof96hRomDesc[] = {
	{"214-pg1.bin"  , 0x100000, 0xbd3757c9, 0x10}, //  0 68K code
	{"214-p2.bin"   , 0x200000, 0x002ccb73, 0x10}, //  1

	{"214-s1.bin"   , 0x020000, 0x1254cbdb,    1}, //  2 Text layer tiles

	{"214-c1.bin"   , 0x400000, 0x7ecf4aa2,    1}, //  3 Sprite data
	{"214-c2.bin"   , 0x400000, 0x05b54f37,    1}, //  4
	{"214-c3.bin"   , 0x400000, 0x64989a65,    1}, //  5
	{"214-c4.bin"   , 0x400000, 0xafbea515,    1}, //  6
	{"214-c5.bin"   , 0x400000, 0x2a3bbd26,    1}, //  7
	{"214-c6.bin"   , 0x400000, 0x44d30dc7,    1}, //  8
	{"214-c7.bin"   , 0x400000, 0x3687331b,    1}, //  9
	{"214-c8.bin"   , 0x400000, 0xfa1461ad,    1}, // 10

	{"214-m1.bin"   , 0x020000, 0xdabc427c, 0x10}, // 11 Z80 code

	{"214-v1.bin"   , 0x400000, 0x63f7b045,    2}, // 12 Sound data
	{"214-v2.bin"   , 0x400000, 0x25929059,    2}, // 13
	{"214-v3.bin"   , 0x200000, 0x92a2257d,    2}, // 14
};

STDROMPICKEXT(kof96h, kof96h, neogeo);
STD_ROM_FN(kof96h);

struct BurnDriver BurnDrvKof96h = {
	{"kof96h", "The King of Fighters '96", "Alternate set", "SNK", "Neo Geo", "1996", "kof96", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof96hRomInfo, kof96hRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '97

static struct BurnRomInfo kof97RomDesc[] = {
	{"232-p1.bin"   , 0x100000, 0x7DB81AD9, 0x10}, //  0 68K code
	{"232-p2.bin"   , 0x400000, 0x158B23F6, 0x10}, //  1

	{"232-s1.bin"   , 0x020000, 0x8514ECF5,    1}, //  2 Text layer tiles

	{"232-c1.bin"   , 0x800000, 0x5F8BF0A1,    1}, //  3 Sprite data
	{"232-c2.bin"   , 0x800000, 0xE4D45C81,    1}, //  4
	{"232-c3.bin"   , 0x800000, 0x581D6618,    1}, //  5
	{"232-c4.bin"   , 0x800000, 0x49BB1E68,    1}, //  6
	{"232-c5.bin"   , 0x400000, 0x34fC4E51,    1}, //  7
	{"232-c6.bin"   , 0x400000, 0x4FF4D47B,    1}, //  8

	{"232-m1.bin"   , 0x020000, 0x45348747, 0x10}, //  9 Z80 code

	{"232-v1.bin"   , 0x400000, 0x22A2B5B5,    2}, // 10 Sound data
	{"232-v2.bin"   , 0x400000, 0x2304E744,    2}, // 11
	{"232-v3.bin"   , 0x400000, 0x759EB954,    2}, // 12
};

STDROMPICKEXT(kof97, kof97, neogeo);
STD_ROM_FN(kof97);

struct BurnDriver BurnDrvKof97 = {
	{"kof97", "The King of Fighters '97", NULL, "SNK", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof97RomInfo, kof97RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '97 (alternate version)

static struct BurnRomInfo kof97aRomDesc[] = {
	{"232-pg1.bin"  , 0x100000, 0x5C2400B7, 0x10}, //  0 68K code
	{"232-p2.bin"   , 0x400000, 0x158B23F6, 0x10}, //  1

	{"232-s1.bin"   , 0x020000, 0x8514ECF5,    1}, //  2 Text layer tiles

	{"232-c1.bin"   , 0x800000, 0x5F8BF0A1,    1}, //  3 Sprite data
	{"232-c2.bin"   , 0x800000, 0xE4D45C81,    1}, //  4
	{"232-c3.bin"   , 0x800000, 0x581D6618,    1}, //  5
	{"232-c4.bin"   , 0x800000, 0x49BB1E68,    1}, //  6
	{"232-c5.bin"   , 0x400000, 0x34fC4E51,    1}, //  7
	{"232-c6.bin"   , 0x400000, 0x4FF4D47B,    1}, //  8

	{"232-m1.bin"   , 0x020000, 0x45348747, 0x10}, //  9 Z80 code

	{"232-v1.bin"   , 0x400000, 0x22A2B5B5,    2}, // 10 Sound data
	{"232-v2.bin"   , 0x400000, 0x2304E744,    2}, // 11
	{"232-v3.bin"   , 0x400000, 0x759EB954,    2}, // 12
};

STDROMPICKEXT(kof97a, kof97a, neogeo);
STD_ROM_FN(kof97a);

struct BurnDriver BurnDrvKof97a = {
	{"kof97a", "The King of Fighters '97", "Alternate version", "SNK", "Neo Geo", "1997", "kof97", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof97aRomInfo, kof97aRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '98 (encrypted)

static struct BurnRomInfo kof98RomDesc[] = {
	{"yz98-p1.160"  , 0x200000, 0x8893DF89, 0x10}, //  0 68K code
	{"242-p2.bin"   , 0x400000, 0x980ABA4C, 0x10}, //  1

	{"242-s1.bin"   , 0x020000, 0x7F7B4805,    1}, //  2 Text layer tiles

	{"242-c1.bin"   , 0x800000, 0xE564ECd6,    1}, //  3 Sprite data
	{"242-c2.bin"   , 0x800000, 0xBD959B60,    1}, //  4
	{"242-c3.bin"   , 0x800000, 0x22127B4F,    1}, //  5
	{"242-c4.bin"   , 0x800000, 0x0B4FA044,    1}, //  6
	{"242-c5.bin"   , 0x800000, 0x9D10bED3,    1}, //  7
	{"242-c6.bin"   , 0x800000, 0xDA07B6A2,    1}, //  8
	{"242-c7.bin"   , 0x800000, 0xF6D7A38A,    1}, //  9
	{"242-c8.bin"   , 0x800000, 0xC823E045,    1}, // 10

	{"242-m1a.bin"  , 0x040000, 0x4EF7016B, 0x10}, // 11 Z80 code

	{"242-v1.bin"   , 0x400000, 0xB9EA8051,    2}, // 12 Sound data
	{"242-v2.bin"   , 0x400000, 0xCC11106E,    2}, // 13
	{"242-v3.bin"   , 0x400000, 0x044EA4E1,    2}, // 13
	{"242-v4.bin"   , 0x400000, 0x7985EA30,    2}, // 14
};

STDROMPICKEXT(kof98, kof98, neogeo);
STD_ROM_FN(kof98);

static void kof98Decrypt()
{
	int sec[] = {0x000000, 0x100000, 0x000004, 0x100004, 0x10000a, 0x00000a, 0x10000e, 0x00000e};
	int pos[] = {0x000, 0x004, 0x00a, 0x00e};

	unsigned char* pTemp = (unsigned char*)malloc(0x200000);

	if (pTemp == NULL) {
		return;
	}

	memcpy(pTemp, Neo68KROM01, 0x200000);

	for (int i = 0x0800; i < 0x100000; i += 0x0200) {
		for (int j = 0; j < 0x0100; j += 0x10) {
			for (int k = 0; k < 8; k++) {
				memcpy(&Neo68KROM01[i + j + k * 2 +      0], &pTemp[i + j + sec[k] + 0x0100], 2);
				memcpy(&Neo68KROM01[i + j + k * 2 + 0x0100], &pTemp[i + j + sec[k] +      0], 2);
			}
			if (i >= 0x080000 && i < 0x0c0000) {
				for (int k = 0; k < 4; k++) {
					memcpy(&Neo68KROM01[i + j + pos[k] +      0], &pTemp[i + j + pos[k] +      0], 2);
					memcpy(&Neo68KROM01[i + j + pos[k] + 0x0100], &pTemp[i + j + pos[k] + 0x0100], 2);
				}
			}
			if (i >= 0x0c0000) {
				for (int k = 0; k < 4; k++) {
					memcpy(&Neo68KROM01[i + j + pos[k] +      0], &pTemp[i + j + pos[k] + 0x0100], 2);
					memcpy(&Neo68KROM01[i + j + pos[k] + 0x0100], &pTemp[i + j + pos[k] +      0], 2);
				}
			}
		}

		memcpy(&Neo68KROM01[i + 0x000000], &pTemp[i + 0x000000], 2);
		memcpy(&Neo68KROM01[i + 0x000002], &pTemp[i + 0x100000], 2);
		memcpy(&Neo68KROM01[i + 0x000100], &pTemp[i + 0x000100], 2);
		memcpy(&Neo68KROM01[i + 0x000102], &pTemp[i + 0x100100], 2);
	}

	memcpy(&Neo68KROM01[0x100000], &Neo68KROM01[0x200000], 0x400000);

	free(pTemp);
}

static unsigned short nkof98Protection;

static void kof98Protection()
{
	// We need to writes because the BIOS vector block is actually 1024 bytes large
	switch (nkof98Protection) {
		case 0x0090:
			*((unsigned int*)Neo68KROM01 + 0x0100) = 0x00C200FD;
			SekWriteLongROM(0x000100, 0x00C200FD);
			break;
		case 0x00F0:
			*((unsigned int*)Neo68KROM01 + 0x0100) = 0x4E454F2D;
			SekWriteLongROM(0x000100, 0x4E454F2D);
			break;
	}
}

void __fastcall kof98WriteByteProtection(unsigned int sekAddress, unsigned char byteValue)
{
	switch (sekAddress) {
		case 0x20AAAA: {
			nkof98Protection &= 0x00FF;
			nkof98Protection |= byteValue << 8;
			kof98Protection();
		}
		case 0x20AAAB: {
			nkof98Protection &= 0xFF00;
			nkof98Protection |= byteValue;
			kof98Protection();
		}
	}
}

void __fastcall kof98WriteWordProtection(unsigned int sekAddress, unsigned short wordValue)
{
	switch (sekAddress) {
		case 0x20AAAA: {
			nkof98Protection = wordValue;
			kof98Protection();
		}
	}
}

static int kof98Init()
{
	int nRet;

	pNeoInitCallback = kof98Decrypt;

	nRet = NeoInit();

	if (nRet == 0) {
		// Install protection handler
		SekMapHandler(5,	0x200000, 0x2FFBFF, SM_WRITE);
		SekSetWriteWordHandler(5, kof98WriteWordProtection);
		SekSetWriteByteHandler(5, kof98WriteByteProtection);

		nkof98Protection = 0;
	}

	return nRet;

}

struct BurnDriver BurnDrvKof98 = {
	{"kof98", "The King of Fighters '98: The Slugfest", "Encrypted, Japanese title is King of Fighters '98: dream match never ends", "SNK", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof98RomInfo, kof98RomName, neogeoInputInfo, neogeoDIPInfo,
	kof98Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '98

static struct BurnRomInfo kof98nRomDesc[] = {
	{"242-p1.bin"   , 0x100000, 0x61AC868A, 0x10}, //  0 68K code
	{"242-p2.bin"   , 0x400000, 0x980ABA4C, 0x10}, //  1

	{"242-s1.bin"   , 0x020000, 0x7F7B4805,    1}, //  2 Text layer tiles

	{"242-c1.bin"   , 0x800000, 0xE564ECd6,    1}, //  3 Sprite data
	{"242-c2.bin"   , 0x800000, 0xBD959B60,    1}, //  4
	{"242-c3.bin"   , 0x800000, 0x22127B4F,    1}, //  5
	{"242-c4.bin"   , 0x800000, 0x0B4FA044,    1}, //  6
	{"242-c5.bin"   , 0x800000, 0x9D10bED3,    1}, //  7
	{"242-c6.bin"   , 0x800000, 0xDA07B6A2,    1}, //  8
	{"242-c7.bin"   , 0x800000, 0xF6D7A38A,    1}, //  9
	{"242-c8.bin"   , 0x800000, 0xC823E045,    1}, // 10

	{"242-m1.bin"   , 0x040000, 0x4E7A6B1B, 0x10}, // 11 Z80 code

	{"242-v1.bin"   , 0x400000, 0xB9EA8051,    2}, // 12 Sound data
	{"242-v2.bin"   , 0x400000, 0xCC11106E,    2}, // 13
	{"242-v3.bin"   , 0x400000, 0x044EA4E1,    2}, // 13
	{"242-v4.bin"   , 0x400000, 0x7985EA30,    2}, // 14
};

STDROMPICKEXT(kof98n, kof98n, neogeo);
STD_ROM_FN(kof98n);

struct BurnDriver BurnDrvKof98n = {
	{"kof98n", "The King of Fighters '98: The Slugfest", "Japanese title is King of Fighters '98: dream match never ends", "SNK", "Neo Geo", "1998", "kof98", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof98nRomInfo, kof98nRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '98 (alternate set)

static struct BurnRomInfo kof98aRomDesc[] = {
	{"242-p1.bin"   , 0x100000, 0x61AC868A, 0x10}, //  0 68K code
	{"242-p2.bin"   , 0x400000, 0x980ABA4C, 0x10}, //  1

	{"242-s1.bin"   , 0x020000, 0x7F7B4805,    1}, //  2 Text layer tiles

	{"242-c1.bin"   , 0x800000, 0xE564ECd6,    1}, //  3 Sprite data
	{"242-c2.bin"   , 0x800000, 0xBD959B60,    1}, //  4
	{"242-c3.bin"   , 0x800000, 0x22127B4F,    1}, //  5
	{"242-c4.bin"   , 0x800000, 0x0B4FA044,    1}, //  6
	{"242-c5.bin"   , 0x800000, 0x9D10bED3,    1}, //  7
	{"242-c6.bin"   , 0x800000, 0xDA07B6A2,    1}, //  8
	{"242-c7.bin"   , 0x800000, 0xF6D7A38A,    1}, //  9
	{"242-c8.bin"   , 0x800000, 0xC823E045,    1}, // 10

	{"242-m1a.bin"  , 0x040000, 0x4EF7016B, 0x10}, // 11 Z80 code

	{"242-v1.bin"   , 0x400000, 0xB9EA8051,    2}, // 12 Sound data
	{"242-v2.bin"   , 0x400000, 0xCC11106E,    2}, // 13
	{"242-v3.bin"   , 0x400000, 0x044EA4E1,    2}, // 13
	{"242-v4.bin"   , 0x400000, 0x7985EA30,    2}, // 14
};

STDROMPICKEXT(kof98a, kof98a, neogeo);
STD_ROM_FN(kof98a);

struct BurnDriverX BurnDrvKof98a = {
	{"kof98a", "The King of Fighters '98: The Slugfest", "Alternate version, Japanese title is King of Fighters '98: dream match never ends", "SNK", "Neo Geo", "1998", "kof98", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof98aRomInfo, kof98aRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99

static struct BurnRomInfo kof99RomDesc[] = {
	{"251-sma.kc", 0x040000, 0x6C9D0647, 0x10}, //  0 68K code
	{"251-p1.bin", 0x400000, 0x006e4532, 0x10}, //  1
	{"251-pg2.bin",0x400000, 0xD9057F51, 0x10}, //  2

	{"251-c1.bin", 0x800000, 0x0f9e93fe,    1}, //  3 Sprite data
	{"251-c2.bin", 0x800000, 0xe71e2ea3,    1}, //  4
	{"251-c3.bin", 0x800000, 0x238755d2,    1}, //  5
	{"251-c4.bin", 0x800000, 0x438c8b22,    1}, //  6
	{"251-c5.bin", 0x800000, 0x0b0abd0a,    1}, //  7
	{"251-c6.bin", 0x800000, 0x65bbf281,    1}, //  8
	{"251-c7.bin", 0x800000, 0xff65f62e,    1}, //  9
	{"251-c8.bin", 0x800000, 0x8d921c68,    1}, // 10

	{"251-m1.bin", 0x020000, 0x5e74539c, 0x10}, // 11 Z80 code

	{"251-v1.bin", 0x400000, 0xef2eecc8,    2}, // 12 Sound data
	{"251-v2.bin", 0x400000, 0x73e211ca,    2}, // 13
	{"251-v3.bin", 0x400000, 0x821901da,    2}, // 14
	{"251-v4.bin", 0x200000, 0xb49e6178,    2}, // 15
};

STDROMPICKEXT(kof99, kof99, neogeo);
STD_ROM_FN(kof99);

static void kof99SMADecrypt()
{
	for (int i = 0; i < 0x800000 / 2; i++) {
		((unsigned short*)Neo68KROM02)[i] = BITSWAP16(((unsigned short*)Neo68KROM02)[i], 13, 7, 3, 0, 9, 4, 5, 6, 1, 12, 8, 14, 10, 11, 2, 15);
	}

	for (int i = 0; i < 0x0C0000 / 2; i++) {
		((unsigned short*)Neo68KROM01)[i] = ((unsigned short*)Neo68KROM01)[0x700000 / 2 + BITSWAP24(i, 23, 22, 21, 20, 19, 18, 11, 6, 14, 17, 16, 5, 8, 10, 12, 0, 4, 3, 2, 7, 9, 15, 13, 1)];
	}

	for (int i = 0; i < 0x600000 / 2; i += 0x0800 / 2) {
		unsigned short nBuffer[0x0800 / 2];
		memcpy(nBuffer, &((unsigned short*)Neo68KROM02)[i], 0x0800);
		for (int j = 0; j < 0x0800 / 2; j++) {
			((unsigned short*)Neo68KROM02)[i + j] = nBuffer[BITSWAP24(j, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 6, 2, 4, 9, 8, 3, 1, 7, 0, 5)];
		}
	}
}

void __fastcall kof99WriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{
	if (sekAddress == 0x2FFFF0) {
		static unsigned int bankoffset[64] = {
			0x000000, 0x100000, 0x200000, 0x300000,
			0x3cc000, 0x4cc000, 0x3f2000, 0x4f2000,
			0x407800, 0x507800, 0x40d000, 0x50d000,
			0x417800, 0x517800, 0x420800, 0x520800,
			0x424800, 0x524800, 0x429000, 0x529000,
			0x42e800, 0x52e800, 0x431800, 0x531800,
			0x54d000, 0x551000, 0x567000, 0x592800,
			0x588800, 0x581800, 0x599800, 0x594800,
			0x200000,	/* rest not used? */
		};

		// Unscramble bank number
		int nBank =
			(((wordValue >> 14) & 1) << 0) +
			(((wordValue >>  6) & 1) << 1) +
			(((wordValue >>  8) & 1) << 2) +
			(((wordValue >> 10) & 1) << 3) +
			(((wordValue >> 12) & 1) << 4) +
			(((wordValue >>  5) & 1) << 5);

		if (bankoffset[nBank] != nNeo68KROMBank) {
			nNeo68KROMBank = bankoffset[nBank];
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank,			  0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFBFF, SM_ROM);
		}
	}
}

static int kof99Init()
{
	nNeoProtectionXor = 0x00;

	nNeoSMARNGAddress[0] = 0x2FFFF8; nNeoSMARNGAddress[1] = 0x2FFFFA;
	pNeoSMABankswitch = kof99WriteWordBankswitch;
	pNeoInitCallback = kof99SMADecrypt;

	return NeoInit();
}

struct BurnDriver BurnDrvkof99 = {
	{"kof99", "The King of Fighters '99: Millennium Battle", NULL, "SNK", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, kof99RomInfo, kof99RomName, neogeoInputInfo, neogeoDIPInfo,
	kof99Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99 (alternate set)

static struct BurnRomInfo kof99aRomDesc[] = {
	{"251-sma.ka", 0x040000, 0x7766d09e, 0x10}, //  0 68K code
	{"251-p1.bin", 0x400000, 0x006e4532, 0x10}, //  1
	{"251-p2.bin", 0x400000, 0x90175f15, 0x10}, //  2

	{"251-c1.bin", 0x800000, 0x0f9e93fe,    1}, //  3 Sprite data
	{"251-c2.bin", 0x800000, 0xe71e2ea3,    1}, //  4
	{"251-c3.bin", 0x800000, 0x238755d2,    1}, //  5
	{"251-c4.bin", 0x800000, 0x438c8b22,    1}, //  6
	{"251-c5.bin", 0x800000, 0x0b0abd0a,    1}, //  7
	{"251-c6.bin", 0x800000, 0x65bbf281,    1}, //  8
	{"251-c7.bin", 0x800000, 0xff65f62e,    1}, //  9
	{"251-c8.bin", 0x800000, 0x8d921c68,    1}, // 10

	{"251-m1.bin", 0x020000, 0x5e74539c, 0x10}, // 11 Z80 code

	{"251-v1.bin", 0x400000, 0xef2eecc8,    2}, // 12 Sound data
	{"251-v2.bin", 0x400000, 0x73e211ca,    2}, // 13
	{"251-v3.bin", 0x400000, 0x821901da,    2}, // 14
	{"251-v4.bin", 0x200000, 0xb49e6178,    2}, // 15
};

STDROMPICKEXT(kof99a, kof99a, neogeo);
STD_ROM_FN(kof99a);

struct BurnDriver BurnDrvkof99a = {
	{"kof99a", "The King of Fighters '99: Millennium Battle", "Alternate version", "SNK", "Neo Geo", "1999", "kof99", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, kof99aRomInfo, kof99aRomName, neogeoInputInfo, neogeoDIPInfo,
	kof99Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99 (earlier version)

static struct BurnRomInfo kof99eRomDesc[] = {
	{"251-sma.ka", 0x040000, 0x7766d09e, 0x10}, //  0 68K code
	{"251-ep1.p1", 0x200000, 0x1e8d692d, 0x10}, //  1
	{"251-ep2.p2", 0x200000, 0xd6206e5a, 0x10}, //  2
	{"251-ep3.p3", 0x200000, 0xd58c3ef8, 0x10}, //  3
	{"251-ep4.p4", 0x200000, 0x52de02ae, 0x10}, //  4

	{"251-c1.bin", 0x800000, 0x0f9e93fe,    1}, //  5 Sprite data
	{"251-c2.bin", 0x800000, 0xe71e2ea3,    1}, //  6
	{"251-c3.bin", 0x800000, 0x238755d2,    1}, //  7
	{"251-c4.bin", 0x800000, 0x438c8b22,    1}, //  8
	{"251-c5.bin", 0x800000, 0x0b0abd0a,    1}, //  9
	{"251-c6.bin", 0x800000, 0x65bbf281,    1}, // 10
	{"251-c7.bin", 0x800000, 0xff65f62e,    1}, // 11
	{"251-c8.bin", 0x800000, 0x8d921c68,    1}, // 12

	{"251-m1.bin", 0x020000, 0x5e74539c, 0x10}, // 13 Z80 code

	{"251-v1.bin", 0x400000, 0xef2eecc8,    2}, // 14 Sound data
	{"251-v2.bin", 0x400000, 0x73e211ca,    2}, // 15
	{"251-v3.bin", 0x400000, 0x821901da,    2}, // 16
	{"251-v4.bin", 0x200000, 0xb49e6178,    2}, // 17
};

STDROMPICKEXT(kof99e, kof99e, neogeo);
STD_ROM_FN(kof99e);

struct BurnDriver BurnDrvkof99e = {
	{"kof99e", "The King of Fighters '99: Millennium Battle", "Earlier version", "SNK", "Neo Geo", "1999", "kof99", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, kof99eRomInfo, kof99eRomName, neogeoInputInfo, neogeoDIPInfo,
	kof99Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99 (not encrypted)

static struct BurnRomInfo kof99nRomDesc[] = {
	{"152-p1.bin", 0x100000, 0xF2C7DDFA, 0x10}, //  0 68K code
	{"152-p2.bin", 0x400000, 0x274EF47A, 0x10}, //  1

	{"251-c1.bin", 0x800000, 0x0F9E93FE,    1}, //  2 Sprite data
	{"251-c2.bin", 0x800000, 0xE71E2EA3,    1}, //  3
	{"251-c3.bin", 0x800000, 0x238755D2,    1}, //  4
	{"251-c4.bin", 0x800000, 0x438C8B22,    1}, //  5
	{"251-c5.bin", 0x800000, 0x0B0ABD0A,    1}, //  6
	{"251-c6.bin", 0x800000, 0x65BBF281,    1}, //  7
	{"251-c7.bin", 0x800000, 0xFF65F62E,    1}, //  8
	{"251-c8.bin", 0x800000, 0x8D921C68,    1}, //  9

	{"251-m1.bin", 0x020000, 0x5E74539C, 0x10}, // 10 Z80 code

	{"251-v1.bin", 0x400000, 0xEF2EECC8,    2}, // 11 Sound data
	{"251-v2.bin", 0x400000, 0x73E211CA,    2}, // 12
	{"251-v3.bin", 0x400000, 0x821901DA,    2}, // 13
	{"251-v4.bin", 0x200000, 0xB49E6178,    2}, // 14
};

STDROMPICKEXT(kof99n, kof99n, neogeo);
STD_ROM_FN(kof99n);

static int kof99nInit()
{
	nNeoProtectionXor = 0x00;
	return NeoInit();
}

struct BurnDriver BurnDrvkof99n = {
	{"kof99n", "The King of Fighters '99: Millennium Battle", "Non-encrypted P-ROMs", "SNK", "Neo Geo", "1999", "kof99", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM,
	NULL, kof99nRomInfo, kof99nRomName, neogeoInputInfo, neogeoDIPInfo,
	kof99nInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99 - Millennium Battle (prototype)

static struct BurnRomInfo kof99pRomDesc[] = {
	{"251-p1p.bin"  , 0x100000, 0xf37929c4, 0x10}, //  0 68K code
	{"251-p2p.bin"  , 0x400000, 0x739742ad, 0x10}, //  1

	{"251-s1p.bin"  , 0x020000, 0xfb1498ed,    1}, //  2 Text layer tiles

	{"251-c1p.bin"  , 0x800000, 0xe5d8ffa4,    1}, //  3 Sprite data
	{"251-c2p.bin"  , 0x800000, 0xd822778f,    1}, //  4
	{"251-c3p.bin"  , 0x800000, 0xf20959e8,    1}, //  5
	{"251-c4p.bin"  , 0x800000, 0x54ffbe9f,    1}, //  6
	{"251-c5p.bin"  , 0x800000, 0xd87a3bbc,    1}, //  7
	{"251-c6p.bin"  , 0x800000, 0x4d40a691,    1}, //  8
	{"251-c7p.bin"  , 0x800000, 0xa4479a58,    1}, //  9
	{"251-c8p.bin"  , 0x800000, 0xead513ce,    1}, // 10

	{"251-m1.bin"   , 0x020000, 0x5e74539c, 0x10}, // 11 Z80 code

	{"251-v1.bin"   , 0x400000, 0xeF2eecc8,    2}, // 12 Sound data
	{"251-v2.bin"   , 0x400000, 0x73e211ca,    2}, // 13
	{"251-v3.bin"   , 0x400000, 0x821901da,    2}, // 14
	{"251-v4.bin"   , 0x200000, 0xb49e6178,    2}, // 15
};

STDROMPICKEXT(kof99p, kof99p, neogeo);
STD_ROM_FN(kof99p);

struct BurnDriver BurnDrvkof99p = {
	{"kof99p", "The King of Fighters '99: Millennium Battle", NULL, "SNK", "Neo Geo", "1999", "kof99", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE | BDF_PROTOTYPE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof99pRomInfo, kof99pRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The Last Blade

static struct BurnRomInfo lastbladRomDesc[] = {
	{"234-p1.bin", 0x100000, 0xCD01C06D, 0x10}, //  0 68K code
	{"234-p2.bin", 0x400000, 0x0FDC289E, 0x10}, //  1

	{"234-s1.bin", 0x020000, 0x95561412,    1}, //  2 Text layer tiles

	{"234-c1.bin", 0x800000, 0x9F7E2BD3,    1}, //  3 Sprite data
	{"234-c2.bin", 0x800000, 0x80623D3C,    1}, //  4
	{"234-c3.bin", 0x800000, 0x91AB1A30,    1}, //  5
	{"234-c4.bin", 0x800000, 0x3D60b037,    1}, //  6
	{"234-c5.bin", 0x200000, 0x17BBD7CA,    1}, //  7
	{"234-c6.bin", 0x200000, 0x5C35d541,    1}, //  8

	{"234-m1.bin", 0x020000, 0x087628EA, 0x10}, //  9 Z80 code

	{"234-v1.bin", 0x400000, 0xED66B76F,    2}, // 10 Sound data
	{"234-v2.bin", 0x400000, 0xA0e7F6E2,    2}, // 11
	{"234-v3.bin", 0x400000, 0xA506E1E2,    2}, // 12
	{"234-v4.bin", 0x200000, 0x13583C4B,    2}, // 13
};

STDROMPICKEXT(lastblad, lastblad, neogeo);
STD_ROM_FN(lastblad);

struct BurnDriver BurnDrvlastblad = {
	{"lastblad", "The Last Blade", "Japanese title is Bakumatsu Roman: Gekkano Kenshi", "SNK", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, lastbladRomInfo, lastbladRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The Last Blade (alternate set)

static struct BurnRomInfo lastbldaRomDesc[] = {
	{"234-p1.rom", 0x100000, 0xE123A5A3, 0x10}, //  0 68K code
	{"234-p2.bin", 0x400000, 0x0FDC289E, 0x10}, //  1

	{"234-s1.bin", 0x020000, 0x95561412,    1}, //  2 Text layer tiles

	{"234-c1.bin", 0x800000, 0x9F7E2BD3,    1}, //  3 Sprite data
	{"234-c2.bin", 0x800000, 0x80623D3C,    1}, //  4
	{"234-c3.bin", 0x800000, 0x91AB1A30,    1}, //  5
	{"234-c4.bin", 0x800000, 0x3D60b037,    1}, //  6
	{"234-c5.bin", 0x200000, 0x17BBD7CA,    1}, //  7
	{"234-c6.bin", 0x200000, 0x5C35d541,    1}, //  8

	{"234-m1.bin", 0x020000, 0x087628EA, 0x10}, //  9 Z80 code

	{"234-v1.bin", 0x400000, 0xED66B76F,    2}, // 10 Sound data
	{"234-v2.bin", 0x400000, 0xA0e7F6E2,    2}, // 11
	{"234-v3.bin", 0x400000, 0xA506E1E2,    2}, // 12
	{"234-v4.bin", 0x200000, 0x13583C4B,    2}, // 13
};

STDROMPICKEXT(lastblda, lastblda, neogeo);
STD_ROM_FN(lastblda);

struct BurnDriver BurnDrvlastblda = {
	{"lastblda", "The Last Blade", "Alternate version, Japanese title is Bakumatsu Roman: Gekkano Kenshi", "SNK", "Neo Geo", "1997", "lastblad", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, lastbldaRomInfo, lastbldaRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The Last Blade 2

static struct BurnRomInfo lastbld2RomDesc[] = {
	{"243-p1.bin", 0x100000, 0xAF1E6554, 0x10}, //  0 68K code
	{"243-p2.bin", 0x400000, 0xADD4A30B, 0x10}, //  1

	{"243-s1.bin", 0x020000, 0xC9CD2298,    1}, //  2 Text layer tiles

	{"243-c1.bin", 0x800000, 0x5839444D,    1}, //  3 Sprite data
	{"243-c2.bin", 0x800000, 0xDD087428,    1}, //  4
	{"243-c3.bin", 0x800000, 0x6054CBE0,    1}, //  5
	{"243-c4.bin", 0x800000, 0x8BD2A9D2,    1}, //  6
	{"243-c5.bin", 0x800000, 0x6A503DCF,    1}, //  7
	{"243-c6.bin", 0x800000, 0xEC9C36D0,    1}, //  8

	{"243-m1.bin", 0x020000, 0xACF12D10, 0x10}, //  9 Z80 code

	{"243-v1.bin", 0x400000, 0xF7EE6FBB,    2}, // 10 Sound data
	{"243-v2.bin", 0x400000, 0xAA9E4DF6,    2}, // 11
	{"243-v3.bin", 0x400000, 0x4AC750B2,    2}, // 12
	{"243-v4.bin", 0x400000, 0xF5C64BA6,    2}, // 13
};

STDROMPICKEXT(lastbld2, lastbld2, neogeo);
STD_ROM_FN(lastbld2);

struct BurnDriver BurnDrvlastbld2 = {
	{"lastbld2", "The Last Blade 2", "Japanese title is Bakumatsu Roman: Dai Ni Maku Gekkano Kenshi", "SNK", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, lastbld2RomInfo, lastbld2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The Super Spy

static struct BurnRomInfo superspyRomDesc[] = {
	{"011-p1.bin"   , 0x080000, 0xc7f944b5, 0x10}, //  0 68K code
	{"011-p2.bin"   , 0x020000, 0x811a4faf, 0x10}, //  1

	{"011-s1.bin"   , 0x020000, 0xec5fdb96,    1}, //  2 Text layer tiles

	{"011-c1.bin"   , 0x100000, 0xcae7be57,    1}, //  3 Sprite data
	{"011-c2.bin"   , 0x100000, 0x9e29d986,    1}, //  4
	{"011-c3.bin"   , 0x100000, 0x14832ff2,    1}, //  5
	{"011-c4.bin"   , 0x100000, 0xb7f63162,    1}, //  6

	{"011-m1.bin"   , 0x020000, 0xd59d5d12, 0x10}, //  7 Z80 code

	{"011-v11.bin"  , 0x100000, 0x5c674d5c,    2}, //  8 Sound data
	{"011-v12.bin"  , 0x100000, 0x7df8898b,    2}, //  9
	{"011-v21.bin"  , 0x100000, 0x1ebe94c7,    2}, // 10
};

STDROMPICKEXT(superspy, superspy, neogeo);
STD_ROM_FN(superspy);

struct BurnDriver BurnDrvSuperspy = {
	{"superspy", "The Super Spy", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, superspyRomInfo, superspyRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Top Hunter

static struct BurnRomInfo tophuntrRomDesc[] = {
	{"046-p1.bin"  , 0x100000, 0x69FA9E29, 0x10}, //  0 68K code
	{"046-p2.sp2"  , 0x100000, 0xF182CB3E, 0x10}, //  1

	{"046-s1.bin"  , 0x020000, 0x14B01D7B,    1}, //  2 Text layer tiles

	{"046-c1.bin"  , 0x100000, 0xFA720A4A,    1}, //  3 Sprite data
	{"046-c2.bin"  , 0x100000, 0xC900C205,    1}, //  4
	{"046-c3.bin"  , 0x100000, 0x880E3C25,    1}, //  5
	{"046-c4.bin"  , 0x100000, 0x7A2248AA,    1}, //  6
	{"046-c5.bin"  , 0x100000, 0x4B735E45,    1}, //  7
	{"046-c6.bin"  , 0x100000, 0x273171DF,    1}, //  8
	{"046-c7.bin"  , 0x100000, 0x12829C4C,    1}, //  9
	{"046-c8.bin"  , 0x100000, 0xC944E03D,    1}, // 10

	{"046-m1.bin"  , 0x020000, 0x3F84BB9f, 0x10}, // 11 Z80 code

	{"046-v1.bin"  , 0x100000, 0xC1F9C2DB,    2}, // 12 Sound data
	{"046-v2.bin"  , 0x100000, 0x56254A64,    2}, // 13
	{"046-v3.bin"  , 0x100000, 0x58113FB1,    2}, // 14
	{"046-v4.bin"  , 0x100000, 0x4F54C187,    2}, // 15
};

STDROMPICKEXT(tophuntr, tophuntr, neogeo);
STD_ROM_FN(tophuntr);

struct BurnDriver BurnDrvtophntr = {
	{"tophuntr", "Top Hunter: Roddy & Cathy", NULL, "SNK", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM | HARDWARE_SNK_SWAPP,
	NULL, tophuntrRomInfo, tophuntrRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Top Player's Golf

static struct BurnRomInfo tpgolfRomDesc[] = {
	{"003-p1.bin"  , 0x080000, 0xf75549ba, 0x10}, //  0 68K code
	{"003-p2.bin"  , 0x080000, 0xb7809a8f, 0x10}, //  1

	{"003-s1.bin"  , 0x020000, 0x7b3eb9b1,    1}, //  2 Text layer tiles

	{"003-c1.bin"  , 0x080000, 0x0315fbaf,    1}, //  3 Sprite data
	{"003-c2.bin"  , 0x080000, 0xb4c15d59,    1}, //  4
	{"003-c3.bin"  , 0x080000, 0xb09f1612,    1}, //  5
	{"003-c4.bin"  , 0x080000, 0x150ea7a1,    1}, //  6
	{"003-c5.bin"  , 0x080000, 0x9a7146da,    1}, //  7
	{"003-c6.bin"  , 0x080000, 0x1e63411a,    1}, //  8
	{"003-c7.bin"  , 0x080000, 0x2886710c,    1}, //  9
	{"003-c8.bin"  , 0x080000, 0x422af22d,    1}, // 10

	{"003-m1.bin"  , 0x010000, 0x7851d0d9, 0x10}, // 11 Z80 code

	{"003-v11.bin" , 0x080000, 0xff97f1cb,    2}, // 12 Sound data
	{"003-v21.bin" , 0x080000, 0xd34960c6,    2}, // 13
	{"003-v22.bin" , 0x080000, 0x9a5f58d4,    2}, // 14
	{"003-v23.bin" , 0x080000, 0x30f53e54,    2}, // 15
	{"003-v24.bin" , 0x080000, 0x5ba0f501,    2}, // 16
};

STDROMPICKEXT(tpgolf, tpgolf, neogeo);
STD_ROM_FN(tpgolf);

struct BurnDriver BurnDrvTpgolf = {
	{"tpgolf", "Top Player's Golf", NULL, "SNK", "Neo Geo", "1990", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, tpgolfRomInfo, tpgolfRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sunsoft

// Galaxy Fight

static struct BurnRomInfo galaxyfgRomDesc[] = {
	{"078-p1.bin"  , 0x200000, 0x45906309, 0x10}, //  0 68K code

	{"078-s1.bin"  , 0x020000, 0x72f8923e,    1}, //  1 Text layer tiles

	{"078-c1.bin"  , 0x200000, 0xc890c7c0,    1}, //  2 Sprite data
	{"078-c2.bin"  , 0x200000, 0xb6d25419,    1}, //  3
	{"078-c3.bin"  , 0x200000, 0x9d87e761,    1}, //  4
	{"078-c4.bin"  , 0x200000, 0x765d7cb8,    1}, //  5
	{"078-c5.bin"  , 0x200000, 0xe6b77e6a,    1}, //  6
	{"078-c6.bin"  , 0x200000, 0xd779a181,    1}, //  7
	{"078-c7.bin"  , 0x100000, 0x4f27d580,    1}, //  8
	{"078-c8.bin"  , 0x100000, 0x0a7cc0d8,    1}, //  9

	{"078-m1.bin"  , 0x020000, 0x8e9e3b10, 0x10}, // 10 Z80 code

	{"078-v1.bin"  , 0x200000, 0xe3b735ac,    2}, // 11	Sound data
	{"078-v2.bin"  , 0x200000, 0x6a8e78c2,    2}, // 12
	{"078-v3.bin"  , 0x100000, 0x70bca656,    2}, // 13
};

STDROMPICKEXT(galaxyfg, galaxyfg, neogeo);
STD_ROM_FN(galaxyfg);

struct BurnDriver BurnDrvGalaxyfg = {
	{"galaxyfg", "Galaxy Fight: Universal Warriors", NULL, "Sunsoft", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, galaxyfgRomInfo, galaxyfgRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Waku Waku 7

static struct BurnRomInfo wakuwak7RomDesc[] = {
	{"225-p1.bin"  , 0x100000, 0xb14da766, 0x10}, //  0 68K code
	{"225-p2.bin"  , 0x200000, 0xfe190665, 0x10}, //  1

	{"225-s1.bin"  , 0x020000, 0x71c4b4b5,    1}, //  2 Text layer tiles

	{"225-c1.bin"  , 0x400000, 0xd91d386f,    1}, //  3 Sprite data
	{"225-c2.bin"  , 0x400000, 0x36b5cf41,    1}, //  4
	{"225-c3.bin"  , 0x400000, 0x02fcff2f,    1}, //  5
	{"225-c4.bin"  , 0x400000, 0xcd7f1241,    1}, //  6
	{"225-c5.bin"  , 0x400000, 0x03d32f25,    1}, //  7
	{"225-c6.bin"  , 0x400000, 0xd996a90a,    1}, //  8

	{"225-m1.bin"  , 0x020000, 0x0634bba6, 0x10}, //  9 Z80 code

	{"225-v1.bin"  , 0x400000, 0x6195c6b4,    2}, // 10	Sound data
	{"225-v2.bin"  , 0x400000, 0x6159c5fe,    2}, // 11
};

STDROMPICKEXT(wakuwak7, wakuwak7, neogeo);
STD_ROM_FN(wakuwak7);

struct BurnDriver BurnDrvWakuwak7 = {
	{"wakuwak7", "Waku Waku 7", NULL, "Sunsoft", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, wakuwak7RomInfo, wakuwak7RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sammy

// Viewpoint

static struct BurnRomInfo viewpoinRomDesc[] = {
	{"051-p1.bin"  , 0x100000, 0x17aa899d, 0x10}, //  0 68K code

	{"051-s1.bin"  , 0x010000, 0x6d0f146a,    1}, //  1 Text layer tiles

	{"051-c1.bin"  , 0x200000, 0xd624c132,    1}, //  2 Sprite data
	{"051-c2.bin"  , 0x200000, 0x40d69f1e,    1}, //  3

	{"051-m1.bin"  , 0x010000, 0xd57bd7af, 0x10}, //  4 Z80 code

	{"051-v1.bin"  , 0x200000, 0x019978b6,    2}, //  5 Sound data
	{"051-v2.bin"  , 0x200000, 0x5758f38c,    2}, //  6
};

STDROMPICKEXT(viewpoin, viewpoin, neogeo);
STD_ROM_FN(viewpoin);

struct BurnDriver BurnDrvViewpoin = {
	{"viewpoin", "Viewpoint", NULL, "Sammy", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, viewpoinRomInfo, viewpoinRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Taito

// Puzzle Bobble

static struct BurnRomInfo pbobblenRomDesc[] = {
	{"083-p1.bin"  , 0x040000, 0x7c3c34e1, 0x10}, //  0 68K code

	{"083-s1.bin"  , 0x020000, 0x9caae538,    1}, //  1 Text layer tiles

	{"083-c5.bin"  , 0x080000, 0xe89ad494,    1}, //  2 Sprite data
	{"083-c6.bin"  , 0x080000, 0x4b42d7eb,    1}, //  3

	{"083-m1.bin"  , 0x010000, 0x129e6054, 0x10}, //  4 Z80 code

	{"083-v3.bin"  , 0x100000, 0x0840cbc4,    2}, //  5	Sound data
	{"083-v4.bin"  , 0x080000, 0x0a548948,    2}, //  6
};

STDROMPICKEXT(pbobblen, pbobblen, neogeo);
STD_ROM_FN(pbobblen);

struct BurnDriver BurnDrvPbobblen = {
	{"pbobblen", "Puzzle Bobble", "Japanese title is Bust-A-Move", "Taito", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, pbobblenRomInfo, pbobblenRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Puzzle Bobble (alternate set)

static struct BurnRomInfo pbobblenaRomDesc[] = {
	{"083-p1.rom"  , 0x040000, 0xd6efe86f, 0x10}, //  0 68K code

	{"083-s1.bin"  , 0x020000, 0x9caae538,    1}, //  1 Text layer tiles

	{"083-c5.bin"  , 0x080000, 0xe89ad494,    1}, //  2 Sprite data
	{"083-c6.bin"  , 0x080000, 0x4b42d7eb,    1}, //  3

	{"083-m1.bin"  , 0x010000, 0x129e6054, 0x10}, //  4 Z80 code

	{"083-v3.bin"  , 0x100000, 0x0840cbc4,    2}, //  5	Sound data
	{"083-v4.bin"  , 0x080000, 0x0a548948,    2}, //  6
};

STDROMPICKEXT(pbobblena, pbobblena, neogeo);
STD_ROM_FN(pbobblena);

struct BurnDriver BurnDrvPbobblena = {
	{"pbobblena", "Puzzle Bobble", "Alternate set, Japanese title is Bust-A-Move", "Taito", "Neo Geo", "1994", "pbobblen", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, pbobblenaRomInfo, pbobblenaRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Puzzle Bobble 2

static struct BurnRomInfo pbobbl2nRomDesc[] = {
	{"248-p1.bin"  , 0x100000, 0x9d6c0754, 0x10}, //  0 68K code

	{"248-s1.bin"  , 0x020000, 0x0a3fee41,    1}, //  1 Text layer tiles

	{"248-c1.bin"  , 0x400000, 0xd9115327,    1}, //  2 Sprite data
	{"248-c2.bin"  , 0x400000, 0x77f9fdac,    1}, //  3
	{"248-c3.bin"  , 0x100000, 0x8890bf7c,    1}, //  4
	{"248-c4.bin"  , 0x100000, 0x8efead3f,    1}, //  5

	{"248-m1.bin"  , 0x020000, 0x883097a9, 0x10}, //  6 Z80 code

	{"248-v1.bin"  , 0x400000, 0x57fde1fa,    2}, //  7	Sound data
	{"248-v2.bin"  , 0x400000, 0x4b966ef3,    2}, //  8
};

STDROMPICKEXT(pbobbl2n, pbobbl2n, neogeo);
STD_ROM_FN(pbobbl2n);

struct BurnDriver BurnDrvPbobbl2n = {
	{"pbobbl2n", "Puzzle Bobble 2", "Japanese title is Bust-A-Move Again", "Taito", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, pbobbl2nRomInfo, pbobbl2nRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Puzzle De Pon

static struct BurnRomInfo puzzledpRomDesc[] = {
	{"202-p1.bin"  , 0x080000, 0x2b61415b, 0x10}, //  0 68K code

	{"202-s1.bin"  , 0x010000, 0x4a421612,    1}, //  1 Text layer tiles

	{"202-c1.bin"  , 0x100000, 0xcc0095ef,    1}, //  2 Sprite data
	{"202-c2.bin"  , 0x100000, 0x42371307,    1}, //  3

	{"202-m1.bin"  , 0x020000, 0x9c0291ea, 0x10}, //  4 Z80 code

	{"202-v1.bin"  , 0x080000, 0xdebeb8fb,    2}, //  5 Sound data
};

STDROMPICKEXT(puzzledp, puzzledp, neogeo);
STD_ROM_FN(puzzledp);

struct BurnDriver BurnDrvPuzzledp = {
	{"puzzledp", "Puzzle De Pon", NULL, "Taito (Visco license)", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, puzzledpRomInfo, puzzledpRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Puzzle De Pon R

static struct BurnRomInfo puzzldprRomDesc[] = {
	{"235-p1.bin"  , 0x080000, 0xafed5de2, 0x10}, //  0 68K code

	{"235-s1.bin"  , 0x010000, 0x5a68d91e,    1}, //  1 Text layer tiles

	{"202-c1.bin"  , 0x100000, 0xcc0095ef,    1}, //  2 Sprite data
	{"202-c2.bin"  , 0x100000, 0x42371307,    1}, //  3

	{"202-m1.bin"  , 0x020000, 0x9c0291ea, 0x10}, //  4 Z80 code

	{"202-v1.bin"  , 0x080000, 0xdebeb8fb,    2}, //  5 Sound data
};

STDROMPICKEXT(puzzldpr, puzzldpr, neogeo);
STD_ROM_FN(puzzldpr);

struct BurnDriver BurnDrvPuzzldpr = {
	{"puzzldpr", "Puzzle De Pon R", NULL, "Taito (Visco license)", "Neo Geo", "1997", "puzzledp", "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, puzzldprRomInfo, puzzldprRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};


// Takara

// Chibi Marukochan Deluxe Quiz

static struct BurnRomInfo marukodqRomDesc[] = {
	{"206-p1.bin"  , 0x100000, 0xc33ed21e, 0x10}, //  0 68K code

	{"206-s1.bin"  , 0x008000, 0x3b52a219,    1}, //  1 Text layer tiles

	{"206-c1.bin"  , 0x400000, 0x4bd5e70f,    1}, //  2 Sprite data
	{"206-c2.bin"  , 0x400000, 0x67dbe24d,    1}, //  3
	{"206-c3.bin"  , 0x100000, 0x79aa2b48,    1}, //  4
	{"206-c4.bin"  , 0x100000, 0x55e1314d,    1}, //  5

	{"206-m1.bin"  , 0x020000, 0x0e22902e, 0x10}, //  6 Z80 code

	{"206-v1.bin"  , 0x200000, 0x5385eca8,    2}, //  7 Sound data
	{"206-v2.bin"  , 0x200000, 0xf8c55404,    2}, //  8
};

STDROMPICKEXT(marukodq, marukodq, neogeo);
STD_ROM_FN(marukodq);

struct BurnDriver BurnDrvMarukodq = {
	{"marukodq", "Chibi Marukochan Deluxe Quiz", NULL, "Takara", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, marukodqRomInfo, marukodqRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Technos

// Double Dragon

static struct BurnRomInfo doubledrRomDesc[] = {
	{"082-p1.bin"  , 0x200000, 0x34ab832a, 0x10}, //  0 68K code

	{"082-s1.bin"  , 0x020000, 0xbef995c5,    1}, //  1 Text layer tiles

	{"082-c1.bin"  , 0x200000, 0xb478c725,    1}, //  2 Sprite data
	{"082-c2.bin"  , 0x200000, 0x2857da32,    1}, //  3
	{"082-c3.bin"  , 0x200000, 0x8b0d378e,    1}, //  4
	{"082-c4.bin"  , 0x200000, 0xc7d2f596,    1}, //  5
	{"082-c5.bin"  , 0x200000, 0xec87bff6,    1}, //  6
	{"082-c6.bin"  , 0x200000, 0x844a8a11,    1}, //  7
	{"082-c7.bin"  , 0x100000, 0x727c4d02,    1}, //  8
	{"082-c8.bin"  , 0x100000, 0x69a5fa37,    1}, //  9

	{"082-m1.bin"  , 0x020000, 0x10b144de, 0x10}, // 10 Z80 code

	{"082-v1.bin"  , 0x200000, 0xcc1128e4,    2}, // 11 Sound data
	{"082-v2.bin"  , 0x200000, 0xc3ff5554,    2}, // 12
};

STDROMPICKEXT(doubledr, doubledr, neogeo);
STD_ROM_FN(doubledr);

struct BurnDriver BurnDrvDoubledr = {
	{"doubledr", "Double Dragon", NULL, "Technos", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, doubledrRomInfo, doubledrRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Super Dodge Ball

static struct BurnRomInfo sdodgebRomDesc[] = {
	{"208-p1.bin"  , 0x200000, 0x127f3d32, 0x10}, //  0 68K code

	{"208-s1.bin"  , 0x020000, 0x64abd6b3,    1}, //  1 Text layer tiles

	{"208-c1.bin"  , 0x400000, 0x93d8619b,    1}, //  2 Sprite data
	{"208-c2.bin"  , 0x400000, 0x1c737bb6,    1}, //  3
	{"208-c3.bin"  , 0x200000, 0x14cb1703,    1}, //  4
	{"208-c4.bin"  , 0x200000, 0xc7165f19,    1}, //  5

	{"208-m1.bin"  , 0x020000, 0x0a5f3325, 0x10}, //  6 Z80 code

	{"208-v1.bin"  , 0x200000, 0x8b53e945,    2}, //  7 Sound data
	{"208-v2.bin"  , 0x200000, 0xaf37ebf8,    2}, //  8
};

STDROMPICKEXT(sdodgeb, sdodgeb, neogeo);
STD_ROM_FN(sdodgeb);

struct BurnDriver BurnDrvSdodgeb = {
	{"sdodgeb", "Super Dodge Ball", "Japanese title is Kunio no Nekketsu Toukyuu Densetsu", "Technos", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, sdodgebRomInfo, sdodgebRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Voltage Fighter: Gowcaizer

static struct BurnRomInfo gowcaizrRomDesc[] = {
	{"094-p1.bin"  , 0x200000, 0x33019545, 0x10}, //  0 68K code

	{"094-s1.bin"  , 0x020000, 0x2F8748A2,    1}, //  1 Text layer tiles

	{"094-c1.bin"  , 0x200000, 0x042F6AF5,    1}, //  2 Sprite data
	{"094-c2.bin"  , 0x200000, 0x0FBCD046,    1}, //  3
	{"094-c3.bin"  , 0x200000, 0x58BFBAA1,    1}, //  4
	{"094-c4.bin"  , 0x200000, 0x9451EE73,    1}, //  5
	{"094-c5.bin"  , 0x200000, 0xFF9CF48C,    1}, //  6
	{"094-c6.bin"  , 0x200000, 0x31BBD918,    1}, //  7
	{"094-c7.bin"  , 0x200000, 0x2091EC04,    1}, //  8
	{"094-c8.bin"  , 0x200000, 0x0D31DEE6,    1}, //  9

	{"094-m1.bin"  , 0x020000, 0x78C851CB, 0x10}, //  10 Z80 code

	{"094-v1.bin"  , 0x200000, 0x6C31223C,    2}, //  11 Sound data
	{"094-v2.bin"  , 0x200000, 0x8EDB776C,    2}, //  12
	{"094-v3.bin"  , 0x100000, 0xC63B9285,    2}, //  13
};

STDROMPICKEXT(gowcaizr, gowcaizr, neogeo);
STD_ROM_FN(gowcaizr);

struct BurnDriver BurnDrvgowcaizr = {
	{"gowcaizr", "Voltage Fighter: Gowcaizer", "Japanese title is Choujin Gakuen Gowcaizer", "Technos", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, gowcaizrRomInfo, gowcaizrRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Tecmo

// Tecmo World Soccer 96

static struct BurnRomInfo tws96RomDesc[] = {
	{"086-p1.bin"  , 0x100000, 0x03e20ab6, 0x10}, //  0 68K code

	{"086-s1.bin"  , 0x020000, 0x6f5e2b3a,    1}, //  1 Text layer tiles

	{"086-c1.bin"  , 0x400000, 0xd301a867,    1}, //  2 Sprite data
	{"086-c2.bin"  , 0x400000, 0x305fc74f,    1}, //  3
	{"086-c3.bin"  , 0x100000, 0x750ddc0c,    1}, //  4
	{"086-c4.bin"  , 0x100000, 0x7a6e7d82,    1}, //  5

	{"086-m1.bin"  , 0x010000, 0x860ba8c7, 0x10}, //  6 Z80 code

	{"086-v1.bin"  , 0x200000, 0x97bf1986,    2}, //  7 Sound data
	{"086-v2.bin"  , 0x200000, 0xb7eb05df,    1}, //  8
};

STDROMPICKEXT(tws96, tws96, neogeo);
STD_ROM_FN(tws96);

struct BurnDriver BurnDrvTws96 = {
	{"tws96", "Tecmo World Soccer '96", NULL, "Tecmo", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, tws96RomInfo, tws96RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Viccom

// Fight Fever

static struct BurnRomInfo fightfevRomDesc[] = {
	{"060-p1.bin"  , 0x080000, 0x3032041b, 0x10}, //  0 68K code
	{"060-p2.bin"  , 0x080000, 0xb0801d5f, 0x10}, //  1 68K code

	{"060-s1.bin"  , 0x020000, 0x70727a1e,    1}, //  2 Text layer tiles

	{"060-c1.bin"  , 0x200000, 0x8908fff9,    1}, //  3 Sprite data
	{"060-c2.bin"  , 0x200000, 0xc6649492,    1}, //  4
	{"060-c3.bin"  , 0x200000, 0x0956b437,    1}, //  5
	{"060-c4.bin"  , 0x200000, 0x026f3b62,    1}, //  6

	{"060-m1.bin"  , 0x020000, 0x0b7c4e65, 0x10}, //  7 Z80 code

	{"060-v1.bin"  , 0x200000, 0xf417c215,    2}, //  8 Sound data
	{"060-v2.bin"  , 0x100000, 0x64470036,    2}, //  9
};

STDROMPICKEXT(fightfev, fightfev, neogeo);
STD_ROM_FN(fightfev);

struct BurnDriver BurnDrvFightfev = {
	{"fightfev", "Fight Fever", "Japanese title is Crystal Legacy", "Viccom", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, fightfevRomInfo, fightfevRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Fight Fever (alternate set)

static struct BurnRomInfo fightfevaRomDesc[] = {
	{"060-p1a.bin" , 0x100000, 0x2a104b50, 0x10}, //  0 68K code

	{"060-s1.bin"  , 0x020000, 0x70727a1e,    1}, //  2 Text layer tiles

	{"060-c1.bin"  , 0x200000, 0x8908fff9,    1}, //  3 Sprite data
	{"060-c2.bin"  , 0x200000, 0xc6649492,    1}, //  4
	{"060-c3.bin"  , 0x200000, 0x0956b437,    1}, //  5
	{"060-c4.bin"  , 0x200000, 0x026f3b62,    1}, //  6

	{"060-m1.bin"  , 0x020000, 0x0b7c4e65, 0x10}, //  7 Z80 code

	{"060-v1.bin"  , 0x200000, 0xf417c215,    2}, //  8 Sound data
	{"060-v2.bin"  , 0x100000, 0x64470036,    2}, //  9
};

STDROMPICKEXT(fightfeva, fightfeva, neogeo);
STD_ROM_FN(fightfeva);

struct BurnDriver BurnDrvFightfeva = {
	{"fightfeva", "Fight Fever", "Alternate set, Japanese title is Crystal Legacy", "Viccom", "Neo Geo", "1994", "fightfev", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO,
	NULL, fightfevaRomInfo, fightfevaRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Video System

// Pop 'n Bounce

static struct BurnRomInfo popbouncRomDesc[] = {
	{"237-p1.bin"  , 0x100000, 0xbe96e44f, 0x10}, //  0 68K code

	{"237-s1.bin"  , 0x020000, 0xb61cf595,    1}, //  1 Text layer tiles

	{"237-c1.bin"  , 0x200000, 0xeda42d66,    1}, //  2 Sprite data
	{"237-c2.bin"  , 0x200000, 0x5e633c65,    1}, //  3

	{"237-m1.bin"  , 0x020000, 0xd4c946dd, 0x10}, //  4 Z80 code

	{"237-v1.bin"  , 0x200000, 0xedcb1beb,    2}, //  5 Sound data
};

STDROMPICKEXT(popbounc, popbounc, neogeo);
STD_ROM_FN(popbounc);

struct BurnDriver BurnDrvPopbounc = {
	{"popbounc", "Pop 'n Bounce", "Japanese title is Gapporin", "Video System Co.", "Neo Geo", "1997", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_PADDLE,
	NULL, popbouncRomInfo, popbouncRomName, neopaddleInputInfo, neopaddleDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Power Spikes II

static struct BurnRomInfo pspikes2RomDesc[] = {
	{"068-p1.bin"  , 0x100000, 0x105a408f, 0x10}, //  0 68K code

	{"068-s1.bin"  , 0x020000, 0x18082299,    1}, //  1 Text layer tiles

	{"068-c1.bin"  , 0x100000, 0x7f250f76,    1}, //  2 Sprite data
	{"068-c2.bin"  , 0x100000, 0x20912873,    1}, //  3
	{"068-c3.bin"  , 0x100000, 0x4b641ba1,    1}, //  4
	{"068-c4.bin"  , 0x100000, 0x35072596,    1}, //  5
	{"068-c5.bin"  , 0x100000, 0x151dd624,    1}, //  6
	{"068-c6.bin"  , 0x100000, 0xa6722604,    1}, //  7

	{"068-m1.bin"  , 0x020000, 0xb1c7911e, 0x10}, //  8 Z80 code

	{"068-v1.bin"  , 0x100000, 0x2ced86df,    2}, //  9 Sound data
	{"068-v2.bin"  , 0x100000, 0x970851ab,    2}, // 10
	{"068-v3.bin"  , 0x100000, 0x81ff05aa,    2}, // 11
};

STDROMPICKEXT(pspikes2, pspikes2, neogeo);
STD_ROM_FN(pspikes2);

struct BurnDriver BurnDrvPspikes2 = {
	{"pspikes2", "Power Spikes II", NULL, "Video System Co.", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, pspikes2RomInfo, pspikes2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sonic Wings 2

static struct BurnRomInfo sonicwi2RomDesc[] = {
	{"075-p1.bin"  , 0x200000, 0x92871738, 0x10}, //  0 68K code

	{"075-s1.bin"  , 0x020000, 0xc9eec367,    1}, //  1 Text layer tiles

	{"075-c1.bin"  , 0x200000, 0x3278e73e,    1}, //  2 Sprite data
	{"075-c2.bin"  , 0x200000, 0xfe6355d6,    1}, //  3
	{"075-c3.bin"  , 0x200000, 0xc1b438f1,    1}, //  4
	{"075-c4.bin"  , 0x200000, 0x1f777206,    1}, //  5

	{"075-m1.bin"  , 0x020000, 0xbb828df1, 0x10}, //  6 Z80 code

	{"075-v1.bin"  , 0x200000, 0x7577e949,    2}, //  7 Sound data
	{"075-v2.bin"  , 0x080000, 0x6d0a728e,    2}, //  8
};

STDROMPICKEXT(sonicwi2, sonicwi2, neogeo);
STD_ROM_FN(sonicwi2);

struct BurnDriver BurnDrvSonicwi2 = {
	{"sonicwi2", "Aero Fighters 2", "Japanese title is Sonic Wings 2", "Video System Co.", "Neo Geo", "1994", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, sonicwi2RomInfo, sonicwi2RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Sonic Wings 3

static struct BurnRomInfo sonicwi3RomDesc[] = {
	{"097-p1.bin"  , 0x200000, 0x0547121d, 0x10}, //  0 68K code

	{"097-s1.bin"  , 0x020000, 0x8dd66743,    1}, //  1 Text layer tiles

	{"097-c1.bin"  , 0x400000, 0x3ca97864,    1}, //  2 Sprite data
	{"097-c2.bin"  , 0x400000, 0x1da4b3a9,    1}, //  3
	{"097-c3.bin"  , 0x200000, 0xc339fff5,    1}, //  4
	{"097-c4.bin"  , 0x200000, 0x84a40c6e,    1}, //  5

	{"097-m1.bin"  , 0x020000, 0xb20e4291, 0x10}, //  6 Z80 code

	{"097-v1.bin"  , 0x400000, 0x6f885152,    2}, //  7 Sound data
	{"097-v2.bin"  , 0x100000, 0x32187ccd,    2}, //  8
};

STDROMPICKEXT(sonicwi3, sonicwi3, neogeo);
STD_ROM_FN(sonicwi3);

struct BurnDriver BurnDrvSonicwi3 = {
	{"sonicwi3", "Aero Fighters 3", "European / Japanese title is Sonic Wings 3", "Video System Co.", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPP,
	NULL, sonicwi3RomInfo, sonicwi3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Visco

// Andro Dunos

static struct BurnRomInfo androdunRomDesc[] = {
	{"049-p1.bin"  , 0x080000, 0x3B857DA2, 0x10}, //  0 68K code
	{"049-p2.bin"  , 0x080000, 0x2F062209, 0x10}, //  1

	{"049-s1.bin"  , 0x020000, 0x6349DE5D,    1}, //  2 Text layer tiles

	{"049-c1.bin"  , 0x100000, 0x7ACE6DB3,    1}, //  3 Sprite data
	{"049-c2.bin"  , 0x100000, 0xB17024F7,    1}, //  4
#if 0
	{"049-c3.bin"  , 0x100000, 0x2E0F3F9A,    1}, //  5
	{"049-c4.bin"  , 0x100000, 0x4A19FB92,    1}, //  6
#endif

	{"049-m1.bin"  , 0x020000, 0x1A009F8C, 0x10}, //  7 Z80 code

	{"049-v1.bin"  , 0x080000, 0x577C85B3,    2}, //  8 Sound data
	{"049-v2.bin"  , 0x080000, 0xE14551C4,    2}, //  9
};

STDROMPICKEXT(androdun, androdun, neogeo);
STD_ROM_FN(androdun);

struct BurnDriver BurnDrvandrodun = {
	{"androdun", "Andro Dunos", NULL, "Visco", "Neo Geo", "1992", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, androdunRomInfo, androdunRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Bang Bead (encrypted graphics)

static struct BurnRomInfo bangbeadRomDesc[] = {
	{"259-p1.bin"  , 0x200000, 0x88A37F8B, 0x10}, //  0 68K code

	{"259-c1.bin"  , 0x800000, 0x1F537F74,    1}, //  1 Sprite data
	{"259-c2.bin"  , 0x800000, 0x0EFD98FF,    1}, //  2

	{"259-m1.bin"  , 0x020000, 0x85668EE9, 0x10}, // 3 Z80 code

	{"259-v1.bin"  , 0x400000, 0x088EB8AB,    2}, //  4 Sound data
	{"259-v2.bin"  , 0x100000, 0x97528FE9,    2}, //  5
};

STDROMPICKEXT(bangbead, bangbead, neogeo);
STD_ROM_FN(bangbead);

static int bangbeadInit()
{
	nNeoProtectionXor = 0xF8;
	return NeoInit();
}

struct BurnDriver BurnDrvbangbead = {
	{"bangbead", "Bang Bead", NULL, "Visco", "Neo Geo", "2000", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SWAPP,
	NULL, bangbeadRomInfo, bangbeadRomName, neogeoInputInfo, neogeoDIPInfo,
	bangbeadInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Bang Bead (prototype)

static struct BurnRomInfo bangbedpRomDesc[] = {
	{"259-p1.bin"  , 0x200000, 0x88A37F8B, 0x10}, //  0 68K code

	{"259-s1.bin"  , 0x020000, 0xBB50FB2D,    1}, //  1 Text layer tiles

	{"259-c1p.bin" , 0x200000, 0xE3919E44,    1}, //  2 Sprite data
	{"259-c2p.bin" , 0x200000, 0xBAF5A320,    1}, //  3
	{"259-c3p.bin" , 0x100000, 0xC8E52157,    1}, //  4
	{"259-c4p.bin" , 0x100000, 0x69FA8E60,    1}, //  5

	{"259-m1.bin"  , 0x020000, 0x85668EE9, 0x10}, //  6 Z80 code

	{"259-v1p.bin" , 0x200000, 0xE97B9385,    2}, //  7 Sound data
	{"259-v2p.bin" , 0x200000, 0xB0CBD70A,    2}, //  8
	{"259-v3p.bin" , 0x100000, 0x97528FE9,    2}, //  9
};

STDROMPICKEXT(bangbedp, bangbedp, neogeo);
STD_ROM_FN(bangbedp);

struct BurnDriver BurnDrvbangbedp = {
	{"bangbedp", "Bang Bead", "All (decrypted) data identical to bangbead", "Visco", "Neo Geo", "2000", "bangbead", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE | BDF_PROTOTYPE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, bangbedpRomInfo, bangbedpRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Battle Flip Shot

static struct BurnRomInfo flipshotRomDesc[] = {
	{"247-p1.bin"  , 0x080000, 0xd2e7a7e3, 0x10}, //  0 68K code

	{"247-s1.bin"  , 0x020000, 0x6300185c,    1}, //  1 Text layer tiles

	{"247-c1.bin"  , 0x200000, 0xc9eedcb2,    1}, //  2 Sprite data
	{"247-c2.bin"  , 0x200000, 0x7d6d6e87,    1}, //  3

	{"247-m1.bin"  , 0x020000, 0xa9fe0144, 0x10}, //  4 Z80 code

	{"247-v1.bin"  , 0x200000, 0x42ec743d,    2}, //  5 Sound data
};

STDROMPICKEXT(flipshot, flipshot, neogeo);
STD_ROM_FN(flipshot);

struct BurnDriver BurnDrvFlipshot = {
	{"flipshot", "Battle Flip Shot", NULL, "Visco", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, flipshotRomInfo, flipshotRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Breakers

static struct BurnRomInfo breakersRomDesc[] = {
	{"230-p1.bin"  , 0x200000, 0xED24A6E6, 0x10}, //  0 68K code

	{"230-s1.bin"  , 0x020000, 0x076FB64C,    1}, //  1 Text layer tiles

	{"230-c1.bin"  , 0x400000, 0x68D4AE76,    1}, //  2 Sprite data
	{"230-c2.bin"  , 0x400000, 0xFDEE05CD,    1}, //  3
	{"230-c3.bin"  , 0x400000, 0x645077F3,    1}, //  4
	{"230-c4.bin"  , 0x400000, 0x63AEB74C,    1}, //  5

	{"230-m1.bin"  , 0x020000, 0x3951A1C1, 0x10}, //  6 Z80 code

	{"230-v1.bin"  , 0x400000, 0x7F9ED279,    2}, //  7 Sound data
	{"230-v2.bin"  , 0x400000, 0x1D43E420,    2}, //  8
};

STDROMPICKEXT(breakers, breakers, neogeo);
STD_ROM_FN(breakers);

struct BurnDriver BurnDrvBreakers = {
	{"breakers", "Breakers", NULL, "Visco", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, breakersRomInfo, breakersRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Breakers Revenge

static struct BurnRomInfo breakrevRomDesc[] = {
	{"245-p1.bin"  , 0x200000, 0xC828876D, 0x10}, //  0 68K code

	{"245-s1.bin"  , 0x020000, 0xE7660A5D,    1}, //  1 Text layer tiles

	{"230-c1.bin"  , 0x400000, 0x68D4AE76,    1}, //  2 Sprite data
	{"230-c2.bin"  , 0x400000, 0xFDEE05CD,    1}, //  3
	{"230-c3.bin"  , 0x400000, 0x645077F3,    1}, //  4
	{"230-c4.bin"  , 0x400000, 0x63AEB74C,    1}, //  5
	{"245-c5.bin"  , 0x200000, 0x28FF1792,    1}, //  6
	{"245-c6.bin"  , 0x200000, 0x23C65644,    1}, //  7

	{"245-m1.bin"  , 0x020000, 0x00F31C66, 0x10}, //  8 Z80 code

	{"245-v1.bin"  , 0x400000, 0xE255446C,    2}, //  9 Sound data
	{"245-v2.bin"  , 0x400000, 0x9068198A,    2}, // 10
};

STDROMPICKEXT(breakrev, breakrev, neogeo);
STD_ROM_FN(breakrev);

struct BurnDriver BurnDrvBreakRev = {
	{"breakrev", "Breakers Revenge", NULL, "Visco", "Neo Geo", "1998", "breakers", "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, breakrevRomInfo, breakrevRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Captain Tomaday

static struct BurnRomInfo ctomadayRomDesc[] = {
	{"249-p1.bin"  , 0x200000, 0xC9386118, 0x10}, //  0 68K code

	{"249-s1.bin"  , 0x020000, 0xDC9EB372,    1}, //  1 Text layer tiles

	{"249-c1.bin"  , 0x400000, 0x041FB8EE,    1}, //  2 Sprite data
	{"249-c2.bin"  , 0x400000, 0x74F3CDF4,    1}, //  3

	{"249-m1.bin"  , 0x020000, 0x80328A47, 0x10}, //  4 Z80 code

	{"249-v1.bin"  , 0x400000, 0xDE7C8F27,    2}, //  5 Sound data
	{"249-v2.bin"  , 0x100000, 0xC8E40119,    2}, //  6
};

STDROMPICKEXT(ctomaday, ctomaday, neogeo);
STD_ROM_FN(ctomaday);

struct BurnDriver BurnDrvCTomaday = {
	{"ctomaday", "Captain Tomaday", NULL, "Visco", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP,
	NULL, ctomadayRomInfo, ctomadayRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Ganryu

static struct BurnRomInfo ganryuRomDesc[] = {
	{"252-p1.bin"  , 0x200000, 0x4B8AC4FB, 0x10}, //  0 68K code

	{"252-c1.bin"  , 0x800000, 0x50EE7882,    1}, //  1 Sprite data
	{"252-c2.bin"  , 0x800000, 0x62585474,    1}, //  2

	{"252-m1.bin"  , 0x020000, 0x30CC4099, 0x10}, //  3 Z80 code

	{"252-v1.bin"  , 0x400000, 0xE5946733,    2}, //  4 Sound data
};

STDROMPICKEXT(ganryu, ganryu, neogeo);
STD_ROM_FN(ganryu);

static int ganryuInit()
{
	nNeoProtectionXor = 0x07;
	return NeoInit();
}

struct BurnDriver BurnDrvGanryu = {
	{"ganryu", "Ganryu", "Japanese title is Mushashi Ganryuki", "Visco", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SWAPP,
	NULL, ganryuRomInfo, ganryuRomName, neogeoInputInfo, neogeoDIPInfo,
	ganryuInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Goal! Goal! Goal!

static struct BurnRomInfo goalx3RomDesc[] = {
	{"209-p1.bin"  , 0x200000, 0x2a019a79, 0x10}, //  0 68K code

	{"209-s1.bin"  , 0x020000, 0xc0eaad86,    1}, //  1 Text layer tiles

	{"209-c1.bin"  , 0x400000, 0xd061f1f5,    1}, //  2 Sprite data
	{"209-c2.bin"  , 0x400000, 0x3f63c1a2,    1}, //  3
	{"209-c3.bin"  , 0x100000, 0x5f91bace,    1}, //  4
	{"209-c4.bin"  , 0x100000, 0x1e9f76f2,    1}, //  5

	{"209-m1.bin"  , 0x010000, 0xdd945773, 0x10}, //  6 Z80 code

	{"209-v1.bin"  , 0x200000, 0xef214212,    2}, //  7	Sound data
};

STDROMPICKEXT(goalx3, goalx3, neogeo);
STD_ROM_FN(goalx3);

struct BurnDriver BurnDrvGoalx3 = {
	{"goalx3", "Goal! Goal! Goal!", NULL, "Visco", "Neo Geo", "1995", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPP | HARDWARE_SNK_SWAPC,
	NULL, goalx3RomInfo, goalx3RomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Neo Drift Out

static struct BurnRomInfo neodriftRomDesc[] = {
	{"213-p1.bin"  , 0x200000, 0xe397d798, 0x10}, //  0 68K code

	{"213-s1.bin"  , 0x020000, 0xb76b61bc,    1}, //  1 Text layer tiles

	{"213-c1.bin"  , 0x400000, 0x62c5edc9,    1}, //  2 Sprite data
	{"213-c2.bin"  , 0x400000, 0x9dc9c72a,    1}, //  3

	{"213-m1.bin"  , 0x020000, 0x200045f1, 0x10}, //  4 Z80 code

	{"213-v1.bin"  , 0x200000, 0xa421c076,    2}, //  5	Sound data
	{"213-v2.bin"  , 0x200000, 0x233c7dd9,    2}, //  6
};

STDROMPICKEXT(neodrift, neodrift, neogeo);
STD_ROM_FN(neodrift);

struct BurnDriver BurnDrvNeodrift = {
	{"neodrift", "Neo Drift Out: New Technology", NULL, "Visco", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC | HARDWARE_SNK_SWAPP,
	NULL, neodriftRomInfo, neodriftRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Neo Mr. Do!

static struct BurnRomInfo neomrdoRomDesc[] = {
	{"207-p1.bin"  , 0x080000, 0x39efdb82, 0x10}, //  0 68K code

	{"207-s1.bin"  , 0x010000, 0x6c4b09c4,    1}, //  1 Text layer tiles

	{"207-c1.bin"  , 0x200000, 0xc7541b9d,    1}, //  2 Sprite data
	{"207-c2.bin"  , 0x200000, 0xf57166d2,    1}, //  3

	{"207-m1.bin"  , 0x020000, 0x81eade02, 0x10}, //  4 Z80 code

	{"207-v1.bin"  , 0x200000, 0x4143c052,    2}, //  5 Sound data
};

STDROMPICKEXT(neomrdo, neomrdo, neogeo);
STD_ROM_FN(neomrdo);

struct BurnDriver BurnDrvNeomrdo = {
	{"neomrdo", "Neo Mr. Do!", NULL, "Visco", "Neo Geo", "1996", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, neomrdoRomInfo, neomrdoRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Yumebubo

// Blazing Star

static struct BurnRomInfo blazstarRomDesc[] = {
	{"239-p1.bin", 0x100000, 0x183682F8, 0x10}, //  0 68K code
	{"239-p2.bin", 0x200000, 0x9A9F4154, 0x10}, //  1

	{"239-s1.bin", 0x020000, 0xD56CB498,    1}, //  2 Text layer tiles

	{"239-c1.bin", 0x400000, 0x754744E0,    1}, //  3 Sprite data
	{"239-c2.bin", 0x400000, 0xAF98C037,    1}, //  4
	{"239-c3.bin", 0x400000, 0x7B39B590,    1}, //  5
	{"239-c4.bin", 0x400000, 0x6E731B30,    1}, //  6
	{"239-c5.bin", 0x400000, 0x9CEB113B,    1}, //  7
	{"239-c6.bin", 0x400000, 0x6A78E810,    1}, //  8
	{"239-c7.bin", 0x400000, 0x50D28ECA,    1}, //  9
	{"239-c8.bin", 0x400000, 0xCDBBB7D7,    1}, // 10

	{"239-m1.bin", 0x020000, 0xd31A3AEA, 0x10}, // 11 Z80 code

	{"239-v1.bin", 0x400000, 0x1B8D5BF7,    2}, // 12	Sound data
	{"239-v2.bin", 0x400000, 0x74CF0A70,    2}, // 13
};

STDROMPICKEXT(blazstar, blazstar, neogeo);
STD_ROM_FN(blazstar);

struct BurnDriver BurnDrvBlazStar = {
	{"blazstar", "Blazing Star", NULL, "Yumekobo", "Neo Geo", "1998", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, blazstarRomInfo, blazstarRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Prehistoric Isle 2 (encrypted grahics)

static struct BurnRomInfo preisle2RomDesc[] = {
	{"255-p1.bin", 0x100000, 0xDFA3C0F3, 0x10}, //  0 68K code
	{"255-p2.bin", 0x400000, 0x42050B80, 0x10}, //  1

	{"255-c1.bin", 0x800000, 0xEA06000B,    1}, //  2 Sprite data
	{"255-c2.bin", 0x800000, 0x04E67D79,    1}, //  3
	{"255-c3.bin", 0x800000, 0x60E31E08,    1}, //  4
	{"255-c4.bin", 0x800000, 0x40371D69,    1}, //  5
	{"255-c5.bin", 0x800000, 0x0B2E6ADF,    1}, //  6
	{"255-c6.bin", 0x800000, 0xB001BDD3,    1}, //  7

	{"255-m1.bin", 0x020000, 0x8EFD4014, 0x10}, // 10 Z80 code

	{"255-v1.bin", 0x400000, 0x5A14543D,    2}, // 11 Sound data
	{"255-v2.bin", 0x200000, 0x6610D91A,    2}, // 12
};

STDROMPICKEXT(preisle2, preisle2, neogeo);
STD_ROM_FN(preisle2);

static int preisle2Init()
{
	nNeoProtectionXor = 0x9F;
	return NeoInit();
}

struct BurnDriver BurnDrvpreisle2 = {
	{"preisle2", "Prehistoric Isle 2", NULL, "Yumekobo", "Neo Geo", "1999", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ENCRYPTED_A | HARDWARE_SNK_SRAM,
	NULL, preisle2RomInfo, preisle2RomName, neogeoInputInfo, neogeoDIPInfo,
	preisle2Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// -----------------------------------------------------------------------------
// Free / homebrew games

/*

// Neo No Panepon

static struct BurnRomInfo neonoponRomDesc[] = {
	{"239-p1.bin", 0x080000, 0x8A792271, 0x10}, //  0 68K code

	{"239-s1.bin", 0x010000, 0x93E6FE7D,    1}, //  1 Text layer tiles

	{"239-c1.bin", 0x100000, 0x4A718AE3,    1}, //  2 Sprite data
	{"239-c2.bin", 0x100000, 0x0E2CBC25,    1}, //  3

	{"239-m1.bin", 0x010000, 0x7669DE64, 0x10}, //  4 Z80 code

	{"239-v1.bin", 0x080000, 0x504BF849,    2}, //  5 Sound data
};

STDROMPICKEXT(neonopon, neonopon, neogeo);
STD_ROM_FN(neonopon);

struct BurnDriver BurnDrvNeonopon = {
	{"neonopon", "Neo No Panepon", NULL, "blastar@gmx.net", "Neo Geo", "2003", NULL, "neogeo"},
	BDF_GAME_WORKING, 2, HARDWARE_SNK_NEOGEO,
	NULL, neonoponRomInfo, neonoponRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

*/

// -----------------------------------------------------------------------------
// Pre-decrypted ROMsets

/*

// Garou (decrypted C-ROMs)

static struct BurnRomInfo garounRomDesc[] = {
	{"253-sma.bin"  , 0x040000, 0x98bc93dc, 0x10}, //  0 68K code
	{"253-ep1.p1"   , 0x200000, 0xea3171a4, 0x10}, //  1
	{"253-ep2.p2"   , 0x200000, 0x382f704b, 0x10}, //  2
	{"253-ep3.p3"   , 0x200000, 0xe395bfdd, 0x10}, //  3
	{"253-ep4.p4"   , 0x200000, 0xda92c08e, 0x10}, //  4

	{"motwn_c1.bin" , 0x800000, 0x497be3f2,    1}, //  5 Sprite data
	{"motwn_c2.bin" , 0x800000, 0x6a9e95ca,    1}, //  6
	{"motwn_c3.bin" , 0x800000, 0x39373d2f,    1}, //  7
	{"motwn_c4.bin" , 0x800000, 0x4de23f6c,    1}, //  8
	{"motwn_c5.bin" , 0x800000, 0x16634ba5,    1}, //  9
	{"motwn_c6.bin" , 0x800000, 0x95671ffd,    1}, // 10
	{"motwn_c7.bin" , 0x800000, 0xe36ce77f,    1}, // 11
	{"motwn_c8.bin" , 0x800000, 0xddbd1096,    1}, // 12

	{"253-m1.bin"   , 0x040000, 0x36a806be, 0x10}, // 13 Z80 code

	{"253-v1.bin"   , 0x400000, 0x263e388c,    2}, // 14 Sound data
	{"253-v2.bin"   , 0x400000, 0x2c6bc7be,    2}, // 15
	{"253-v3.bin"   , 0x400000, 0x0425b27d,    2}, // 16
	{"253-v4.bin"   , 0x400000, 0xa54be8a9,    2}, // 17
};

STDROMPICKEXT(garoun, garoun, neogeo);
STD_ROM_FN(garoun);

struct BurnDriver BurnDrvGaroun = {
	{"garoun", "Garou: Mark Of The Wolves", "decrypted C-ROMs", "SNK", "Neo Geo", "1999", "garou", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM | HARDWARE_SNK_SMA_PROTECTION,
	NULL, garounRomInfo, garounRomName, neogeoInputInfo, neogeoDIPInfo,
	garouInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King of Fighters '99 (Non-encrypted P-ROMs, decrypted C-ROMs)

static struct BurnRomInfo kof99ndRomDesc[] = {
	{"152-p1.bin",	0x100000, 0xF2C7DDFA, 0x10}, //  0 68K code
	{"152-p2.bin",	0x400000, 0x274EF47A, 0x10}, //  1

	{"kf99n_c1.bin",0x800000, 0xb3d88546,    1}, //  2 Sprite data
	{"kf99n_c2.bin",0x800000, 0x915c8634,    1}, //  3
	{"kf99n_c3.bin",0x800000, 0xb047c9d5,    1}, //  4
	{"kf99n_c4.bin",0x800000, 0x6bc8e4b1,    1}, //  5
	{"kf99n_c5.bin",0x800000, 0x9746268c,    1}, //  6
	{"kf99n_c6.bin",0x800000, 0x238b3e71,    1}, //  7
	{"kf99n_c7.bin",0x800000, 0x2f68fdeb,    1}, //  8
	{"kf99n_c8.bin",0x800000, 0x4c2fad1e,    1}, //  9

	{"251-m1.bin",	0x020000, 0x5E74539C, 0x10}, // 10 Z80 code

	{"251-v1.bin",	0x400000, 0xEF2EECC8,    2}, // 11 Sound data
	{"251-v2.bin",	0x400000, 0x73E211CA,    2}, // 12
	{"251-v3.bin",	0x400000, 0x821901DA,    2}, // 13
	{"251-v4.bin",	0x200000, 0xB49E6178,    2}, // 14
};

STDROMPICKEXT(kof99nd, kof99nd, neogeo);
STD_ROM_FN(kof99nd);

struct BurnDriver BurnDrvkof99nd = {
	{"kof99nd", "The King of Fighters '99: Millennium Battle", "Non-encrypted P-ROMs, decrypted C-ROMs", "SNK", "Neo Geo", "1999", "kof99", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, kof99ndRomInfo, kof99ndRomName, neogeoInputInfo, neogeoDIPInfo,
	NeoInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// The King Of Fighters 2000 (Non-encrypted P-ROMs, decrypted C-ROMs)

static struct BurnRomInfo kof2kndRomDesc[] = {
	{"257-p1n.bin",	0x100000, 0x5F809DBE, 0x10}, //  0 68K code
	{"257-p2n.bin",	0x400000, 0x693C2C5E, 0x10}, //  1

	{"kof2k_c1.bin",0x800000, 0xabcdd424,    1}, //  2 Sprite data
	{"kof2k_c2.bin",0x800000, 0xcda33778,    1}, //  3
	{"kof2k_c3.bin",0x800000, 0x087fb15b,    1}, //  4
	{"kof2k_c4.bin",0x800000, 0xfe9dfde4,    1}, //  5
	{"kof2k_c5.bin",0x800000, 0x03ee4bf4,    1}, //  6
	{"kof2k_c6.bin",0x800000, 0x8599cc5b,    1}, //  7
	{"kof2k_c7.bin",0x800000, 0x71dfc3e2,    1}, //  8
	{"kof2k_c8.bin",0x800000, 0x0fa30e5f,    1}, //  9

	{"257-m1d.bin",	0x040000, 0xD404DB70, 0x10}, // 10 Z80 code (decrypted)

	{"257-v1.bin",	0x400000, 0x17CDE847,    2}, // 11 Sound data
	{"257-v2.bin",	0x400000, 0x1aFB20FF,    2}, // 12
	{"257-v3.bin",	0x400000, 0x4605036A,    2}, // 13
	{"257-v4.bin",	0x400000, 0x764BBD6B,    2}, // 14
};

STDROMPICKEXT(kof2knd, kof2knd, neogeo);
STD_ROM_FN(kof2knd);

static int kof2kndInit()
{
	nNeoTextROMSize = 0x080000;
	return NeoInit();
}

struct BurnDriver BurnDrvkof2knd = {
	{"kof2knd", "The King of Fighters 2000", "Non-encrypted P-ROMs, decrypted C-ROMs", "SNK", "Neo Geo", "2000", "kof2000", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_ALTERNATE_TEXT | HARDWARE_SNK_SRAM,
	NULL, kof2kndRomInfo, kof2kndRomName, neogeoInputInfo, neogeoDIPInfo,
	kof2kndInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Metal Slug 3 (Non-encrypted P-ROMs, decrypted C-ROMs)

static struct BurnRomInfo mslug3ndRomDesc[] = {
	{"256-ph1.rom",0x100000, 0x9C42CA85, 0x10}, //  0 68K code
	{"256-ph2.rom",0x400000, 0x1F3D8CE8, 0x10}, //  1

	{"ms3n_c1.bin",0x800000, 0x3540398c,    1}, //  2 Sprite data
	{"ms3n_c2.bin",0x800000, 0xbdd220f0,    1}, //  3
	{"ms3n_c3.bin",0x800000, 0xbfaade82,    1}, //  4
	{"ms3n_c4.bin",0x800000, 0x1463add6,    1}, //  5
	{"ms3n_c5.bin",0x800000, 0x48ca7f28,    1}, //  6
	{"ms3n_c6.bin",0x800000, 0x806eb36f,    1}, //  7
	{"ms3n_c7.bin",0x800000, 0x9395b809,    1}, //  8
	{"ms3n_c8.bin",0x800000, 0xa369f9d4,    1}, //  9

	{"256-m1.bin", 0x080000, 0xEAEEC116, 0x10}, // 10 Z80 code

	{"256-v1.bin", 0x400000, 0xF2690241,    2}, // 11 Sound data
	{"256-v2.bin", 0x400000, 0x7E2A10BD,    2}, // 12
	{"256-v3.bin", 0x400000, 0x0EAEC17C,    2}, // 13
	{"256-v4.bin", 0x400000, 0x9B4B22D4,    2}, // 14
};

STDROMPICKEXT(mslug3nd, mslug3nd, neogeo);
STD_ROM_FN(mslug3nd);

static int mslug3ndInit()
{
	nNeoTextROMSize = 0x080000;
	return NeoInit();
}

struct BurnDriver BurnDrvmslug3nd = {
	{"mslug3nd", "Metal Slug 3", "Non-encrypted P-ROMs, decrypted C-ROMs", "SNK", "Neo Geo", "2000", "mslug3", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO,
	NULL, mslug3ndRomInfo, mslug3ndRomName, neogeoInputInfo, neogeoDIPInfo,
	mslug3ndInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Prehistoric Isle 2 (Non-encrypted P-ROMs, decrypted C-ROMs)

static struct BurnRomInfo preisl2nRomDesc[] = {
	{"255-p1.bin", 0x100000, 0xDFA3C0F3, 0x10}, //  0 68K code
	{"255-p2.bin", 0x400000, 0x42050B80, 0x10}, //  1

	{"pi2n_c1.bin",0x800000, 0x50fd785e,    1}, //  2 Sprite data
	{"pi2n_c2.bin",0x800000, 0xab913f1e,    1}, //  3
	{"pi2n_c3.bin",0x800000, 0xbc0ee75c,    1}, //  4
	{"pi2n_c4.bin",0x800000, 0x29908823,    1}, //  5
	{"pi2n_c5.bin",0x800000, 0x83c56bca,    1}, //  6
	{"pi2n_c6.bin",0x800000, 0x59e0e805,    1}, //  7

	{"255-m1.bin", 0x020000, 0x8EFD4014, 0x10}, // 10 Z80 code

	{"255-v1.bin", 0x400000, 0x5A14543D,    2}, // 11 Sound data
	{"255-v2.bin", 0x200000, 0x6610D91A,    2}, // 12
};

STDROMPICKEXT(preisl2n, preisl2n, neogeo);
STD_ROM_FN(preisl2n);

struct BurnDriver BurnDrvpreisl2n = {
	{"preisl2n", "Prehistoric Isle 2", "Non-encrypted P-ROMs, decrypted C-ROMs", "Yumekobo", "Neo Geo", "1999", "preisle2", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SRAM,
	NULL, preisl2nRomInfo, preisl2nRomName, neogeoInputInfo, neogeoDIPInfo,
	preisle2Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};

// Strikers 1945 plus (Non-encrypted P-ROMs, decrypted C-ROMs)

static struct BurnRomInfo s1945pnRomDesc[] = {
	{"254-p1.bin",	0x100000, 0xFF8EFCFF, 0x10}, //  0 68K code
	{"254-p2.bin",	0x400000, 0xEFDFD4DD, 0x10}, //  1

	{"s45pn_c1.bin",0x800000, 0x7b6902f9,    1}, //  2 Sprite data
	{"s45pn_c2.bin",0x800000, 0x51bd4252,    1}, //  3
	{"s45pn_c3.bin",0x800000, 0xa38993e4,    1}, //  4
	{"s45pn_c4.bin",0x800000, 0xd5696530,    1}, //  5
	{"s45pn_c5.bin",0x800000, 0x28764bd6,    1}, //  6
	{"s45pn_c6.bin",0x800000, 0x9931bdf1,    1}, //  7
	{"s45pn_c7.bin",0x800000, 0x6e12afcd,    1}, //  8
	{"s45pn_c8.bin",0x800000, 0x178d4684,    1}, //  9

	{"254-m1.bin",	0x020000, 0x994B4487, 0x10}, // 10 Z80 code

	{"254-v1.bin",	0x400000, 0x844F58FB,    2}, // 11 Sound data
	{"254-v2.bin",	0x400000, 0xD9A248F0,    2}, // 12
	{"254-v3.bin",	0x400000, 0x0B0D2D33,    2}, // 13
	{"254-v4.bin",	0x400000, 0x6D13DC91,    2}, // 14
};

STDROMPICKEXT(s1945pn, s1945pn, neogeo);
STD_ROM_FN(s1945pn);

struct BurnDriver BurnDrvs1945pn = {
	{"s1945pn", "Strikers 1945 plus", "Non-encrypted P-ROMs, decrypted C-ROMs", "Psikyo", "Neo Geo", "1999", "s1945p", "neogeo"},
	BDF_GAME_WORKING | BDF_CLONE, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, s1945pnRomInfo, s1945pnRomName, neogeoInputInfo, neogeoDIPInfo,
	s1945pInit, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette,
	nNeoScreenWidth, 224, 4, 3
};
// Crouching Tiger, Hidden Dragon 2003 (Bootleg)

static struct BurnRomInfo cthd2003RomDesc[] = { 
	{"5003-p1.bin", 0x100000, 0xbb7602c1, 0x10}, // 0 68K code 
	{"5003-p2.bin", 0x400000, 0xadc1c22b, 0x10}, // 1 

	{"5003-s1.bin", 0x020000, 0x5ba29aab,    1}, // 2 Text layer tiles 

	{"5003-c1.bin", 0x800000, 0x68f54b67,    1}, // 3 Sprite data 
	{"5003-c2.bin", 0x800000, 0x2f8849d5,    1}, // 4 
	{"5003-c3.bin", 0x800000, 0xac4aff71,    1}, // 5 
	{"5003-c4.bin", 0x800000, 0xafef5d66,    1}, // 6 
	{"5003-c5.bin", 0x800000, 0xc7c1ae50,    1}, // 7 
	{"5003-c6.bin", 0x800000, 0x613197f9,    1}, // 8 
	{"5003-c7.bin", 0x800000, 0x64ddfe0f,    1}, // 9 
	{"5003-c8.bin", 0x800000, 0x917a1439,    1}, // 10 

	{"5003-m1.bin", 0x020000, 0x1a8c274b, 0x10}, // 11 Z80 code 

	{"262-v1.bin", 0x400000, 0x83d49ecf,     2}, // 11 Sound data 
	{"262-v2.bin", 0x400000, 0x003f1843,     2}, // 12 
	{"262-v3.bin", 0x400000, 0x2ae38dbe,     2}, // 13 
	{"262-v4.bin", 0x400000, 0x26ec4dd9,     2}, // 14
}; 

STDROMPICKEXT(cthd2003, cthd2003, neogeo);
STD_ROM_FN(cthd2003);

void __fastcall cthd2003WriteWordBankswitch(unsigned int sekAddress, unsigned short wordValue)
{ 
	static unsigned int cthd2003_banks[8] =
	{ 
		1,0,1,0,1,0,3,2,
	};

	if (sekAddress == 0x2ffff0)
	{ 
		if ((cthd2003_banks[wordValue&7]*0x100000) != nNeo68KROMBank)
		{
			nNeo68KROMBank = cthd2003_banks[wordValue&7]*0x100000;
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank, 0x200000, 0x2FE3FF, SM_ROM);
			SekMapMemory(Neo68KROM02 + nNeo68KROMBank + 0x0FE800, 0x2FE800, 0x2FFBFF, SM_ROM);
		}
	}
}

static void cthd2003Patch() 
{ 
	*((unsigned short*)(Neo68KROM01 + 0xf415a)) = 0x4ef9; 
	*((unsigned short*)(Neo68KROM01 + 0xf415c)) = 0x000f; 
	*((unsigned short*)(Neo68KROM01 + 0xf415e)) = 0x4cf2; 
	int i; 
	for (i=0x1ae290;i < 0x1ae8d0; i=i+2) 
	{ 
		*((unsigned short*)(Neo68KROM01 + i)) = 0x0000; 
	} 
	for (i=0x1f8ef0;i < 0x1fa1f0; i=i+4) 
	{ 
		*((unsigned short*)(Neo68KROM01 + i)) -= 0x7000; 
		*((unsigned short*)(Neo68KROM01 + (i + 2))) -= 0x0010; 
	} 
	for (i=0xac500;i < 0xac520; i=i+2) 
	{ 
		*((unsigned short*)(Neo68KROM01 + i)) = 0xFFFF; 
	} 
	*((unsigned short*)(Neo68KROM01 + 0x991d0)) = 0xdd03; 
	*((unsigned short*)(Neo68KROM01 + 0x99306)) = 0xdd03; 
	*((unsigned short*)(Neo68KROM01 + 0x99354)) = 0xdd03; 
	*((unsigned short*)(Neo68KROM01 + 0x9943e)) = 0xdd03; 
} 

static void cthd2003_neogeo_gfx_address_fix_do(int start, int end, int bit3shift, int bit2shift, int bit1shift, int bit0shift) 
{ 
	int i,j; 
	int tilesize=128; 
	UINT8* rom = (UINT8*)malloc(16*tilesize); // 16 tiles buffer 
	UINT8* realrom = (UINT8*)(NeoSpriteROM + start*tilesize); 
	for (i = 0; i < (end-start)/16; i++) { 
		for (j = 0; j < 16; j++) { 
			int offset = (((j&1)>>0)<<bit0shift) 
			+(((j&2)>>1)<<bit1shift) 
			+(((j&4)>>2)<<bit2shift) 
			+(((j&8)>>3)<<bit3shift); 
			memcpy(rom+j*tilesize, realrom+offset*tilesize, tilesize); 
		} 
	memcpy(realrom,rom,tilesize*16); 
	realrom+=16*tilesize; 
	} 
	free(rom); 
} 

static void cthd2003_neogeo_gfx_address_fix(int start, int end) 
{ 
	cthd2003_neogeo_gfx_address_fix_do(start+512*0, end+512*0, 0,3,2,1); 
	cthd2003_neogeo_gfx_address_fix_do(start+512*1, end+512*1, 1,0,3,2); 
	cthd2003_neogeo_gfx_address_fix_do(start+512*2, end+512*2, 2,1,0,3); 
	// skip 3 & 4 
	cthd2003_neogeo_gfx_address_fix_do(start+512*5, end+512*5, 0,1,2,3); 
	cthd2003_neogeo_gfx_address_fix_do(start+512*6, end+512*6, 0,1,2,3); 
	cthd2003_neogeo_gfx_address_fix_do(start+512*7, end+512*7, 0,2,3,1); 
} 

static void cthd2003_c() 
{ 
	int i; 
	for (i=0; i=192; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
	for (i=200; i<=392; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
	for (i=400; i<=592; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
	for (i=600; i<=792; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
	for (i=800; i<=992; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
	for (i=1000; i<=1016; i+=8) 
	cthd2003_neogeo_gfx_address_fix(i*512,i*512+512); 
} 

static void cthd2003Decrypt() 
{ 
	UINT8 *romdata = (UINT8 *)(NeoTextROM + 0x020000); 
	UINT8*tmp = (UINT8*)malloc(0x20000); 
	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128); 
	memcpy(tmp+8*32*128, romdata+8*64*128, 8*32*128); 
	memcpy(tmp+8*64*128, romdata+8*32*128, 8*32*128); 
	memcpy(tmp+8*96*128, romdata+8*96*128, 8*32*128); 
	memcpy(romdata, tmp, 8*128*128); 
	romdata = (UINT8 *)(NeoZ80ROM); 
	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128); 
	memcpy(tmp+8*32*128, romdata+8*64*128, 8*32*128); 
	memcpy(tmp+8*64*128, romdata+8*32*128, 8*32*128); 
	memcpy(tmp+8*96*128, romdata+8*96*128, 8*32*128); 
	memcpy(romdata, tmp, 8*128*128); 
	free(tmp); 
	memcpy(romdata-0x10000,romdata,0x10000); 
	cthd2003_c(); 
	cthd2003Patch(); 
} 

static int cthd2003Init() 
{ 
	pNeoSMABankswitch = cthd2003WriteWordBankswitch; 
	pNeoInitCallback = cthd2003Decrypt; 
	ncthd2003=1; 

	return NeoInit(); 
}

struct BurnDriver BurnDrvcthd2003 = { 
	{"cthd2003", "Crouching Tiger Hidden Dragon 2003", "Korean bootleg of The King of Fighters 2001", "SNK", "Neo Geo", "2001", "kof2001", "neogeo"}, 
	BDF_GAME_WORKING | BDF_CLONE | BDF_BOOTLEG, 2, HARDWARE_SNK_NEOGEO | HARDWARE_SNK_SWAPC,
	NULL, cthd2003RomInfo, cthd2003RomName, neogeoInputInfo, neogeoDIPInfo, 
	cthd2003Init, NeoExit, NeoFrame, NeoRender, NeoScan, &NeoRecalcPalette, 
	nNeoScreenWidth, 224, 4, 3 
};
*/
